@@ -48,6 +48,7 @@ $tablecitta = $PHPR_TAB_PRE."citta";
 $tabledocumentiid = $PHPR_TAB_PRE."documentiid";
 $tableparentele = $PHPR_TAB_PRE."parentele";
 $tablecache = $PHPR_TAB_PRE."cache";
+$tablecasse = $PHPR_TAB_PRE."casse";
 
 
 
@@ -145,13 +146,20 @@ if (substr($priv_ins_clienti,2,1) == "p") $vedi_clienti = "PROPRI";
 if (substr($priv_ins_clienti,2,1) == "g") { $vedi_clienti = "GRUPPI"; $prendi_gruppi = "SI"; }
 $priv_vedi_telefoni = substr($priv_ins_clienti,3,1);
 $priv_vedi_indirizzo = substr($priv_ins_clienti,4,1);
+$casse_consentite = risul_query($privilegi_globali_utente,0,'casse_consentite');
+$attiva_casse_consentite = substr($casse_consentite,0,1);
+if ($attiva_casse_consentite == "s") {
+$casse_consentite = explode(",",substr($casse_consentite,2));
+unset($casse_consentite_vett);
+for ($num1 = 0 ; $num1 < count($casse_consentite) ; $num1++) if ($casse_consentite[$num1]) $casse_consentite_vett[$casse_consentite[$num1]] = "SI";
+} # fine if ($attiva_casse_consentite == "s")
 $contratti_consentiti = risul_query($privilegi_annuali_utente,0,'contratti_consentiti');
 $attiva_contratti_consentiti = substr($contratti_consentiti,0,1);
 if ($attiva_contratti_consentiti == "s") {
 $contratti_consentiti = explode(",",$contratti_consentiti);
-unset($contratto_trovato);
-for ($num1 = 1 ; $num1 < count($contratti_consentiti) ; $num1++) if ($contratti_consentiti[$num1] and $contratti_consentiti[$num1] == $numero_contratto) $contratto_trovato = "SI";
-if ($contratto_trovato != "SI") $anno_utente_attivato = "NO";
+$contratti_consentiti_vett = array();
+for ($num1 = 1 ; $num1 < count($contratti_consentiti) ; $num1++) if ($contratti_consentiti[$num1]) $contratti_consentiti_vett[$contratti_consentiti[$num1]] = "SI";
+if ($contratti_consentiti_vett[$numero_contratto] != "SI") $anno_utente_attivato = "NO";
 } # fine if ($attiva_contratti_consentiti == "s")
 } # fine else if (numlin_query($privilegi_annuali_utente) == 0)
 unset($utenti_gruppi);
@@ -185,6 +193,7 @@ $priv_mod_codice = "s";
 $vedi_clienti = "SI";
 $priv_vedi_telefoni = "s";
 $priv_vedi_indirizzo = "s";
+$attiva_casse_consentite = "n";
 $attiva_contratti_consentiti = "n";
 } # fine else if ($id_utente != 1)
 if ($anno_utente_attivato == "SI") {
@@ -201,7 +210,7 @@ $nome_contratto = $nomi_contratti['salv'][$numero_contratto];
 $cont_salva = "SI";
 $sovrascrivi = "";
 
-define('C_ID_UTENTE',$id_utente);
+define('C_ID_UTENTE_CONTR',$id_utente);
 $campi_pers_comm = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'campi_pers_comm' and idutente = '$id_utente'");
 if (numlin_query($campi_pers_comm) == 1) {
 $campi_pers_comm = explode(">",risul_query($campi_pers_comm,0,'valpersonalizza'));
@@ -227,8 +236,10 @@ $tableperiodi = $PHPR_TAB_PRE."periodi".$anno;
 $tablesoldi = $PHPR_TAB_PRE."soldi".$anno;
 $tablerclientiprenota = $PHPR_TAB_PRE."rclientiprenota".$anno;
 $tablesoldi = $PHPR_TAB_PRE."soldi".$anno;
+$tablecosti = $PHPR_TAB_PRE."costi".$anno;
 $query_prenota = "";
 $query_clienti = "";
+$query_cassa = "";
 $lista_prenota = 0;
 $sec_oggi = time() + (C_DIFF_ORE * 3600);
 
@@ -363,7 +374,11 @@ if ($clients == "guests") $query_clienti = "select idclienti from $tableclienti
 if (!$query_clienti) $query_clienti = "select idclienti from $tableclienti where idclienti < '-3'";
 } # fine if ($clients and !$query_prenota)
 
-if (!$query_prenota and !$query_clienti) {
+if (strcmp($cashbox,"") and !$query_prenota and !$query_clienti) {
+$query_cassa = "select idcasse from $tablecasse where nome_cassa = '".aggslashdb($cashbox)."' ";
+} # fine if (strcmp($cashbox,"") and !$query_prenota and !$query_clienti)
+
+if (!$query_prenota and !$query_clienti and !$query_cassa) {
 if (!$res_year) $res_year = $anno;
 $primo_periodo = esegui_query("select idperiodi from $tableperiodi where datainizio = '$res_year-01-01' ");
 if (numlin_query($primo_periodo)) {
@@ -375,7 +390,7 @@ $query_prenota = "select idprenota from $tableprenota where iddatafine >= '$prim
 } # fine if (!$query_prenota and !$query_clienti)
 
 
-if ($query_prenota or $query_clienti) {
+if ($query_prenota or $query_clienti or $query_cassa) {
 $num_ripeti = 0;
 
 if ($query_prenota and ($priv_vedi_tab_prenotazioni != "n" or ($priv_vedi_tab_mesi != "n" and $priv_mod_prenotazioni != "n"))) {
@@ -390,10 +405,10 @@ $lista_prenota = array();
 for ($num1 = 1 ; $num1 <= $num_ripeti ; $num1++) $lista_prenota[$num1] = risul_query($prenotazioni,($num1 - 1),'idprenota');
 chiudi_query($prenotazioni);
 } # fine else if ($lista_prenota)
+$pcanc = "";
 include("./includes/dati_lista_prenota.php");
 } # fine if ($query_prenota and ($priv_vedi_tab_prenotazioni != "n" or...
 
-
 if ($query_clienti and $vedi_clienti != "NO") {
 $clienti = esegui_query($query_clienti);
 $num_ripeti = numlin_query($clienti);
@@ -403,6 +418,17 @@ chiudi_query($clienti);
 include("./includes/dati_lista_clienti.php");
 } # fine if ($query_clienti and $vedi_clienti != "NO")
 
+if ($query_cassa and $priv_vedi_tab_costi != "n") {
+$cassa = esegui_query($query_cassa);
+if (numlin_query($cassa)) $lista_cassa = risul_query($cassa,0,'idcasse');
+else $lista_cassa = 1;
+if ($attiva_casse_consentite == "n" or $casse_consentite_vett[$lista_cassa] == "SI") {
+$num_ripeti = 1;
+include("./includes/dati_lista_cassa.php");
+} # fine if ($attiva_casse_consentite == "n" or $casse_consentite_vett[$lista_cassa] == "SI")
+} # fine if ($query_cassa and $priv_vedi_tab_costi != "n")
+
+
 $mostra_headers = "SI";
 $messaggio_di_errore = "";
 $num_contr_esist = 0;
@@ -484,7 +510,7 @@ else include("./includes/foot.php");
 } # fine if ($mostra_headers == "SI")
 if ($foothtm) echo $foothtm;
 
-} # fine if ($query_prenota or $query_clienti)
+} # fine if ($query_prenota or $query_clienti or $query_cassa)
 
 $pag = $pag_orig;
 } # fine if ($anno_utente_attivato == "SI")
@@ -545,6 +571,12 @@ $num_lock++;
 } # fine for $num1
 for ($num1 = 0 ; $num1 < $num_anni ; $num1++) {
 if ($anni[$num1] >= $anno_corr) {
+$altre_tab_lock[$num_lock] = $PHPR_TAB_PRE."prenotacanc".$anni[$num1];
+$num_lock++;
+} # fine if ($anni[$num1] >= $anno_corr)
+} # fine for $num1
+for ($num1 = 0 ; $num1 < $num_anni ; $num1++) {
+if ($anni[$num1] >= $anno_corr) {
 $altre_tab_lock[$num_lock] = $PHPR_TAB_PRE."rclientiprenota".$anni[$num1];
 $num_lock++;
 } # fine if ($anni[$num1] >= $anno_corr)
@@ -681,8 +713,8 @@ echo "<cli_priv>$cli_priv</cli_priv>";
 } # fine if ($cli_id and $id_utente != 1)
 
 if ($cli_pass or $cli_presfut) {
-$idperiodocorrente = (calcola_id_periodo_corrente($anno_corr,"NO",$data_limite_passato) + 1);
-unset($cliente_attivo);
+$idperiodocorrente = (calcola_id_periodo_corrente($anno_corr,"NO",$data_limite_passato) - 1);
+$cliente_attivo = array();
 for ($num1 = 0 ; $num1 < $num_anni ; $num1++) {
 $anno_mostra = $anni[$num1];
 if ($anno_mostra >= $anno_corr) {
@@ -697,6 +729,16 @@ $idprenota = risul_query($prenota,$num2,'idprenota');
 $ospiti = esegui_query("select idclienti from $tablerclientiprenota_mostra where idprenota = '$idprenota' ");
 for ($num3 = 0 ; $num3 < numlin_query($ospiti) ; $num3++) $cliente_attivo[risul_query($ospiti,$num3,'idclienti')] = 1;
 } # fine for $num2
+$tableprenotacanc_mostra = $PHPR_TAB_PRE."prenotacanc".$anno_mostra;
+if ($anno_mostra == $anno_corr) $prenotacanc = esegui_query("select idprenota,idclienti from $tableprenotacanc_mostra where iddatafine > '".($idperiodocorrente - 2)."' ");
+else  $prenotacanc = esegui_query("select idprenota,idclienti from $tableprenotacanc_mostra");
+$num_prenotacanc = numlin_query($prenotacanc);
+for ($num2 = 0 ; $num2 < $num_prenotacanc ; $num2++) {
+$cliente_attivo[risul_query($prenotacanc,$num2,'idclienti')] = 1;
+$idprenota = risul_query($prenotacanc,$num2,'idprenota');
+$ospiti = esegui_query("select idclienti from $tablerclientiprenota_mostra where idprenota = '$idprenota' ");
+for ($num3 = 0 ; $num3 < numlin_query($ospiti) ; $num3++) $cliente_attivo[risul_query($ospiti,$num3,'idclienti')] = 1;
+} # fine for $num2
 } # fine ($anno_mostra >= $anno_corr)
 } # fine for $num1
 if ($cli_pass) {
@@ -761,6 +803,15 @@ break;
 closedir($interconn_dir);
 if ($funz_import_reservations) {
 
+$anno_esist = 1;
+# Se ci troviamo dopo il periodo di creazione dell'anno ma questo non è stato ancora creato
+if (!@is_file(C_DATI_PATH."/selectperiodi$anno.1.php")) {
+$anno_prec = $anno - 1;
+if (@is_file(C_DATI_PATH."/selectperiodi$anno_prec.1.php")) $anno = $anno_prec;
+else $anno_esist = 0;
+} # fine if (!@is_file(C_DATI_PATH."/selectperiodi$anno.1.php"))
+if ($anno_esist) {
+
 if (substr(C_URL_PULL_TOKEN,0,17) == "https://localhost") $token_res_id = file(C_URL_PULL_TOKEN."boo$token.php",false,stream_context_create(array("ssl" => array("verify_peer" => true,"allow_self_signed" => true))));
 else $token_res_id = @file(C_URL_PULL_TOKEN."boo$token.php");
 if (is_array($token_res_id)) $token_res_id = trim(implode("",$token_res_id));
@@ -793,6 +844,7 @@ $id_utente = $id_utente_origi;
 
 } # fine if (stristr($valore_xml,"<id>$token_res_id<"))
 
+} # fine if ($anno_esist)
 } # fine if ($funz_import_reservations)
 } # fine if (@is_array($ic_present))
 } # fine if (@is_file($file_interconnessioni))
