@@ -1234,3 +1234,17 @@ caselle[n2].title = fr_premere_per_modificare;
 } // fine function attiva_mod_prezzi_cella
 
 
+
+function selizona_opt_con_val (id_sel,val) {
+var sel_el = document.getElementById(id_sel);
+var opts = sel_el.options;
+for (var n1 = 0, lopts = opts.length; n1 < lopts; n1++) {
+if (opts[n1].value == val) {
+sel_el.selectedIndex = n1;
+return true;
+}
+}
+return false;
+} // fine function selizona_opt_con_val
+
+
