@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2018 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2019 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -61,6 +61,7 @@ $anno_utente_attivato = "SI";
 if ($priv_crea_backup == "s") {
 
 if ($mostra_header != "NO") {
+$titolo = "HotelDruid: ".mex("Backup",$pag);
 if ($tema[$id_utente] and $tema[$id_utente] != "base" and @is_dir("./themes/".$tema[$id_utente]."/php")) include("./themes/".$tema[$id_utente]."/php/head.php");
 else include("./includes/head.php");
 } # fine if ($mostra_header != "NO")
@@ -139,6 +140,10 @@ $altre_tab_lock[$num_lock] = $PHPR_TAB_PRE."prenota".risul_query($anni,$num1,'id
 $num_lock++;
 } # fine for $num1
 for ($num1 = 0 ; $num1 < $num_anni ; $num1++) {
+$altre_tab_lock[$num_lock] = $PHPR_TAB_PRE."prenotacanc".risul_query($anni,$num1,'idanni');
+$num_lock++;
+} # fine for $num1
+for ($num1 = 0 ; $num1 < $num_anni ; $num1++) {
 $altre_tab_lock[$num_lock] = $PHPR_TAB_PRE."rclientiprenota".risul_query($anni,$num1,'idanni');
 $num_lock++;
 } # fine for $num1
@@ -294,6 +299,7 @@ for ($num1 = 0 ; $num1 < $num_anni ; $num1++) {
 $anno_reg = risul_query($anni,$num1,'idanni');
 if (!$anni_backup or ${'anno_sel'.$anno_reg}) {
 dump_tabella("prenota$anno_reg",$file);
+dump_tabella("prenotacanc$anno_reg",$file);
 dump_tabella("costiprenota$anno_reg",$file);
 dump_tabella("rclientiprenota$anno_reg",$file);
 dump_tabella("periodi$anno_reg",$file);
@@ -874,7 +880,7 @@ if ($num1 != ($num_anni - 1)) echo "; ";
 } # fine for $num1
 echo "</div>";
 } # fine if ($num_anni > 1)
-echo "<label><input type=\"checkbox\" name=\"includi_modelli\" value=\"SI\" checked> ".mex("Includi i modelli internet",$pag)."</label>
+echo "<label><input type=\"checkbox\" name=\"includi_modelli\" value=\"SI\" checked> ".mex("Includi le pagine per il sito web",$pag)."</label>
 </td></tr></table></div></form>
 <table><tr><td style=\"height: 8px;\"></td></tr></table>";
 
