@@ -40,16 +40,12 @@ $id_utente = controlla_login($numconnessione,$PHPR_TAB_PRE,$id_sessione,$nome_ut
 if ($id_utente and $id_utente == 1) {
 
 
-$show_bar = "NO";
-if ($tema[$id_utente] and $tema[$id_utente] != "base" and @is_dir("./themes/".$tema[$id_utente]."/php")) include("./themes/".$tema[$id_utente]."/php/head.php");
-else include("./includes/head.php");
-
-
 function mex2 ($messaggio,$pagina,$lingua) {
 
-if ($lingua != "ita") {
+if (!$lingua) $lingua = "en";
+if ($lingua != "ita" and @is_file("./includes/lang/$lingua/$pagina")) {
 include("./includes/lang/$lingua/$pagina");
-} # fine if ($lingua != "ita")
+} # fine if ($lingua != "ita" and @is_file("./includes/lang/$lingua/$pagina"))
 elseif ($pagina == "unit.php") include("./includes/unit.php");
 
 return $messaggio;
@@ -57,6 +53,12 @@ return $messaggio;
 } # fine function mex2
 
 
+$show_bar = "NO";
+$titolo = "HotelDruid: ".mex2("Crea Database",$pag,$lingua);
+if ($tema[$id_utente] and $tema[$id_utente] != "base" and @is_dir("./themes/".$tema[$id_utente]."/php")) include("./themes/".$tema[$id_utente]."/php/head.php");
+else include("./includes/head.php");
+
+
 if (defined('C_UTILIZZA_SEMPRE_DEFAULTS') and C_UTILIZZA_SEMPRE_DEFAULTS == "AUTO") $creabase = 1;
 
 
@@ -87,7 +89,11 @@ $tempdatabase = C_CREADB_TEMPDB;
 $prefisso_tab = C_CREADB_PREFISSO_TAB;
 } # fine if (defined('C_UTILIZZA_SEMPRE_DEFAULTS') and (C_UTILIZZA_SEMPRE_DEFAULTS == "SI" or C_UTILIZZA_SEMPRE_DEFAULTS == "AUTO"))
 if (!controlla_num_pos($numletti) == "NO") $numletti = 0;
-if ((!$numappartamenti and !$numletti) or controlla_num_pos($numappartamenti) == "NO") $numappartamenti = 5;
+$numapp_default = 0;
+if ((!$numappartamenti and !$numletti) or controlla_num_pos($numappartamenti) == "NO") {
+$numappartamenti = 5;
+$numapp_default = 1;
+} # fine if ((!$numappartamenti and !$numletti) or controlla_num_pos($numappartamenti) == "NO")
 
 if (defined('C_EXT_DB_DATA_PATH') and C_EXT_DB_DATA_PATH) {
 $HOTELD_DB_TYPE = "";
@@ -144,6 +150,7 @@ if ($tipo_db == "sqlite") {
 if ($carica_estensione == "SI") dl("sqlite.so");
 $database_phprdb = str_replace("..","",$database_phprdb);
 $numconnessione = new SQLite3(C_DATI_PATH."/db_".$database_phprdb);
+$numconnessione->busyTimeout(60000);
 $database_esistente = "SI";
 } # fine if ($tipo_db == "sqlite")
 
@@ -186,6 +193,7 @@ if ($character_set_db != "utf8" or $collation_db != "utf8_general_ci") esegui_qu
 } # fine if ($tipo_db == "mysql" or $tipo_db == "mysqli")
 if ($tipo_db == "sqlite") {
 $numconnessione = new SQLite3(C_DATI_PATH."/db_".$database_phprdb);
+$numconnessione->busyTimeout(60000);
 } # fine if ($tipo_db == "sqlite")
 
 # creo la tabella appartamenti.
@@ -193,7 +201,7 @@ $tableappartamenti = $prefisso_tab."appartamenti";
 esegui_query("create table $tableappartamenti ( idappartamenti varchar(100) primary key, numpiano text, maxoccupanti integer, numcasa text, app_vicini text, priorita integer, priorita2 integer, letto varchar(1), commento text )");
 # creo la tabella clienti.
 $tableclienti = $prefisso_tab."clienti";
-esegui_query("create table $tableclienti (idclienti integer primary key, cognome varchar(70) not null, nome varchar(70), soprannome varchar(70), sesso char, titolo varchar(30), lingua varchar(14), datanascita date, cittanascita varchar(70), regionenascita varchar(70), nazionenascita varchar(70), documento varchar(70), scadenzadoc date, tipodoc varchar(70), cittadoc varchar(70), regionedoc varchar(70), nazionedoc  varchar(70), nazionalita varchar(70), nazione varchar(70), regione varchar(70), citta varchar(70), via varchar(70), numcivico varchar(30), cap varchar(30), telefono varchar(50), telefono2 varchar(50), telefono3 varchar(50), fax varchar(50), email text, cod_fiscale varchar(50), partita_iva varchar(50), commento text, max_num_ordine integer, idclienti_compagni text, doc_inviati text, datainserimento $DATETIME, hostinserimento varchar(50), utente_inserimento integer )");
+esegui_query("create table $tableclienti (idclienti integer primary key, cognome varchar(70) not null, nome varchar(70), soprannome varchar(70), sesso char, titolo varchar(30), lingua varchar(14), datanascita date, cittanascita varchar(70), regionenascita varchar(70), nazionenascita varchar(70), documento varchar(70), scadenzadoc date, tipodoc varchar(70), cittadoc varchar(70), regionedoc varchar(70), nazionedoc  varchar(70), nazionalita varchar(70), nazione varchar(70), regione varchar(70), citta varchar(70), via varchar(70), numcivico varchar(30), cap varchar(30), telefono varchar(50), telefono2 varchar(50), telefono3 varchar(50), fax varchar(50), email text, email2 text, email3 text, cod_fiscale varchar(50), partita_iva varchar(50), commento text, max_num_ordine integer, idclienti_compagni text, doc_inviati text, datainserimento $DATETIME, hostinserimento varchar(50), utente_inserimento integer )");
 # creo la tabella di relazione tra clienti e dati vari.
 $tablerelclienti = $prefisso_tab."relclienti";
 esegui_query("create table $tablerelclienti (idclienti integer, numero integer, tipo varchar(12), testo1 text, testo2 text, testo3 text, testo4 text, testo5 text, testo6 text, testo7 text, testo8 text, datainserimento $DATETIME, hostinserimento varchar(50), utente_inserimento integer )");
@@ -229,7 +237,7 @@ esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersona
 if (defined("C_MASCHERA_EMAIL") and C_MASCHERA_EMAIL == "SI") $maschera_email = "SI";
 else $maschera_email = "NO";
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('maschera_email','1','$maschera_email')");
-esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('dati_struttura','1','#@&#@&#@&#@&#@&#@&#@&#@&#@&#@&#@&')");
+esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('dati_struttura','1','#@&#@&#@&#@&#@&#@&#@&#@&#@&#@&#@&#@&')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('valuta','1','".aggslashdb(mex2("Euro",$pag,$lingua))."')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('arrotond_predef','1','1')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('arrotond_tasse','1','0.01')");
@@ -458,7 +466,10 @@ $zeri = (string) "0000000000000000000000000000";
 $lettere = (string) "abcdefghijklmnopqrstuvwxyz";
 $pos_lettera = 0;
 $num_dorm = $numappartamenti;
-if (!$numletti) $num_app_max = $numappartamenti;
+if (!$numletti) {
+if ($numapp_default) $num_app_max = "10";
+else $num_app_max = $numappartamenti;
+} # fine if (!$numletti)
 else $num_app_max = $numappartamenti + ceil((double) $numletti / 26);
 for ( $num = 1; $num <= ($numappartamenti + $numletti) ; $num = $num + 1) {
 $numapp = "numapp" . $num;
