@@ -24,6 +24,13 @@
 
 
 include_once("./includes/funzioni_costi_agg.php");
+if (!@is_array($altre_valute)) {
+$canc_altre_valute = 1;
+if ($tablepersonalizza and function_exists('altre_valute')) $altre_valute = altre_valute();
+else $altre_valute = array();
+} # fine if (!@is_array($altre_valute))
+else $canc_altre_valute = 0;
+if ($pcanc) $tableprenota = $tableprenotacanc;
 $tabelle_lock = "";
 $altre_tab_lock = array($tableanni,$tableprenota,$tablecostiprenota,$tableperiodi,$tableclienti,$tablerelclienti,$tablesoldi,$tableutenti);
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
@@ -88,6 +95,8 @@ if (strcmp(risul_query($dati_cliente,0,'telefono2'),"")) ${"telefono2_".$num_r}
 if (strcmp(risul_query($dati_cliente,0,'telefono3'),"")) ${"telefono3_".$num_r} = risul_query($dati_cliente,0,'telefono3');
 if (strcmp(risul_query($dati_cliente,0,'fax'),"")) ${"fax_".$num_r} = risul_query($dati_cliente,0,'fax');
 if (strcmp(risul_query($dati_cliente,0,'email'),"")) ${"email_".$num_r} = risul_query($dati_cliente,0,'email');
+if (strcmp(risul_query($dati_cliente,0,'email2'),"")) ${"email2_".$num_r} = risul_query($dati_cliente,0,'email2');
+if (strcmp(risul_query($dati_cliente,0,'email3'),"")) ${"email_certificata_".$num_r} = risul_query($dati_cliente,0,'email3');
 } # fine if ($priv_vedi_telefoni == "s")
 if (strcmp(risul_query($dati_cliente,0,'cod_fiscale'),"")) ${"codice_fiscale_".$num_r} = risul_query($dati_cliente,0,'cod_fiscale');
 if (strcmp(risul_query($dati_cliente,0,'partita_iva'),"")) ${"partita_iva_".$num_r} = risul_query($dati_cliente,0,'partita_iva');
@@ -116,6 +125,19 @@ ${"num_periodi_".$num_r} = $id_data_fine - $id_data_inizio + 1;
 $tariffa = risul_query($dati_prenota,0,'tariffa');
 $tariffa = explode("#@&",$tariffa);
 $costo_tariffa = (double) $tariffa[1];
+$valuta_tariffa = risul_query($dati_prenota,0,'valuta');
+if ($valuta_tariffa) {
+$valuta_tariffa = explode(">",$valuta_tariffa);
+$valuta_caparra = $valuta_tariffa[1];
+$valuta_tariffa = $valuta_tariffa[0];
+} # fine if ($d_valuta_tariffa)
+else $valuta_caparra = "";
+if ($valuta_tariffa) {
+$valuta_tariffa = explode("<",$valuta_tariffa);
+${"tasso_cambio_tariffa_".$num_r} = $valuta_tariffa[1];
+${"valuta_tariffa_".$num_r} = $valuta_tariffa[0];
+${"costo_valuta_tariffa_".$num_r} = converti_valuta($costo_tariffa,$valuta_tariffa[1],$valuta_tariffa[2]);
+} # fine if ($valuta_tariffa)
 $tariffesettimanali = risul_query($dati_prenota,0,'tariffesettimanali');
 ${"percentuale_tasse_tariffa_".$num_r} = 0;
 if ($priv_mod_tariffa != "n") {
@@ -125,7 +147,10 @@ ${"tariffesettimanali_".$num_r} = $tariffesettimanali;
 if (strcmp(risul_query($dati_prenota,0,'tasseperc'),"")) ${"percentuale_tasse_tariffa_".$num_r} = risul_query($dati_prenota,0,'tasseperc');
 } # fine if ($priv_mod_tariffa != "n")
 $sconto = (double) risul_query($dati_prenota,0,'sconto');
-if (strcmp($sconto,"") and $priv_mod_sconto != "n") ${"sconto_".$num_r} = $sconto;
+if (strcmp($sconto,"") and $priv_mod_sconto != "n") {
+${"sconto_".$num_r} = $sconto;
+if ($valuta_tariffa) ${"valore_valuta_sconto_".$num_r} = converti_valuta($sconto,$valuta_tariffa[1],$valuta_tariffa[2]);
+} # fine if (strcmp($sconto,"") and $priv_mod_sconto != "n")
 if (strcmp(risul_query($dati_prenota,0,'commento'),"")) ${"commento_".$num_r} = risul_query($dati_prenota,0,'commento');
 if (strstr(${"commento_".$num_r},">")) {
 $comm = explode(">",${"commento_".$num_r});
@@ -142,15 +167,22 @@ $caparra = risul_query($dati_prenota,0,'caparra');
 if ($priv_mod_caparra != "n") {
 if (strcmp($caparra,"")) ${"caparra_".$num_r} = $caparra;
 if (strcmp(risul_query($dati_prenota,0,'commissioni'),"")) ${"commissioni_".$num_r} = risul_query($dati_prenota,0,'commissioni');
+if ($valuta_caparra) {
+$valuta_caparra = explode("<",$valuta_caparra);
+${"tasso_cambio_caparra_".$num_r} = $valuta_caparra[1];
+${"valuta_caparra_".$num_r} = $valuta_caparra[0];
+${"valore_valuta_caparra_".$num_r} = converti_valuta($caparra,$valuta_caparra[1],$valuta_caparra[2]);
+} # fine if ($valuta_caparra)
+if (strcmp(risul_query($dati_prenota,0,'metodo_pagamento'),"")) ${"metodo_pagamento_caparra_".$num_r} = risul_query($dati_prenota,0,'metodo_pagamento');
 } # fine if ($priv_mod_caparra != "n")
 $numpersone = risul_query($dati_prenota,0,'num_persone');
 if (strcmp($numpersone,"")) ${"num_persone_".$num_r} = $numpersone;
-${"unita_occupata_".$num_r} = risul_query($dati_prenota,0,'idappartamenti');
 $cat_persone = dati_cat_pers_p($dati_prenota,0,$dati_cat_pers,$numpersone,$lingua_mex,0);
 for ($num2 = 0 ; $num2 < $dati_cat_pers['num'] ; $num2++) {
 if ($cat_persone[$num2]['esist']) ${"num_persone_tipo_".($num2 + 1)."_".$num_r} = $cat_persone[$cat_persone[$num2]['ncp']]['molt'];
 else ${"num_persone_tipo_".($num2 + 1)."_".$num_r} = 0;
 } # fine for $num2
+${"unita_occupata_".$num_r} = risul_query($dati_prenota,0,'idappartamenti');
 ${"unita_assegnabili_".$num_r} = risul_query($dati_prenota,0,'app_assegnabili');
 if ($priv_mod_pagato != "n" and $priv_mod_pagato != "i") ${"pagato_".$num_r} = risul_query($dati_prenota,0,'pagato');
 unset($num_letti_agg);
@@ -183,7 +215,15 @@ ${"utente_inserimento_costo_agg".$numca."_".$num_r} = $dati_cap[$numca]['utente_
 if ($priv_mod_costi_agg != "n") ${"num_costi_aggiuntivi_".$num_r} = $dati_cap['num'];
 else ${"num_costi_aggiuntivi_".$num_r} = 0;
 ${"n_letti_agg_".$num_r} = $num_letti_agg['max'];
-if ($priv_mod_pagato != "n" and $priv_mod_pagato != "i") ${"costo_tot_".$num_r} = $costo_tariffa + $costo_agg_tot - $sconto;
+if ($priv_mod_pagato != "n" and $priv_mod_pagato != "i") {
+${"costo_tot_".$num_r} = $costo_tariffa + $costo_agg_tot - $sconto;
+if ($valuta_tariffa) {
+$valuta_tariffa[3] = converti_valuta(($costo_tariffa - $sconto),$valuta_tariffa[1],$valuta_tariffa[2]);
+if (!strcmp($altre_valute['id'][$valuta_tariffa[0]],"")) $valuta_tariffa[4] = converti_valuta($costo_agg_tot,$valuta_tariffa[1],$valuta_tariffa[2]);
+else $valuta_tariffa[4] = converti_valuta($costo_agg_tot,$altre_valute[$altre_valute['id'][$valuta_tariffa[0]]]['cambio'],$altre_valute[$altre_valute['id'][$valuta_tariffa[0]]]['arrotond']);
+${"costo_valuta_tot_".$num_r} = round(($valuta_tariffa[3] + $valuta_tariffa[4]),2);
+} # fine if ($valuta_tariffa)
+} # fine if ($priv_mod_pagato != "n" and $priv_mod_pagato != "i")
 ${"orario_entrata_stimato_".$num_r} = risul_query($dati_prenota,0,'checkin');
 if (!${"orario_entrata_stimato_".$num_r}) ${"orario_entrata_stimato_".$num_r} = risul_query($dati_prenota,0,'checkout');
 else ${"orario_entrata_stimato_".$num_r} = "";
@@ -200,25 +240,39 @@ for ($num2 = 1 ; $num2 < (count($id_anni_prec_vett) - 1) ; $num2++) {
 $id_anno_prec = explode(",",$id_anni_prec_vett[$num2]);
 $anno_prec_esistente = esegui_query("select idanni from $tableanni where idanni = '".aggslashdb($id_anno_prec[0])."'");
 if (numlin_query($anno_prec_esistente)) {
-$pagamenti = esegui_query("select metodo_pagamento,saldo_prenota,data_inserimento,utente_inserimento from $PHPR_TAB_PRE"."soldi".$id_anno_prec[0]." where saldo_prenota is not NULL and motivazione $LIKE '%;".$id_anno_prec[1]."' order by data_inserimento");
+$pagamenti = esegui_query("select metodo_pagamento,saldo_prenota,valuta,data_inserimento,utente_inserimento from $PHPR_TAB_PRE"."soldi".$id_anno_prec[0]." where saldo_prenota is not NULL and motivazione $LIKE '%;".$id_anno_prec[1]."' order by data_inserimento");
 $num_pagamenti2 = numlin_query($pagamenti);
 for ($num3 = 0 ; $num3 < $num_pagamenti2 ; $num3++) {
 ${"data_paga".$num_pagamenti."_".$num_r} = substr(risul_query($pagamenti,$num3,'data_inserimento'),0,10);
 ${"utente_paga".$num_pagamenti."_".$num_r} = risul_query($pagamenti,$num3,'utente_inserimento');
 if (strcmp(risul_query($pagamenti,$num3,'metodo_pagamento'),"")) ${"metodo_paga".$num_pagamenti."_".$num_r} = risul_query($pagamenti,$num3,'metodo_pagamento');
 ${"saldo_paga".$num_pagamenti."_".$num_r} = risul_query($pagamenti,$num3,'saldo_prenota');
+$valuta_paga = risul_query($pagamenti,$num3,'valuta');
+if ($valuta_paga) {
+$valuta_paga = explode(">",$valuta_paga);
+${"valuta_paga".$num_pagamenti."_".$num_r} = $valuta_paga[0];
+${"tasso_cambio_paga".$num_pagamenti."_".$num_r} = $valuta_paga[1];
+${"valore_valuta_paga".$num_pagamenti."_".$num_r} = converti_valuta(${"saldo_paga".$num_pagamenti."_".$num_r},$valuta_paga[1],$valuta_paga[2]);
+} # fine if ($valuta_paga)
 $num_pagamenti++;
 } # fine for $num3
 } # fine (numlin_query($anno_prec_esistente))
 } # fine for $num2
 } # fine if (${"id_anni_prec_".$num_r})
-$pagamenti = esegui_query("select metodo_pagamento,saldo_prenota,data_inserimento,utente_inserimento from $tablesoldi where saldo_prenota is not NULL and motivazione $LIKE '%;$id_prenota' order by data_inserimento");
+$pagamenti = esegui_query("select metodo_pagamento,saldo_prenota,valuta,data_inserimento,utente_inserimento from $tablesoldi where saldo_prenota is not NULL and motivazione $LIKE '%;$id_prenota' order by data_inserimento");
 $num_pagamenti2 = numlin_query($pagamenti);
 for ($num2 = 0 ; $num2 < $num_pagamenti2 ; $num2++) {
 ${"data_paga".$num_pagamenti."_".$num_r} = substr(risul_query($pagamenti,$num2,'data_inserimento'),0,10);
 ${"utente_paga".$num_pagamenti."_".$num_r} = risul_query($pagamenti,$num2,'utente_inserimento');
 if (strcmp(risul_query($pagamenti,$num2,'metodo_pagamento'),"")) ${"metodo_paga".$num_pagamenti."_".$num_r} = risul_query($pagamenti,$num2,'metodo_pagamento');
 ${"saldo_paga".$num_pagamenti."_".$num_r} = risul_query($pagamenti,$num2,'saldo_prenota');
+$valuta_paga = risul_query($pagamenti,$num2,'valuta');
+if ($valuta_paga) {
+$valuta_paga = explode(">",$valuta_paga);
+${"valuta_paga".$num_pagamenti."_".$num_r} = $valuta_paga[0];
+${"tasso_cambio_paga".$num_pagamenti."_".$num_r} = $valuta_paga[1];
+${"valore_valuta_paga".$num_pagamenti."_".$num_r} = converti_valuta(${"saldo_paga".$num_pagamenti."_".$num_r},$valuta_paga[1],$valuta_paga[2]);
+} # fine if ($valuta_paga)
 $num_pagamenti++;
 } # fine for $num2
 ${"num_pagamenti_".$num_r} = $num_pagamenti;
@@ -231,12 +285,18 @@ chiudi_query($dati_prenota);
 
 unset($tariffa);
 unset($costo_tariffa);
+unset($valuta_tariffa);
 unset($tariffesettimanali);
 unset($sconto);
 unset($caparra);
+unset($valuta_caparra);
 unset($costo_agg_tot);
 unset($costo_agg_parziale);
 unset($utente_inserimento);
+unset($valuta_paga);
+unset($num_pagamenti);
+if ($canc_altre_valute) unset($altre_valute);
+unset($canc_altre_valute);
 
 $lista_prenota = $lista_p;
 $num_ripeti = $num_r;
