@@ -53,18 +53,21 @@ $tablepersonalizza = $PHPR_TAB_PRE."personalizza";
 
 #@include("./includes/costanti.php");
 #@include(C_DATI_PATH."/costanti.php");
-define('C_PHPR_VERSIONE_NUM',2.32);
-define('C_PHPR_VERSIONE_TXT',"2.3.2");
+define('C_PHPR_VERSIONE_NUM',3.00);
+define('C_PHPR_VERSIONE_TXT',"3.0.0");
 
 if (!function_exists('utf8_encode')) {
 function utf8_encode ($testo) { return ($testo); }
 function utf8_decode ($testo) { return ($testo); }
 } # fine if (!function_exists('utf8_encode'))
+if (!function_exists('get_magic_quotes_gpc')) {
+function get_magic_quotes_gpc () { return 0; }
+} # fine if (!function_exists('get_magic_quotes_gpc'))
 
 $id_sessione = htmlspecialchars($id_sessione);
 
 # Se non si specifica nessun anno uso l'attuale
-if (@is_file(C_DATI_PATH."/versione.php")) include_once(C_DATI_PATH."/versione.php");
+if (@is_file(C_DATI_PATH."/versione.php") and !defined('C_DIFF_ORE')) include(C_DATI_PATH."/versione.php");
 elseif (!defined('C_DIFF_ORE')) define('C_DIFF_ORE',0);
 $anno_corrente = date("Y",(time() + (C_DIFF_ORE * 3600)));
 if (!$anno) {
@@ -194,6 +197,28 @@ return $nome_valuta;
 
 
 
+function altre_valute ($id_utente_valuta = "") {
+
+$altre_valute = array();
+global $tablepersonalizza;
+if ($id_utente_valuta) $id_utente = $id_utente_valuta;
+else global $id_utente;
+$valute = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'valuta2' and idutente = '$id_utente' order by valpersonalizza ");
+$altre_valute['num'] = numlin_query($valute);
+for ($num1 = 0 ; $num1 < $altre_valute['num'] ; $num1++) {
+$nome = explode(">",risul_query($valute,$num1,'valpersonalizza'));
+$altre_valute[$num1]['nome'] = $nome[0];
+$altre_valute[$num1]['cambio'] = $nome[1];
+$altre_valute[$num1]['arrotond'] = $nome[2];
+$altre_valute['id'][$nome[0]] = $num1;
+} # fine for $num1
+
+return $altre_valute;
+
+} # fine function altre_valute
+
+
+
 function stile_data ($id_utente_st = "") {
 
 global $tablepersonalizza;
@@ -295,19 +320,27 @@ return $verificato;
 
 function formatta_soldi ($num) {
 
+if (strcmp($num,"")) {
 $num = str_replace(",",".",$num);
+if (strstr($num,".")) {
 $parti = explode(".",$num);
-if (count($parti) == 2) {
 if ($parti[1]) {
 if (strlen($parti[1]) > 2) {
 $parti[1] = substr($parti[1],0,2).".".substr($parti[1],2);
-$parti[1] = round($parti[1]);
+$parti[1] = round((double) $parti[1]);
+if (strlen($parti[1]) == 1) $parti[1] = "0".$parti[1];
+elseif ((int) $parti[1] == 100) {
+$parti[0] = (int) $parti[0] + 1;
+$parti[1] = "00";
+} # fine elseif ((int) $parti[1] == 100)
 } # fine if (strlen($parti[1]) > 2)
 $num = $parti[0].".".$parti[1];
-settype ($num,'double');
+settype($num,'double');
 } # fine if ($parti[1])
 else $num = (int) $parti[0];
-} # fine if (count($parti) == 2)
+} # fine if (strstr($num,"."))
+else $num = (int) $num;
+} # fine if (strcmp($num,""))
 
 return $num;
 
@@ -375,7 +408,8 @@ $id_utente = "";
 
 function controlla_login (&$numconnessione,&$PHPR_TAB_PRE,&$id_sessione,$nome_utente_phpr,$password_phpr,$anno) {
 
-if (defined("C_FILE_SCADENZA_ACCOUNT") and C_FILE_SCADENZA_ACCOUNT != "") {
+$avviso_giorni_scadenza = 0;
+if (defined('C_FILE_SCADENZA_ACCOUNT') and C_FILE_SCADENZA_ACCOUNT != "") {
 $scadenza = trim(@implode("",@file("./".C_FILE_SCADENZA_ACCOUNT)));
 $adesso = date("YmdHis");
 if (!$scadenza or $scadenza < $adesso) {
@@ -384,6 +418,11 @@ if (defined("C_HTML_PRE_LOGIN") and C_HTML_PRE_LOGIN != "") echo C_HTML_PRE_LOGI
 echo "Expired account.<br>";
 if (defined("C_HTML_POST_LOGIN") and C_HTML_POST_LOGIN != "") echo C_HTML_POST_LOGIN;
 } # fine (!$scadenza or $scadenza < $adesso)
+elseif (defined('C_HTML_POST_LOGIN') and C_HTML_POST_LOGIN != "") {
+$giorni_avviso = 3;
+$limite_giorni_avviso = date("YmdHis",(time() + ($giorni_avviso * 86400)));
+if ($scadenza < $limite_giorni_avviso) $avviso_giorni_scadenza = 1;
+} # fine elseif (defined('C_HTML_POST_LOGIN') and C_HTML_POST_LOGIN != "")
 } # fine (defined("C_FILE_SCADENZA_ACCOUNT") and C_FILE_SCADENZA_ACCOUNT != "")
 if (!$disattivato) {
 
@@ -409,8 +448,6 @@ include(C_DATI_PATH."/dati_connessione.php");
 include("./includes/funzioni_$PHPR_DB_TYPE.php");
 $numconnessione = connetti_db($PHPR_DB_NAME,$PHPR_DB_HOST,$PHPR_DB_PORT,$PHPR_DB_USER,$PHPR_DB_PASS,$PHPR_LOAD_EXT);
 } # fine if (!$numconnessione)
-$nome_utente_phpr = aggslashdb($nome_utente_phpr);
-$password_phpr = aggslashdb($password_phpr);
 $tableutenti = $PHPR_TAB_PRE."utenti";
 $tablesessioni = $PHPR_TAB_PRE."sessioni";
 $tableversioni = $PHPR_TAB_PRE."versioni";
@@ -422,7 +459,7 @@ $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
 
 $sec_log_sbagliati = 5;
 $limite_login_sbagliati = date("Y-m-d H:i:s",(time() - $sec_log_sbagliati + (C_DIFF_ORE * 3600)));
-$ultimo_login_sbagliato = esegui_query("select ultimo_accesso from $tabletransazioni where tipo_transazione = 'err_l' and dati_transazione1 = '$nome_utente_phpr' and ultimo_accesso >= '$limite_login_sbagliati'");
+$ultimo_login_sbagliato = esegui_query("select ultimo_accesso from $tabletransazioni where tipo_transazione = 'err_l' and dati_transazione1 = '".aggslashdb($nome_utente_phpr)."' and ultimo_accesso >= '$limite_login_sbagliati'");
 if (numlin_query($ultimo_login_sbagliato) > 0) {
 $mostra_form_login = "SI";
 $messaggio_errore .= mex("Dopo un login <div style=\"display: inline; color: red;\">errato</div> si devono attendere","funzioni.php")." $sec_log_sbagliati ".mex("secondi","funzioni.php").".<br><br>";
@@ -434,7 +471,7 @@ $minuti_durata_sessione = esegui_query("select valpersonalizza_num from $tablepe
 $minuti_durata_sessione = risul_query($minuti_durata_sessione,0,'valpersonalizza_num');
 $limite_transazioni_vecchie = date("Y-m-d H:i:s",(time() - ($minuti_durata_sessione * 60) + (C_DIFF_ORE * 3600)));
 esegui_query("delete from $tabletransazioni where ultimo_accesso <= '$limite_transazioni_vecchie'");
-$login_sbagliati = esegui_query("select tipo_transazione from $tabletransazioni where tipo_transazione = 'err_l' and dati_transazione1 = '$nome_utente_phpr' ");
+$login_sbagliati = esegui_query("select tipo_transazione from $tabletransazioni where tipo_transazione = 'err_l' and dati_transazione1 = '".aggslashdb($nome_utente_phpr)."' ");
 $login_sbagliati = numlin_query($login_sbagliati);
 if ($login_sbagliati >= $num_log_sbagliati) {
 $messaggio_errore .= mex("Numero eccesivo di login <div style=\"display: inline; color: red;\">errati</div> negli ultimi","funzioni.php")." $minuti_durata_sessione ".mex("minuti","funzioni.php").".<br><br>";
@@ -442,11 +479,31 @@ if (defined("C_HTML_POST_LOGIN") and C_HTML_POST_LOGIN != "") $messaggio_errore
 } # fine if ($login_sbagliati >= $num_log_sbagliati)
 else {
 if ($pag != "inizio.php" and !@is_file(C_DATI_PATH."/selectperiodi$anno.1.php")) {
+if ($_SERVER['REQUEST_METHOD'] == "GET") {
+echo "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN\"
+        \"http://www.w3.org/TR/html4/strict.dtd\">
+<html>
+<head>
+<meta http-equiv=\"Content-Type\" content=\"text/html;charset=utf-8\" >
+<meta http-equiv=\"refresh\" content=\"0; url=inizio.php?nome_utente_phpr=".urlencode($nome_utente_phpr)."&password_phpr=".urlencode($password_phpr)."\">
+<title> Hoteldruid </title>
+</head>
+<body style=\"background-color: #ffffff;\">
+<div>&nbsp;</div>
+</body>
+</html>
+";
+exit();
+} # fine if ($_SERVER['REQUEST_METHOD'] == "GET")
+else {
 $mostra_form_login = "SI";
 $pag = "inizio.php";
+} # fine else if ($_SERVER['REQUEST_METHOD'] == "GET")
 } # fine if ($pag != "inizio.php" and !@is_file(C_DATI_PATH."/selectperiodi$anno.1.php"))
 else {
 
+$nome_utente_phpr = aggslashdb($nome_utente_phpr);
+$password_phpr = aggslashdb($password_phpr);
 $utente = esegui_query("select * from $tableutenti where nome_utente = '$nome_utente_phpr'");
 if (numlin_query($utente) == 1) {
 $nome_utente_login = risul_query($utente,0,'nome_utente');
@@ -567,6 +624,12 @@ $messaggio_errore .= "".mex("Sessione <div style=\"display: inline; color: red;\
 if ($messaggio_errore or $mostra_form_login == "SI") {
 if ($pag == "aggiorna.php") $action = "aggiorna.php";
 else {
+if (!$_SERVER['HTTP_REFERER'] or !$_SERVER['SERVER_NAME']) $pag = "";
+else {
+if (($_SERVER['HTTPS'] and $_SERVER['HTTPS'] != 'off') or $_SERVER['SERVER_PORT'] == "443") $url_dom = "https://".$_SERVER['SERVER_NAME']."/";
+else $url_dom = "http://".$_SERVER['SERVER_NAME']."/";
+if (substr($_SERVER['HTTP_REFERER'],0,strlen($url_dom)) != $url_dom) $pag = "";
+} # fine else if (!$_SERVER['HTTP_REFERER'] or !$_SERVER['SERVER_NAME'])
 if ((@is_array($_POST) or @is_array($_GET)) and $pag) {
 $action = $pag;
 if (@is_array($_POST)) {
@@ -613,7 +676,13 @@ $input_var_passate
 <table><tr><td style=\"height: 2px;\"></td></tr></table>
 <button class=\"login\" type=\"submit\"><div>".mex("Entra","funzioni.php")."</div></button>
 </div></form>";
-if (defined("C_HTML_POST_LOGIN") and C_HTML_POST_LOGIN != "") echo C_HTML_POST_LOGIN;
+if (defined("C_HTML_POST_LOGIN") and C_HTML_POST_LOGIN != "") {
+echo C_HTML_POST_LOGIN;
+if ($avviso_giorni_scadenza) {
+$scadenza_vedi = "<span class=\"colred\">".substr($scadenza,0,4)."-".substr($scadenza,4,2)."-".substr($scadenza,6,2)." ".substr($scadenza,8,2).":".substr($scadenza,10,2)."</span> ".mex("orario del server","funzioni.php");
+echo "<br><span class=\"colred\">".mex("Avviso","funzioni.php")."</span>:".mex("Mancano meno di","funzioni.php")." $giorni_avviso ".mex("giorni alla scadenza dell'account","funzioni.php")." ($scadenza_vedi).<br>";
+} # fine if ($avviso_giorni_scadenza)
+} # fine if (defined("C_HTML_POST_LOGIN") and C_HTML_POST_LOGIN != "")
 } # fine if ($mostra_form_login == "SI")
 if ($messaggio_errore or $mostra_form_login == "SI") {
 
