@@ -96,8 +96,10 @@ return substr($tutte_col,0,-1);
 
 # Creo la tabella delle prernotazioni
 $tableprenotazioni = $PHPR_TAB_PRE."prenota".$anno;
-$col_tableprenota = "idprenota integer primary key, idclienti integer, idappartamenti varchar(100), iddatainizio integer, iddatafine integer, assegnazioneapp varchar(4), app_assegnabili text, num_persone integer, cat_persone text, idprenota_compagna text, tariffa text, tariffesettimanali text, incompatibilita text, sconto float8, tariffa_tot float8, caparra float8, commissioni float8, tasseperc float4, pagato float8, metodo_pagamento text, codice varchar(10), origine varchar(70), commento text, conferma varchar(4), checkin $DATETIME, checkout $DATETIME, id_anni_prec text, datainserimento $DATETIME, hostinserimento varchar(50), data_modifica $DATETIME, utente_inserimento integer ";
+$col_tableprenota = "idprenota integer primary key, idclienti integer, idappartamenti varchar(100), iddatainizio integer, iddatafine integer, assegnazioneapp varchar(4), app_assegnabili text, num_persone integer, cat_persone text, idprenota_compagna text, tariffa text, tariffesettimanali text, incompatibilita text, sconto float8, tariffa_tot float8, caparra float8, commissioni float8, tasseperc float4, pagato float8, valuta text, metodo_pagamento text, codice varchar(10), origine varchar(70), commento text, conferma varchar(4), checkin $DATETIME, checkout $DATETIME, id_anni_prec text, datainserimento $DATETIME, hostinserimento varchar(50), data_modifica $DATETIME, utente_inserimento integer ";
 esegui_query("create table $tableprenotazioni ($col_tableprenota)");
+$tableprenotazionicanc = $PHPR_TAB_PRE."prenotacanc".$anno;
+esegui_query("create table $tableprenotazionicanc ($col_tableprenota)");
 $col_tableprenota = estrai_col_tabella($col_tableprenota);
 
 # Creo la tabella con i costi aggiuntivi delle prenotazioni
@@ -123,13 +125,13 @@ $col_tableregole = estrai_col_tabella($col_tableregole);
 
 # Creo la tabella con i costi di gestione
 $tablecosti = $PHPR_TAB_PRE."costi".$anno;
-$col_tablecosti = "idcosti integer unique,nome_costo text, val_costo float8, tipo_costo text, nome_cassa varchar(70), persona_costo text, provenienza_costo text, metodo_pagamento text, datainserimento $DATETIME, hostinserimento varchar(50), utente_inserimento integer";
+$col_tablecosti = "idcosti integer unique,nome_costo text, val_costo float8, tipo_costo text, valuta text, costo_valuta float8, nome_cassa varchar(70), persona_costo text, provenienza_costo text, metodo_pagamento text, datainserimento $DATETIME, hostinserimento varchar(50), utente_inserimento integer";
 esegui_query("create table $tablecosti ($col_tablecosti)");
 $col_tablecosti = estrai_col_tabella($col_tablecosti);
 
 # Creo la tabella per la storia entrate-uscite
 $tablesoldi = $PHPR_TAB_PRE."soldi".$anno;
-$col_tablesoldi = "idsoldi integer unique, motivazione text, id_pagamento text, metodo_pagamento text, saldo_prenota float8, saldo_cassa float8, soldi_prima float8, data_inserimento $DATETIME, utente_inserimento integer";
+$col_tablesoldi = "idsoldi integer unique, motivazione text, id_pagamento text, metodo_pagamento text, saldo_prenota float8, saldo_cassa float8, soldi_prima float8, valuta text, saldo_valuta float8, data_inserimento $DATETIME, utente_inserimento integer";
 esegui_query("create table $tablesoldi ($col_tablesoldi)");
 $col_tablesoldi = estrai_col_tabella($col_tablesoldi);
 
@@ -138,13 +140,14 @@ if ($importa_anno_prec == "SI") {
 $anno_prec = $anno - 1;
 $tablenometariffe_prec = $PHPR_TAB_PRE."ntariffe".$anno_prec;
 $tableprenota_prec = $PHPR_TAB_PRE."prenota".$anno_prec;
+$tableprenotacanc_prec = $PHPR_TAB_PRE."prenotacanc".$anno_prec;
 $tablecostiprenota_prec = $PHPR_TAB_PRE."costiprenota".$anno_prec;
 $tablerclientiprenota_prec = $PHPR_TAB_PRE."rclientiprenota".$anno_prec;
 $tableperiodi_prec = $PHPR_TAB_PRE."periodi".$anno_prec;
 $tableregole_prec = $PHPR_TAB_PRE."regole".$anno_prec;
 $tablesoldi_prec = $PHPR_TAB_PRE."soldi".$anno_prec;
 $tablecosti_prec = $PHPR_TAB_PRE."costi".$anno_prec;
-$tabelle_lock = array($tableanni,$tableprenota_prec,$tableprenotazioni,$tablecostiprenota_prec,$tablecostiprenota,$tablerclientiprenota_prec,$tablerclientiprenota,$tablenometariffe,$tableperiodi,$tablerelclienti,$tablecosti_prec,$tablecosti,$tableregole,$tablesoldi_prec,$tablesoldi,$tableinterconnessioni,$tablemessaggi,$tablepersonalizza,$tableprivilegi,$tabletransazioni);
+$tabelle_lock = array($tableanni,$tableprenota_prec,$tableprenotazioni,$tableprenotacanc_prec,$tableprenotazionicanc,$tablecostiprenota_prec,$tablecostiprenota,$tablerclientiprenota_prec,$tablerclientiprenota,$tablenometariffe,$tableperiodi,$tablerelclienti,$tablecosti_prec,$tablecosti,$tableregole,$tablesoldi_prec,$tablesoldi,$tableinterconnessioni,$tablemessaggi,$tablepersonalizza,$tableprivilegi,$tabletransazioni);
 $altre_tab_lock = array($tablenometariffe_prec,$tableperiodi_prec,$tableregole_prec,$tablecontratti,$tableutenti);
 $max_data_ini_prec = esegui_query("select max(datainizio) from $tableperiodi_prec");
 if (numlin_query($max_data_ini_prec) != 0) {
@@ -314,6 +317,7 @@ $lista_clienti_importati = "";
 # Importo eventuali prenotazioni, tariffe e regole dell'anno precedente
 if ($importa_anno_prec == "SI") {
 $tableprenota = $tableprenotazioni;
+$tableprenotacanc = $tableprenotazionicanc;
 $data_inizio_periodi = esegui_query("select * from $tableperiodi where idperiodi = 1");
 $data_inizio_periodi = risul_query($data_inizio_periodi,0,'datainizio');
 $ini_periodo_interferenza =  esegui_query("select * from $tableperiodi_prec where datainizio = '$data_inizio_periodi'");
@@ -340,12 +344,14 @@ if ($num_prenota_non_importabili != 0) echo "<br>ERROR<br>";
 } # fine if ($num_periodi_prec > $id_data_fine_periodi)
 
 $idprenota_corr = 0;
+$nuovo_idprenota_iniziata = array();
 $max_idprenota_prec = esegui_query("select max(idprenota) from $tableprenota_prec");
 $max_idprenota_prec = risul_query($max_idprenota_prec,0,0) + 1;
 $max_idcostiprenota_prec = esegui_query("select max(idcostiprenota) from $tablecostiprenota_prec");
 $max_idcostiprenota_prec = risul_query($max_idcostiprenota_prec,0,0) + 1;
 $prenota_gia_iniziate = esegui_query("select * from $tableprenota_prec where iddatainizio < $id_data_ini_periodi_prec and iddatafine >= $id_data_ini_periodi_prec and iddatafine <= $id_data_fine_periodi_prec ");
 $num_prenota_gia_iniziate = numlin_query($prenota_gia_iniziate);
+
 for ($num1 = 0 ; $num1 < $num_prenota_gia_iniziate ; $num1 = $num1 + 1) {
 $idprenota = risul_query($prenota_gia_iniziate,$num1,'idprenota');
 $idclienti = risul_query($prenota_gia_iniziate,$num1,'idclienti');
@@ -372,10 +378,12 @@ esegui_query("update $tablerclientiprenota_prec set idprenota = '$max_idprenota_
 esegui_query("insert into $tablerclientiprenota select $col_tablerclientiprenota from $tablerclientiprenota_prec where idprenota = '$max_idprenota_prec' ");
 esegui_query("update $tablerclientiprenota set idprenota = '$idprenota_corr' where idprenota = '$max_idprenota_prec'");
 esegui_query("update $tablerclientiprenota_prec set idprenota = '$idprenota' where idprenota = '$max_idprenota_prec'");
+$nuovo_idprenota_iniziata[$idprenota] = $idprenota_corr;
 } # fine for $num1
-$nuovo_idprenota = "";
-$nuovo_iddatainizio = "";
-$nuovo_iddatafine = "";
+
+$nuovo_idprenota = array();
+$nuovo_iddatainizio = array();
+$nuovo_iddatafine = array();
 $prenota_importate = esegui_query("select * from $tableprenota_prec where iddatainizio >= '$id_data_ini_periodi_prec' and iddatafine <= '$id_data_fine_periodi_prec' order by idprenota ");
 $num_prenota_importate = numlin_query($prenota_importate);
 for ($num1 = 0 ; $num1 < $num_prenota_importate ; $num1 = $num1 + 1) {
@@ -410,6 +418,42 @@ $nuovo_idprenota[$idprenota] = $idprenota_corr;
 $nuovo_iddatainizio[$idprenota] = $iddatainizio;
 $nuovo_iddatafine[$idprenota] = $iddatafine;
 } # fine for $num1
+
+$prenotacanc_importate = esegui_query("select * from $tableprenotacanc_prec where iddatainizio >= '$id_data_ini_periodi_prec' and iddatafine <= '$id_data_fine_periodi_prec' order by idprenota ");
+$num_prenotacanc_importate = numlin_query($prenotacanc_importate);
+for ($num1 = 0 ; $num1 < $num_prenotacanc_importate ; $num1 = $num1 + 1) {
+$idprenota = risul_query($prenotacanc_importate,$num1,'idprenota');
+$iddatainizio = risul_query($prenotacanc_importate,$num1,'iddatainizio');
+$iddatainizio = $iddatainizio - $id_data_ini_periodi_prec + 1;
+$iddatafine = risul_query($prenotacanc_importate,$num1,'iddatafine');
+$iddatafine = $iddatafine - $id_data_ini_periodi_prec + 1;
+$idclienti = risul_query($prenotacanc_importate,$num1,'idclienti');
+$lista_clienti_importati .= "and idclienti != '$idclienti' ";
+$id_anni_prec = risul_query($prenotacanc_importate,$num1,'id_anni_prec');
+if (!$id_anni_prec) $id_anni_prec = ";";
+$id_anni_prec .= "$anno_prec,$idprenota;";
+$idprenota_corr++;
+esegui_query("update $tableprenotacanc_prec set idprenota = '$max_idprenota_prec' where idprenota = '$idprenota'");
+esegui_query("insert into $tableprenotacanc select $col_tableprenota from $tableprenotacanc_prec where idprenota = '$max_idprenota_prec' ");
+esegui_query("update $tableprenotacanc set iddatainizio = '$iddatainizio' where idprenota = '$max_idprenota_prec'");
+esegui_query("update $tableprenotacanc set iddatafine = '$iddatafine' where idprenota = '$max_idprenota_prec'");
+esegui_query("update $tableprenotacanc set id_anni_prec = '$id_anni_prec' where idprenota = '$max_idprenota_prec'");
+esegui_query("update $tableprenotacanc set idprenota = '$idprenota_corr' where idprenota = '$max_idprenota_prec'");
+esegui_query("delete from $tableprenotacanc_prec where idprenota = '$max_idprenota_prec'");
+esegui_query("update $tablecostiprenota_prec set idprenota = '$max_idprenota_prec' where idprenota = '$idprenota'");
+esegui_query("insert into $tablecostiprenota select $col_tablecostiprenota from $tablecostiprenota_prec where idprenota = '$max_idprenota_prec' ");
+esegui_query("update $tablecostiprenota set idprenota = '$idprenota_corr' where idprenota = '$max_idprenota_prec'");
+esegui_query("delete from $tablecostiprenota_prec where idprenota = '$max_idprenota_prec'");
+esegui_query("update $tablerclientiprenota_prec set idprenota = '$max_idprenota_prec' where idprenota = '$idprenota'");
+esegui_query("insert into $tablerclientiprenota select $col_tablerclientiprenota from $tablerclientiprenota_prec where idprenota = '$max_idprenota_prec' ");
+esegui_query("update $tablerclientiprenota set idprenota = '$idprenota_corr' where idprenota = '$max_idprenota_prec'");
+esegui_query("delete from $tablerclientiprenota_prec where idprenota = '$max_idprenota_prec'");
+esegui_query("update $tableinterconnessioni set idlocale = '$idprenota_corr', anno = '$anno' where idlocale = '$idprenota' and ( tipoid = 'prenota' or tipoid = 'mess' ) and anno = '$anno_prec' ");
+$nuovo_idprenota[$idprenota] = $idprenota_corr;
+$nuovo_iddatainizio[$idprenota] = $iddatainizio;
+$nuovo_iddatafine[$idprenota] = $iddatafine;
+} # fine for $num1
+
 esegui_query("update $tablecostiprenota set numlimite = '".($idprenota_corr + 1)."' where idcostiprenota = '1'");
 $prenota_compagne = esegui_query("select idprenota,idprenota_compagna from $tableprenota where idprenota_compagna != '' ");
 $num_prenota_compagne = numlin_query($prenota_compagne);
@@ -542,8 +586,8 @@ if ($num_dirs_salva) {
 unset($contr_salva_in);
 $max_contr = esegui_query("select max(numero) from $tablecontratti where tipo $LIKE 'contr%'");
 $max_contr = risul_query($max_contr,0,0);
-if (defined("C_CARTELLA_CREA_MODELLI") and C_CARTELLA_CREA_MODELLI != "") {
-if (C_CARTELLA_DOC != "" and @is_dir(C_CARTELLA_CREA_MODELLI."/".C_CARTELLA_DOC)) $dir_salva_home = C_CARTELLA_DOC;
+if (defined('C_CARTELLA_CREA_MODELLI') and C_CARTELLA_CREA_MODELLI != "") {
+if (defined('C_CARTELLA_DOC') and C_CARTELLA_DOC != "" and @is_dir(C_CARTELLA_CREA_MODELLI."/".C_CARTELLA_DOC)) $dir_salva_home = C_CARTELLA_DOC;
 else $dir_salva_home = "";
 } # fine if (defined("C_CARTELLA_CREA_MODELLI") and C_CARTELLA_CREA_MODELLI != "")
 else $dir_salva_home = C_DATI_PATH;
@@ -563,62 +607,92 @@ $dati_nome_contratto = explode("#?&",$nomi_contratti[$num2]);
 $nomi_contr_ut[$idutente_contr][$dati_nome_contratto[0]] = $dati_nome_contratto[1];
 } # fine for $num2
 } # fine for $num1
-unset($prefissi_contr);
+$prefissi_contr = array();
 for ($num1 = 0 ; $num1 < $num_dirs_salva ; $num1++) {
 $dir_salva = risul_query($dirs_salva,$num1,'testo');
 if ($dir_salva == "~") $dir_salva = $dir_salva_home;
 if (defined('C_CARTELLA_CREA_MODELLI') and C_CARTELLA_CREA_MODELLI != "") $dir_salva = C_CARTELLA_CREA_MODELLI."/".str_replace("..","",$dir_salva);
 if (@is_dir($dir_salva)) {
-$num_contr = risul_query($dirs_salva,0,'numero');
-$tipo_contratto = esegui_query("select tipo from ".$PHPR_TAB_PRE."contratti where numero = '$num_contr' and tipo $LIKE 'contr%' ");
+$num_contr = risul_query($dirs_salva,$num1,'numero');
+/*$tipo_contratto = esegui_query("select tipo from ".$PHPR_TAB_PRE."contratti where numero = '$num_contr' and tipo $LIKE 'contr%' ");
 $tipo_contratto = risul_query($tipo_contratto,0,'tipo');
+$compress = esegui_query("select testo from ".$PHPR_TAB_PRE."contratti where numero = '$num_contr' and tipo = 'compress' ");
+if (numlin_query($compress)) $compress = risul_query($compress,0,'testo');
+else $compress = "";
 $suff_file = "html";
 if ($tipo_contratto == "contrrtf") $suff_file = "rtf";
 if ($tipo_contratto == "contrtxt") $suff_file = "txt";
+if ($compress) $suff_file .= ".gz";*/
+$nomefile = esegui_query("select testo from ".$PHPR_TAB_PRE."contratti where numero = '$num_contr' and tipo = 'nomefile' ");
+if (numlin_query($nomefile)) $nomefile = risul_query($nomefile,0,'testo');
+else $nomefile = "";
 $filelock_contr = fopen($dir_salva."/crea_contr.lock","w+");
 flock($filelock_contr,2);
 for ($num2 = 0 ; $num2 < $num_utenti ; $num2++) {
 $idutente_contr = risul_query($utenti,$num2,'idutenti');
-if (!$prefissi_contr[$dir_salva."/".$nomi_contr_ut[$idutente_contr][$num_contr]]) {
-$nome_contratto = $nomi_contr_ut[$idutente_contr][$num_contr];
+if ($nomefile) $nome_contratto = $nomefile;
+else $nome_contratto = $nomi_contr_ut[$idutente_contr][$num_contr];
+if (!$prefissi_contr[$dir_salva."/".$nome_contratto]) {
 $prefissi_contr[$dir_salva."/".$nome_contratto] = 1;
 $contr_dir = opendir($dir_salva."/");
 while ($contr_corr = readdir($contr_dir)) {
 if ($contr_corr != "." and $contr_corr != ".." and is_file($dir_salva."/".$contr_corr)) {
 if (substr($contr_corr,0,strlen($nome_contratto)) == $nome_contratto) {
+$suff_file = "";
+$suff_compr = "";
+if (substr($contr_corr,-3) == ".gz") {
+$contr_no_compr = substr($contr_corr,0,-3);
+$suff_compr = ".gz";
+} # fine if (substr($contr_corr,-3) == ".gz")
+else $contr_no_compr = $contr_corr;
+if (substr($contr_no_compr,-4) == ".rtf") $suff_file = "rtf".$suff_compr;
+if (substr($contr_no_compr,-5) == ".html") $suff_file = "html".$suff_compr;
+if (substr($contr_no_compr,-4) == ".txt") $suff_file = "txt".$suff_compr;
+if ($suff_file) {
 $resto_nome_contr = substr($contr_corr,strlen($nome_contratto));
 if (substr($resto_nome_contr,0,6) == "_$anno"."_") {
-if (preg_replace("/_[0-9]{4,4}_[0-9]{5,5}(_[0-9]+(-[0-9]+)?)*\.$suff_file/","",$resto_nome_contr) == "") {
-$num_pren_esist = substr($resto_nome_contr,12);
+if (preg_replace("/_[0-9]{4,4}_[0-9]{5,8}(-[0-9]{5,8})?(_[0-9]+(-[0-9]+|\+[0-9]+(\+[0-9]+)?)?)*\.$suff_file/","",$resto_nome_contr) == "") {
+$num_prog_contr = explode("_",$resto_nome_contr);
+$num_prog_contr = $num_prog_contr[2];
+if (substr($num_prog_contr,(-1 * (strlen($suff_file) + 1))) == ".".$suff_file) $num_prog_contr = substr($num_prog_contr,0,(-1 * (strlen($suff_file) + 1)));
+$num_pren_esist = substr($resto_nome_contr,(7 + strlen($num_prog_contr)));
 $num_pren_esist = substr($num_pren_esist,0,(-1 * (strlen($suff_file) + 1)));
 if ($num_pren_esist) {
-$agg_contr = 1;
 $n_lista_pren = "";
 $num_pren_esist = explode("_",$num_pren_esist);
 for ($num3 = 0 ; $num3 < count($num_pren_esist) ; $num3++) {
+if (strstr($num_pren_esist[$num3],"+")) $n_lista_pren.= "_".$num_pren_esist[$num3];
+else {
 $num_pren_esist2 = explode("-",$num_pren_esist[$num3]);
 $fine_for = $num_pren_esist2[(count($num_pren_esist2) - 1)];
 for ($num4 = $num_pren_esist2[0] ; $num4 <= $fine_for ; $num4++) {
 if (!$nuovo_idprenota[$num4]) {
-$agg_contr = 0;
-break;
+if ($num4 > $num_pren_esist2[0]) {
+if (($num4 - 1) == $num_pren_esist2[0]) $n_lista_pren .= "_".$nuovo_idprenota[($num4 - 1)];
+else $n_lista_pren .= "-".$nuovo_idprenota[$num4];
+} # fine if ($num4 > $num_pren_esist2[0])
+$n_lista_pren .= "_$anno_prec+$num4";
+if ($nuovo_idprenota_iniziata[$num4]) $n_lista_pren .= "+".$nuovo_idprenota_iniziata[$num4];
+$num_pren_esist2[0] = ($num4 + 1);
 } # fine if (!$nuovo_idprenota[$num4])
+else {
 if ($num4 == $num_pren_esist2[0]) $n_lista_pren .= "_".$nuovo_idprenota[$num4];
 elseif ($num4 == $fine_for) $n_lista_pren .= "-".$nuovo_idprenota[$num4];
+} # fine else if (!$nuovo_idprenota[$num4])
 } # fine for $num4
+} # fine else if (strstr($num_pren_esist[$num3],"+"))
 } # fine for $num3
-if ($agg_contr) {
-$n_nome_contr = $nome_contratto.substr($resto_nome_contr,0,11).$n_lista_pren.".$suff_file";
+$n_nome_contr = $nome_contratto.substr($resto_nome_contr,0,(6 + strlen($num_prog_contr))).$n_lista_pren.".$suff_file";
 rename($dir_salva."/".$contr_corr,$dir_salva."/".$n_nome_contr);
-} # fine if ($agg_contr)
 } # fine if ($num_pren_esist)
-} # fine if (preg_replace("/_[0-9]{4,4}_[0-9]{5,5}\.$suff_file/","",$resto_nome_contr) == "")
+} # fine if (preg_replace("/_[0-9]{4,4}_[0-9]{5,8}(-[0-9]{5,8})?(_[0-9]+(-[0-9]+|\+[0-9]+(\+[0-9]+)?)?)*\.$suff_file/","",$resto_nome_contr) == "")
 } # fine if (substr($resto_nome_contr,0,6) == "_$anno"."_")
+} # fine if ($suff_file)
 } # fine if (substr($contr_corr,0,strlen($nome_contratto)) == $nome_contratto)
 } # fine if ($contr_corr != "." and $contr_corr != ".." and...
 } # fine while ($fattura_corr = readdir($fatture_dir))
 closedir($contr_dir);
-} # fine if (!$prefissi_contr[$dir_salva."/".$nomi_contr_ut[$idutente_contr][$num_contr]])
+} # fine if (!$prefissi_contr[$dir_salva."/".$nome_contratto])
 } # fine for $num2
 flock($filelock_contr,3);
 fclose($filelock_contr);
@@ -795,9 +869,11 @@ if ($silenzio != "SI") echo "<br> ".mex("Anno ",$pag).$anno.mex(" creato",$pag).
 if ($importa_anno_prec == "SI" and (!defined('C_RESTRIZIONI_DEMO_ADMIN') or C_RESTRIZIONI_DEMO_ADMIN != "SI")) {
 if ($silenzio != "SI") $silenzio_mod = "SI";
 else $silenzio_mod = "totale";
-global $anno_modello_presente,$num_periodi_date,$modello_esistente,$cambia_frasi,$lingua_modello,$percorso_cartella_modello,$nome_file;
+global $anno_modello_presente,$num_periodi_date,$modello_esistente,$cambia_frasi,$lingua_modello,$percorso_cartella_modello,$nome_file,$id_utente;
 $pag_orig = $pag;
 $pag = "crea_modelli.php";
+$id_utente_orig = $id_utente;
+$id_utente = 1;
 include("./includes/templates/funzioni_modelli.php");
 $modello_esistente = "SI";
 $cambia_frasi = "NO";
@@ -884,6 +960,7 @@ closedir($lang_dir);
 } # fine while ($file = readdir($lang_dig))
 closedir($templates_dir);
 $pag = $pag_orig;
+$id_utente = $id_utente_orig;
 if ($silenzio != "SI") echo "<br>";
 } # fine if ($importa_anno_prec == "SI" and (!defined('C_RESTRIZIONI_DEMO_ADMIN') or C_RESTRIZIONI_DEMO_ADMIN != "SI"))
 
