@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2016 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2019 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -23,7 +23,7 @@
 
 
 
-function inserisci_dati_cliente (&$cognome,&$nome,$soprannome,$titolo_cli,$sesso,$mesenascita,$giornonascita,$annonascita,&$nazionenascita,&$cittanascita,&$regionenascita,$documento,$tipodoc,$mesescaddoc,$giornoscaddoc,$annoscaddoc,&$cittadoc,&$regionedoc,&$nazionedoc,&$nazionalita,&$lingua_cli,&$nazione,&$citta,&$regione,&$via,$nomevia,$numcivico,$cap,$telefono,$telefono2,$telefono3,$fax,$email,$cod_fiscale,$partita_iva,$max_num_ordine,$id_utente_ins,$attiva_prefisso_clienti,$prefisso_clienti,$idclienti="",$valida="",$campi_pers_vett="") {
+function inserisci_dati_cliente (&$cognome,&$nome,$soprannome,$titolo_cli,$sesso,$mesenascita,$giornonascita,$annonascita,&$nazionenascita,&$cittanascita,&$regionenascita,$documento,$tipodoc,$mesescaddoc,$giornoscaddoc,$annoscaddoc,&$cittadoc,&$regionedoc,&$nazionedoc,&$nazionalita,&$lingua_cli,&$nazione,&$citta,&$regione,&$via,$nomevia,$numcivico,$cap,$telefono,$telefono2,$telefono3,$fax,$email,$email2,$email_cert,$cod_fiscale,$partita_iva,$max_num_ordine,$id_utente_ins,$attiva_prefisso_clienti,$prefisso_clienti,$idclienti="",$valida="",$campi_pers_vett="") {
 global $lingua_mex,$HOSTNAME,$id_utente,$PHPR_TAB_PRE;
 $tableclienti = $PHPR_TAB_PRE."clienti";
 $tablerelclienti = $PHPR_TAB_PRE."relclienti";
@@ -58,6 +58,8 @@ $telefono2 = stripslashes($telefono2);
 $telefono3 = stripslashes($telefono3);
 $fax = stripslashes($fax);
 $email = stripslashes($email);
+$email2 = stripslashes($email2);
+$email_cert = stripslashes($email_cert);
 $cod_fiscale = stripslashes($cod_fiscale);
 $partita_iva = stripslashes($partita_iva);
 for ($num1 = 0 ; $num1 < $num_campi_pers ; $num1++) $campi_pers_vett['val'][$num1] = stripslashes($campi_pers_vett['val'][$num1]);
@@ -86,6 +88,8 @@ $telefono2 = htmlspecialchars($telefono2);
 $telefono3 = htmlspecialchars($telefono3);
 $fax = htmlspecialchars($fax);
 $email = htmlspecialchars($email);
+$email2 = htmlspecialchars($email2);
+$email_cert = htmlspecialchars($email_cert);
 $cod_fiscale = htmlspecialchars($cod_fiscale);
 $partita_iva = htmlspecialchars($partita_iva);
 for ($num1 = 0 ; $num1 < $num_campi_pers ; $num1++) $campi_pers_vett['val'][$num1] = htmlspecialchars($campi_pers_vett['val'][$num1]);
@@ -141,7 +145,11 @@ esegui_query("update $tableclienti set sesso = '$sesso' where idclienti = '$idcl
 } # fine if ($sesso)
 if ($mesenascita and $giornonascita and strlen($annonascita) == 4) {
 if ($annonascita > 1970) $datanascita = date("Y-m-d",mktime(0,0,0,$mesenascita,$giornonascita,$annonascita));
-else $datanascita = $annonascita."-".$mesenascita."-".$giornonascita;
+else {
+if (strlen($mesenascita) < 2) $mesenascita = "0".$mesenascita;
+if (strlen($giornonascita) < 2) $giornonascita = "0".$giornonascita;
+$datanascita = $annonascita."-".$mesenascita."-".$giornonascita;
+} # fine else if ($annonascita > 1970)
 $datanascita = aggslashdb($datanascita);
 esegui_query("update $tableclienti set datanascita = '$datanascita' where idclienti = '$idclienti' ");
 } # fine if ($mesenascita and ...
@@ -239,6 +247,10 @@ $fax = aggslashdb($fax);
 if ($fax) esegui_query("update $tableclienti set fax = '$fax' where idclienti = '$idclienti' ");
 $email = aggslashdb($email);
 if ($email) esegui_query("update $tableclienti set email = '$email' where idclienti = '$idclienti' ");
+$email2 = aggslashdb($email2);
+if ($email2) esegui_query("update $tableclienti set email2 = '$email2' where idclienti = '$idclienti' ");
+$email_cert = aggslashdb($email_cert);
+if ($email_cert) esegui_query("update $tableclienti set email3 = '$email_cert' where idclienti = '$idclienti' ");
 $cod_fiscale = aggslashdb($cod_fiscale);
 if ($cod_fiscale) esegui_query("update $tableclienti set cod_fiscale = '$cod_fiscale' where idclienti = '$idclienti' ");
 $partita_iva = aggslashdb($partita_iva);
@@ -260,7 +272,7 @@ return $idclienti;
 
 
 
-function mostra_dati_cliente (&$dati_cliente,&$dcognome,&$dnome,&$dsoprannome,&$dtitolo_cli,&$dsesso,&$ddatanascita,&$ddatanascita_f,&$dnazionenascita,&$dcittanascita,&$dregionenascita,&$ddocumento,&$dscadenzadoc,&$dscadenzadoc_f,&$dtipodoc,&$dnazionedoc,&$dregionedoc,&$dcittadoc,&$dnazionalita,&$dlingua_cli,&$dnazione,&$dregione,&$dcitta,&$dvia,&$dnumcivico,&$dtelefono,&$dtelefono2,&$dtelefono3,&$dfax,&$dcap,&$demail,&$dcod_fiscale,&$dpartita_iva,$mostra_num="",$priv_ins_clienti="",$silenzio="",$mostra_commento="") {
+function mostra_dati_cliente (&$dati_cliente,&$dcognome,&$dnome,&$dsoprannome,&$dtitolo_cli,&$dsesso,&$ddatanascita,&$ddatanascita_f,&$dnazionenascita,&$dcittanascita,&$dregionenascita,&$ddocumento,&$dscadenzadoc,&$dscadenzadoc_f,&$dtipodoc,&$dnazionedoc,&$dregionedoc,&$dcittadoc,&$dnazionalita,&$dlingua_cli,&$dnazione,&$dregione,&$dcitta,&$dvia,&$dnumcivico,&$dtelefono,&$dtelefono2,&$dtelefono3,&$dfax,&$dcap,&$demail,&$demail2,&$demail_cert,&$dcod_fiscale,&$dpartita_iva,$mostra_num="",$priv_ins_clienti="",$silenzio="",$mostra_commento="") {
 global $pag,$id_utente,$PHPR_TAB_PRE;
 
 if ($id_utente == 1 or !$id_utente) {
@@ -310,6 +322,8 @@ $dtelefono2 = risul_query($dati_cliente,0,'telefono2');
 $dtelefono3 = risul_query($dati_cliente,0,'telefono3');
 $dfax = risul_query($dati_cliente,0,'fax');
 $demail = risul_query($dati_cliente,0,'email');
+$demail2 = risul_query($dati_cliente,0,'email2');
+$demail_cert = risul_query($dati_cliente,0,'email3');
 } # fine if ($priv_vedi_telefoni == "s")
 $dcod_fiscale = risul_query($dati_cliente,0,'cod_fiscale');
 $dpartita_iva = risul_query($dati_cliente,0,'partita_iva');
@@ -395,11 +409,21 @@ if ($dnazione or $dregione) $lin .= ") ";
 if ($lin) $output .= "<br>$lin";
 
 $lin = "";
-if ($dtelefono) $lin .= mex("Telefono",$pag).": $dtelefono ";
-if ($dtelefono2) $lin .= mex("2º telefono",$pag).": $dtelefono2 ";
+if ($dtelefono) $lin .= mex("Telefono",$pag).": $dtelefono, ";
+if ($dtelefono2 or $dtelefono3 or $dfax) {
+if ($dtelefono2) $lin .= mex("2º telefono",$pag).": $dtelefono2, ";
 if ($dtelefono3) $lin .= mex("3º telefono",$pag).": $dtelefono3, ";
 if ($dfax) $lin .= "fax: $dfax, ";
-if ($demail) $lin .= "email: <a href=\"mailto:$demail\">$demail</a> ";
+if ($lin) $output .= "<br>".substr($lin,0,-2);
+$lin = "";
+} # fine if ($dtelefono2 or $dtelefono3 or $dfax)
+
+if ($demail) $lin .= mex("email",$pag).": <a href=\"mailto:$demail\">$demail</a> ";
+if ($demail2) $lin .= mex("2ª email",$pag).": <a href=\"mailto:$demail2\">$demail2</a> ";
+if ($demail_cert) {
+if (strstr($demail_cert,"@")) $lin .= mex("PEC/codice",$pag).": <a href=\"mailto:$demail_cert\">$demail_cert</a> ";
+else $lin .= mex("PEC/codice",$pag).": $demail_cert ";
+} # fine if ($demail_cert)
 if ($lin) $output .= "<br>$lin";
 
 $lin = "";
