@@ -366,7 +366,7 @@ $mess_errore .= mex("Nel periodo selezionato non è possibile ospitare il client
 if ($app_incomp_costi) $mess_errore .= " ".mex("con i costi aggiuntivi selezionati",'clienti.php');
 $mess_errore .= ".<br>";
 for ($n_t = 1 ; $n_t <= $num_tipologie ; $n_t++) {
-$mess_prenota .= mex("Prenotazione","prenota.php").mex("dal","prenota.php")." <b>".formatta_data($inizioperiodo_orig[$n_t],$stile_data)."</b> ".mex("al","prenota.php")." <b>".formatta_data($fineperiodo_orig[$n_t],$stile_data)."</b>";
+$mess_prenota .= mex("Prenotazione","prenota.php")." ".mex("dal","prenota.php")." <b>".formatta_data($inizioperiodo_orig[$n_t],$stile_data)."</b> ".mex("al","prenota.php")." <b>".formatta_data($fineperiodo_orig[$n_t],$stile_data)."</b>";
 $mess_prenota .= " ".mex("a nome di","prenota.php")." <b>$cognome</b> ";
 if ($numpersone[$n_t]) $mess_prenota .= " ".mex("per","prenota.php")." <b>".$numpersone[$n_t]."</b> ".mex("persone","prenota.php")."";
 if ($dati_tariffe[$tipotariffa[$n_t]]['nome']) $nometariffa_vedi = $dati_tariffe[$tipotariffa[$n_t]]['nome'];
@@ -462,7 +462,7 @@ $mess_errore .= mex("Nel periodo selezionato non è possibile ospitare il client
 if ($app_incomp_costi) $mess_errore .= " ".mex("con i costi aggiuntivi selezionati",'clienti.php');
 $mess_errore .= ".<br>";
 for ($n_t = 1 ; $n_t <= $num_tipologie ; $n_t++) {
-$mess_prenota .= mex("Prenotazione","prenota.php").mex("dal","prenota.php")." <b>".formatta_data($inizioperiodo_orig[$n_t],$stile_data)."</b> ".mex("al","prenota.php")." <b>".formatta_data($fineperiodo_orig[$n_t],$stile_data)."</b>";
+$mess_prenota .= mex("Prenotazione","prenota.php")." ".mex("dal","prenota.php")." <b>".formatta_data($inizioperiodo_orig[$n_t],$stile_data)."</b> ".mex("al","prenota.php")." <b>".formatta_data($fineperiodo_orig[$n_t],$stile_data)."</b>";
 $mess_prenota .= " ".mex("a nome di","prenota.php")." <b>$cognome</b> ";
 if ($numpersone[$n_t]) $mess_prenota .= " ".mex("per","prenota.php")." <b>".$numpersone[$n_t]."</b> ".mex("persone","prenota.php")."";
 if ($dati_tariffe[$tipotariffa[$n_t]]['nome']) $nometariffa_vedi = $dati_tariffe[$tipotariffa[$n_t]]['nome'];
@@ -775,12 +775,13 @@ $mess_prenota .= "<br>".mex("Orario stimato di entrata","prenota.php").": <b>".s
 } # fine if (controlla_num_pos($giorno_stima_checkin) == "SI" and...
 } # fine if ($giorno_stima_checkin[$n_t] and $ora_stima_checkin[$n_t] and $min_stima_checkin[$n_t])
 
-if ($commento[$n_t]) {
+if (strcmp($commento[$n_t],"") or $commento['pers'][$n_t]) {
 $commento[$n_t] = htmlspecialchars($commento[$n_t]);
-$mess_prenota .= "<br>".mex("Commento","prenota.php").": ".$commento[$n_t]."<br>";
+if (strcmp($commento[$n_t],"")) $mess_prenota .= "<br>".mex("Commento","prenota.php").": ".$commento[$n_t]."<br>";
+if ($commento['pers'][$n_t]) $commento[$n_t] .= $commento['pers'][$n_t];
 $commento[$n_t] = aggslashdb($commento[$n_t]);
 esegui_query("update $tableprenota set commento = '".$commento[$n_t]."' where idprenota = '$idprenota' ");
-} # fine if ($commento[$n_t])
+} # fine if (strcmp($commento[$n_t],"") or $commento['pers'][$n_t])
 
 $mess_prenota .= "<br>".mex("Prenotazione","prenota.php")." $idprenota ".mex("inserita","prenota.php")."!<br>";
 if ($n_t != $num_tipologie) $mess_prenota .= "<hr style=\"width: 95%\">";
