@@ -588,4 +588,19 @@ return $dati_cat_pers_p;
 
 
 
+function converti_valuta ($val,$cambio,$arrotond,$inv=0) {
+
+if ($inv) $val = (double) formatta_soldi($val) / (double) $cambio;
+else $val = (double) formatta_soldi($val) * (double) $cambio;
+$val = $val / (double) $arrotond;
+$val = round($val);
+$val = $val * (double) $arrotond;
+
+return $val;
+
+} # fine function function converti_valuta
+
+
+
+
 ?>
\ No newline at end of file
