@@ -41,7 +41,7 @@ if (defined('C_NASCONDI_MARCA') and C_NASCONDI_MARCA == "SI") $titolo = "";
 if (defined('C_FILE_TITOLO_PERS') and C_FILE_TITOLO_PERS != "" and @is_file(C_FILE_TITOLO_PERS)) $titolo = trim(substr(implode("",file(C_FILE_TITOLO_PERS)),0,40))." - $titolo";
 echo "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN\"
         \"http://www.w3.org/TR/html4/strict.dtd\">
-<html>
+<html lang=\"$lingua_mex\">
 <head>
 <meta http-equiv=\"Content-Type\" content=\"text/html;charset=utf-8\" >
 <meta name=\"viewport\" content=\"initial-scale=$iscale\">
