@@ -2,6 +2,7 @@
 
 switch ($messaggio) {
 
+case "Modifica Variabili Documenti":  		$messaggio = "Modify Documents Variables"; break;
 case "Torna indietro":  			$messaggio = "Go back"; break;
 case "Variabili personalizzate dei documenti":  $messaggio = "Documents custom variables"; break;
 case "Variabili personalizzate":  		$messaggio = "Custom variables"; break;
@@ -119,6 +120,7 @@ case "codificato per URL":  			$messaggio = "encoded for URL"; break;
 case "codificato in ASCII":  			$messaggio = "encoded in ASCII"; break;
 case "in ASCII esteso":  			$messaggio = "in extended ASCII"; break;
 case "codificato con MD5":  			$messaggio = "encoded with MD5"; break;
+case "solo nelle ripetizioni dei documenti salvati":	$messaggio = "only inside repetitions of saved documents"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
