@@ -2,11 +2,12 @@
 
 switch ($messaggio) {
 
+case "Personalizza":  				$messaggio = "Customize"; break;
 case "Configura e personalizza HotelDruid":	$messaggio = "Configure and customize HotelDruid"; break;
 case "Scegli la lingua":  			$messaggio = "Choose the language"; break;
 case "cambia la lingua":  			$messaggio = "change language"; break;
 case "Tabella con tutte le prenotazioni":  	$messaggio = "Table with all the reservations"; break;
-case "Cambia la valuta":  			$messaggio = "Change currency"; break;
+case "Nome della valuta principale":  		$messaggio = "Name of the main currency"; break;
 case "Scegli le colonne da far comparire":  	$messaggio = "Choose the colums that will appear"; break;
 case "n° di settimane":  			$messaggio = "n° of weeks"; break;
 case "n° di giorni":  				$messaggio = "n° of days"; break;
@@ -178,6 +179,7 @@ case "Elimina tutte":  				$messaggio = "Delete all"; break;
 case "Ripristina predefinite":  		$messaggio = "Restore defaults"; break;
 case "Importa le nazioni":  			$messaggio = "Import nations"; break;
 case "Regioni/provincie":  			$messaggio = "Regions"; break;
+case "Regione/provincia":  			$messaggio = "Region"; break;
 case "Importa le regioni/provincie":  		$messaggio = "Import regions"; break;
 case "Nazione cancellata":  			$messaggio = "Nation deleted"; break;
 case "Regione/provincia cancellata":  		$messaggio = "Region deleted"; break;
@@ -305,7 +307,7 @@ case "2° codice":  				$messaggio = "2nd code"; break;
 case "3° codice":  				$messaggio = "3rd code"; break;
 case "Tabella con i documenti salvati":  	$messaggio = "Table with saved documents"; break;
 case "Il numero delle righe della tabella con i documenti salvati è stato cambiato":	$messaggio = "The number of rows of the table with saved documents has been changed"; break;
-case "valore a cui arrotondare le percentuali delle tasse":	$messaggio = "rounding value for percentages of taxes"; break;
+case "valore a cui arrotondare le percentuali delle tasse e delle valute":	$messaggio = "rounding value for percentages of taxes and currencies"; break;
 case "commissioni":  				$messaggio = "commissions"; break;
 case "resto commissioni":  			$messaggio = "commissions rest"; break;
 case "documenti salvati":  			$messaggio = "saved documents"; break;
@@ -424,6 +426,17 @@ case "Le tipologie di persone sono state modificate":	$messaggio = "The people t
 case "Cambia per tutti gli utenti":  		$messaggio = "Change for all users"; break;
 case "Modifica le tipologie di persone per tutti gli utenti":	$messaggio = "Modify people types for all users"; break;
 case "tipi di persona":  			$messaggio = "person types"; break;
+case "Valuta secondaria chiamata":  		$messaggio = "Secundary currency called"; break;
+case "nuova valuta":  				$messaggio = "new currency"; break;
+case "con arrotondamento":  			$messaggio = "with rounding"; break;
+case "Aggiungi per tutti gli utenti":  		$messaggio = "Add for all users"; break;
+case "Elimina la valuta":  			$messaggio = "Delete the currency"; break;
+case "Elimina":  				$messaggio = "Delete"; break;
+case "Elimina per tutti gli utenti":  		$messaggio = "Delete for all users"; break;
+case "La nuova valuta secondaria è stata aggiunta":	$messaggio = "The new secundary currency has been addded"; break;
+case "La valuta secondaria":  			$messaggio = "The secundary currency"; break;
+case "è stata modificata":  			$messaggio = "has been modified"; break;
+case "è stata eliminata":  			$messaggio = "has been deleted"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
