@@ -2,6 +2,7 @@
 
 switch ($messaggio) {
 
+case "Visualizza Tabelle":  			$messaggio = "View Tables"; break;
 case "Vedi le prenotazioni":  			$messaggio = "View the reservations"; break;
 case "presenti dal":  				$messaggio = "present from"; break;
 case "al":  					$messaggio = "to"; break;
@@ -360,6 +361,15 @@ case "escludere_da_totale_percentuale":  	$messaggio = "exclude_from_percentage_
 case "da varie tariffe":  			$messaggio = "from different<br>rates"; break;
 case "senza letti aggiuntivi":  		$messaggio = "without extra beds"; break;
 case "Premere per modificare":  		$messaggio = "Click to modify"; break;
+case "Converti definitivamente in":  		$messaggio = "Permanently convert into"; break;
+case "al cambio attuale":  			$messaggio = "at current exchange rate"; break;
+case "Le altre valute presenti nella cassa":  	$messaggio = "Other currencies in cashbox"; break;
+case "sono state convertite in":  		$messaggio = "have been converted into"; break;
+case "Tabella con le prenotazioni cancellate":	$messaggio = "Table with deleted reservations"; break;
+case "Prenotazioni cancellate":  		$messaggio = "Deleted reservations"; break;
+case "<b>non importare</b> i prezzi":  		$messaggio = "<b>do not import</b> prices"; break;
+case "Attenzione":  				$messaggio = "Notice"; break;
+case "i periodi aggiunti non potranno più essere eliminati":	$messaggio = "periods added now can't be deleted later"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
