@@ -12,9 +12,9 @@ case "Il piano verrà cambiato da":  		$messaggio = "El piso será cambiado de";
 case "Il massimo numero di occupanti verrà cambiato da":	$messaggio = "El máximo número de ocupantes será cambiado de"; break;
 case "La priorità verrà cambiata da":  		$messaggio = "La prioridad será cambiada de"; break;
 case "Il commento verrà cambiato":  		$messaggio = "El comentario será cambiado"; break;
-case "Continua":  				$messaggio = "Continua"; break;
+case "Continua":  				$messaggio = "Continuar"; break;
 case "Casa":  					$messaggio = "Casa"; break;
-case "Cambia in":  				$messaggio = "Cambia a"; break;
+case "Cambia in":  				$messaggio = "Cambiar a"; break;
 case "Piano":  					$messaggio = "Piso"; break;
 case "Capienza":  				$messaggio = "Capacidad"; break;
 case "Priorità":  				$messaggio = "Prioridad"; break;
