@@ -2,6 +2,7 @@
 
 switch ($messaggio) {
 
+case "Modifica Variabili Documenti":  		$messaggio = "Modificar Variables Documentos"; break;
 case "Torna indietro":  			$messaggio = "Volver atrás"; break;
 case "Variabili personalizzate dei documenti":  $messaggio = "Variables personalizadas de los documentos"; break;
 case "Variabili personalizzate":  		$messaggio = "Variables personalizadas"; break;
@@ -119,6 +120,7 @@ case "codificato per URL":  			$messaggio = "codificado para URL"; break;
 case "codificato in ASCII":  			$messaggio = "codificado en ASCII"; break;
 case "in ASCII esteso":  			$messaggio = "en ASCII extendido"; break;
 case "codificato con MD5":  			$messaggio = "codificado con MD5"; break;
+case "solo nelle ripetizioni dei documenti salvati":	$messaggio = "solo en las repeticiones de los documentos salvados"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
