@@ -2,11 +2,12 @@
 
 switch ($messaggio) {
 
+case "Personalizza":  				$messaggio = "Personalizar"; break;
 case "Configura e personalizza HotelDruid":	$messaggio = "Configurar y personalizar HotelDruid"; break;
 case "Scegli la lingua":  			$messaggio = "Escoger el idioma"; break;
 case "cambia la lingua":  			$messaggio = "cambiar el idioma"; break;
 case "Tabella con tutte le prenotazioni":  	$messaggio = "Tabla con todas las reservas"; break;
-case "Cambia la valuta":  			$messaggio = "Cambiar la divisa"; break;
+case "Nome della valuta principale":  		$messaggio = "Nombre de la divisa principal"; break;
 case "Scegli le colonne da far comparire":  	$messaggio = "Escoger las columnas que aparecerán"; break;
 case "n° di settimane":  			$messaggio = "n° de semanas"; break;
 case "n° di giorni":  				$messaggio = "n° de días"; break;
@@ -178,6 +179,7 @@ case "Elimina tutte":  				$messaggio = "Eliminar todas"; break;
 case "Ripristina predefinite":  		$messaggio = "Restaurar predefinidas"; break;
 case "Importa le nazioni":  			$messaggio = "Importar la naciones"; break;
 case "Regioni/provincie":  			$messaggio = "Regiones"; break;
+case "Regione/provincia":  			$messaggio = "Región"; break;
 case "Importa le regioni/provincie":  		$messaggio = "Importar las regiones"; break;
 case "Nazione cancellata":  			$messaggio = "Nación borrada"; break;
 case "Regione/provincia cancellata":  		$messaggio = "Región borrada"; break;
@@ -305,7 +307,7 @@ case "2° codice":  				$messaggio = "2° código"; break;
 case "3° codice":  				$messaggio = "3er código"; break;
 case "Tabella con i documenti salvati":  	$messaggio = "Tabla con los documentos salvados"; break;
 case "Il numero delle righe della tabella con i documenti salvati è stato cambiato":	$messaggio = "El número de líneas de la tabla con los documentos salvados ha sido cambiado"; break;
-case "valore a cui arrotondare le percentuali delle tasse":	$messaggio = "valor al que redondear los porcentajes de las tasas"; break;
+case "valore a cui arrotondare le percentuali delle tasse e delle valute":	$messaggio = "valor al que redondear los porcentajes de las tasas y las divisas"; break;
 case "commissioni":  				$messaggio = "comisiones"; break;
 case "resto commissioni":  			$messaggio = "resto comisiones"; break;
 case "documenti salvati":  			$messaggio = "documentos salvados"; break;
@@ -424,6 +426,17 @@ case "Le tipologie di persone sono state modificate":	$messaggio = "Los tipos de
 case "Cambia per tutti gli utenti":  		$messaggio = "Cambiar para todos los usuarios"; break;
 case "Modifica le tipologie di persone per tutti gli utenti":	$messaggio = "Modificar los tipos de personas para todos los usuarios"; break;
 case "tipi di persona":  			$messaggio = "tipos de persona"; break;
+case "Valuta secondaria chiamata":  		$messaggio = "Divisa secundaria llamada"; break;
+case "nuova valuta":  				$messaggio = "nueva divisa"; break;
+case "con arrotondamento":  			$messaggio = "con redondeo"; break;
+case "Aggiungi per tutti gli utenti":  		$messaggio = "Añadir para todos los usuarios"; break;
+case "Elimina la valuta":  			$messaggio = "Eliminar la divisa"; break;
+case "Elimina":  				$messaggio = "Eliminar"; break;
+case "Elimina per tutti gli utenti":  		$messaggio = "Eliminar para todos los usuarios"; break;
+case "La nuova valuta secondaria è stata aggiunta":	$messaggio = "La nueva divisa secundaria ha sido añadida"; break;
+case "La valuta secondaria":  			$messaggio = "La divisa secundaria"; break;
+case "è stata modificata":  			$messaggio = "ha sido modificada"; break;
+case "è stata eliminata":  			$messaggio = "ha sido eliminada"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
