@@ -2,6 +2,7 @@
 
 switch ($messaggio) {
 
+case "Visualizza Tabelle":  			$messaggio = "Ver Tablas"; break;
 case "Vedi le prenotazioni":  			$messaggio = "Mira las reservas"; break;
 case "presenti dal":  				$messaggio = "presentes desde"; break;
 case "al":  					$messaggio = "hasta"; break;
@@ -361,6 +362,15 @@ case "escludere_da_totale_percentuale":  	$messaggio = "excluir_del_total_para_p
 case "da varie tariffe":  			$messaggio = "desde varias<br>tarifas"; break;
 case "senza letti aggiuntivi":  		$messaggio = "sin camas extra"; break;
 case "Premere per modificare":  		$messaggio = "Hacer clic para modificar"; break;
+case "Converti definitivamente in":  		$messaggio = "Convertir definitivamente en"; break;
+case "al cambio attuale":  			$messaggio = "al cambio actual"; break;
+case "Le altre valute presenti nella cassa":  	$messaggio = "Las otras divisas presentes en la caja"; break;
+case "sono state convertite in":  		$messaggio = "han sido convertidas en"; break;
+case "Tabella con le prenotazioni cancellate":	$messaggio = "Tabla con las reservas borradas"; break;
+case "Prenotazioni cancellate":  		$messaggio = "Reservas borradas"; break;
+case "<b>non importare</b> i prezzi":  		$messaggio = "<b>sin importar</b> los precios"; break;
+case "Attenzione":  				$messaggio = "Aviso"; break;
+case "i periodi aggiunti non potranno più essere eliminati":	$messaggio = "los períodos añadidos ya no podrán ser eliminados"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
