@@ -22,6 +22,8 @@
 
 
 
+if (function_exists('esegui_query')) {
+
 if (preg_replace("/[a-z]/","",$template_data_dir) != "") $template_data_dir = "";
 include("./includes/templates/$template_data_dir/phrases.php");
 
@@ -34,22 +36,42 @@ esegui_query("insert into $tablepersonalizza (idpersonalizza,valpersonalizza,idu
 # Prendo i dati dal file se già esistente
 if ($template_file_name[$lingua_modello]) $nome_file = $template_file_name[$lingua_modello];
 else {
-$nome_file = mext_cal($template_file_name["ita"],$pag,$lingua_modello);
-if ($nome_file == $template_file_name["en"] or $nome_file == $template_file_name["ita"]) $nome_file = $lingua_modello."_".$template_file_name['en'];
+$nome_file = mext_cal($template_file_name['ita'],$pag,$lingua_modello);
+if ($nome_file == $template_file_name['en'] or $nome_file == $template_file_name['ita']) $nome_file = $lingua_modello."_".$template_file_name['en'];
 } # fine else if ($template_file_name[$lingua_modello])
-$SI = mex("SI",$pag);
-$NO = mex("NO",$pag);
+$SI = mex2("SI",$pag,$lingua_mex_1);
+$NO = mex2("NO",$pag,$lingua_mex_1);
 $modello_esistente = "NO";
+unset($id_transazione);
 if (@is_file("$percorso_cartella_modello/$nome_file")) {
 $modello_esistente = "SI";
+$lingua_mex = $lingua_mex_1;
 include("./includes/templates/$template_data_dir/functions.php");
 recupera_var_modello_cal($nome_file,$percorso_cartella_modello,$pag,$fr_frase,$num_frasi,$var_mod,$num_var_mod,$tipo_periodi,"NO",$anno_modello,$PHPR_TAB_PRE);
+$lingua_mex = $lingua_orig;
+
+$tabelle_lock = array($tableversioni,$tabletransazioni);
+$tabelle_lock = lock_tabelle($tabelle_lock);
+$adesso = date("YmdHis",(time() + (C_DIFF_ORE * 3600)));
+list($usec, $sec) = explode(' ', microtime());
+mt_srand((float) $sec + ((float) $usec * 100000));
+$val_casuale = mt_rand(100000,999999);
+$versione_transazione = prendi_numero_versione($tableversioni);
+$id_transazione = $adesso.$val_casuale.$versione_transazione;
+$ultimo_accesso = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
+esegui_query("delete from $tabletransazioni where spostamenti = '$modello_ext' and tipo_transazione = 'cpweb' ");
+$dati_tr2 = aggslashdb(serialize($tariffe_mostra));
+$dati_tr4 = aggslashdb(serialize($considera_motivazioni_regola1));
+esegui_query("insert into $tabletransazioni (idtransazioni,idsessione,tipo_transazione,anno,spostamenti,dati_transazione2,dati_transazione4,ultimo_accesso) 
+values ('$id_transazione','$id_sessione','cpweb','$anno','$modello_ext','$dati_tr2','$dati_tr4','$ultimo_accesso')");
+unlock_tabelle($tabelle_lock);
 } # fine if (@is_file("$percorso_cartella_modello/$nome_file"))
 
 
-echo "<form method=\"post\" action=\"crea_modelli.php\"><div>
+echo "<form method=\"post\" action=\"crea_modelli.php\" enctype=\"multipart/form-data\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
+<input type=\"hidden\" name=\"id_transazione\" value=\"$id_transazione\">
 <input type=\"hidden\" name=\"crea_modello\" value=\"SI\">
 <input type=\"hidden\" name=\"fonte_dati_conn\" value=\"$fonte_dati_conn\">
 <input type=\"hidden\" name=\"T_PHPR_DB_TYPE\" value=\"".htmlspecialchars($T_PHPR_DB_TYPE)."\">
@@ -176,6 +198,9 @@ $tablenometariffe_modello = $PHPR_TAB_PRE."ntariffe".$anno_modello;
 $rigatariffe = esegui_query("select * from $tablenometariffe_modello where idntariffe = 1 ");
 $numero_tariffe = risul_query($rigatariffe,0,'nomecostoagg');
 for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa++) {
+if (strtoupper($tariffe_mostra[$numtariffa]) == $SI) $checked = " checked";
+else $checked = "";
+if ($attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[$numtariffa] == "SI" or $checked) {
 if ($celle == 1) echo "<tr>";
 $tariffa = "tariffa".$numtariffa;
 $nometariffa=risul_query($rigatariffe,0,$tariffa);
@@ -185,8 +210,6 @@ $nometariffa_vedi = mex("tariffa",$pag).$numtariffa;
 } # fine if ($nometariffa == "")
 else $nometariffa_vedi = $nometariffa;
 $nome_tariffa_imposto = "nome_tariffa_imposto".$numtariffa;
-if (strtoupper($tariffe_mostra[$numtariffa]) == $SI) $checked = " checked";
-else $checked = "";
 if (!$tariffe_mostra['array_esistente']) $checked = " checked";
 $val = "";
 if ($nomi_tariffe_imposte["array_esistente"]) $val = $nomi_tariffe_imposte[$numtariffa];
@@ -197,6 +220,7 @@ echo "</tr>";
 $celle = 0;
 } # fine if ($celle == 3)
 $celle++;
+} # fine if ($attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[$numtariffa] == "SI" or $checked)
 } # fine for $numtariffa
 if ($celle != 1) {
 for ($num1 = $celle ; $num1 <= $num_colonne ; $num1++) echo "<td>&nbsp;</td>";
@@ -214,20 +238,25 @@ $num_regole = numlin_query($regole);
 unset($motivazioni_presenti);
 $num_motivazioni = 0;
 for ($num1 = 0 ; $num1 < $num_regole ; $num1 = $num1 + 1) {
-if ($celle == 1) echo "<tr>";
-$idregole = risul_query($regole,$num1,'idregole');
 $motivazione = risul_query($regole,$num1,'motivazione');
 if (!$motivazione) {
 $motivazione = " ";
 $motivazione_vedi = mex("nessuna",$pag);
 } # fine if (!$motivazione)
 else $motivazione_vedi = $motivazione;
+if (strtoupper($considera_motivazioni_regola1[$motivazione]) == $SI) $checked = " checked";
+else $checked = "";
+$regola1_consentita = 0;
+if ($attiva_regole1_consentite == "n" or $checked) $regola1_consentita = 1;
+else for ($num2 = 0 ; $num2 < count($regole1_consentite) ; $num2++) if ($regole1_consentite[$num2] == $motivazione) $regola1_consentita = 1;
+if ($regola1_consentita) {
+if ($celle == 1) echo "<tr>";
+$idregole = risul_query($regole,$num1,'idregole');
 if ($motivazioni_presenti[$motivazione] != "SI") {
 $motivazioni_presenti[$motivazione] = "SI";
 $var_motivazione = "var_mot_".$num_motivazioni;
 $num_motivazioni++;
-if (!$considera_motivazioni_regola1['array_esistente'] or strtoupper($considera_motivazioni_regola1[$motivazione]) == $SI) $checked = " checked";
-else $checked = "";
+if (!$considera_motivazioni_regola1['array_esistente']) $checked = " checked";
 echo "<td><label><input type=\"checkbox\" name=\"$var_motivazione\" value=\"$motivazione\"$checked> $motivazione_vedi</label></td>";
 if ($celle == $num_colonne) {
 echo "</tr>";
@@ -235,6 +264,7 @@ $celle = 0;
 } # fine if ($celle == 3)
 $celle++;
 } # fine if ($motivazioni_presenti[$motivazione] != "SI")
+} # fine if ($regola1_consentita)
 } # fine for $num1
 if ($celle != 1) {
 for ($num1 = $celle ; $num1 <= $num_colonne ; $num1++) echo "<td>&nbsp;</td>";
@@ -297,7 +327,9 @@ for ($num2 = 1 ; $num2 <= $num_valori ; $num2++) {
 $valore_corr = $valori_tema[$num2]['default'];
 if ($sel and $modello_esistente == "SI") $valore_corr = ${"valore_tema_".$num2};
 $js_opz_tema .= "".mex("Valore del tema",$pag)." \"".mex($template_theme_name[$num1],$pag)."\" ".mex("per",$pag)." \"".$valori_tema[$num2]['name']."\":\\
- <input type=\"text\" name=\"valore_tema_$num2\" id=\"valtema$num2\" size=\"24\" value=\"$valore_corr\"><br>";
+ <input type=\"text\" name=\"valore_tema_$num2\" id=\"valtema$num2\" size=\"24\" value=\"$valore_corr\">";
+if ($valori_tema[$num2]['img']) $js_opz_tema .= " ".upload_hd_img_form("valtema$num2",$tablepersonalizza,$num2,1);
+$js_opz_tema .= "<br>";
 } # fine for $num2
 $js_opz_tema .= "<\/td><\/tr><\/table>';
 }";
@@ -335,6 +367,7 @@ echo "<br>".mex("Parte html del file prima della form di disponibilità",$pag)."
 <textarea name=\"ultima_parte_html\" id=\"html_post\" rows=12 cols=110>
 $ultima_parte_html
 </textarea><br>
+".upload_hd_img_form("","","",2)."
 <script type=\"text/javascript\">
 <!--
 options_colori = '<option value=\"#ffffff\" style=\"background-color: #ffffff;\">&nbsp;<\/option>\\
@@ -408,6 +441,8 @@ echo "<br><div style=\"text-align: center;\"><input type=\"hidden\" name=\"$temp
 <button class=\"gobk\" type=\"submit\"><div>".mex("Torna indietro",$pag)."</div></button>
 </div></form><br></div>";
 
+} # fine if (function_exists('esegui_query'))
+
 
 
 ?>
\ No newline at end of file
