@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2018 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2019 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -305,10 +305,10 @@ $data_fissa_sel = "$data_preselezionata";
 } # fine if ($data_preselezionata)
 else $data_presel = "attuale";
 
-if (get_magic_quotes_gpc()) {
+if (@get_magic_quotes_gpc()) {
 $prima_parte_html = addslashes($prima_parte_html);
 $ultima_parte_html = addslashes($ultima_parte_html);
-} # fine if (get_magic_quotes_gpc())
+} # fine if (@get_magic_quotes_gpc())
 
 } # fine if ($continua != "NO")
 } # fine if ($var_per_crea_mod == "SI")
@@ -322,8 +322,8 @@ $ultima_parte_html = addslashes($ultima_parte_html);
 
 
 
-function crea_modello_cal ($percorso_cartella_modello,$anno_modello,$PHPR_TAB_PRE,$pag,$lingua_modello,$silenzio,$fr_frase,$frase,$num_frasi,$tipo_periodi) {
-global $num_periodi_date,$M_PHPR_DB_TYPE,$M_PHPR_DB_NAME,$M_PHPR_DB_HOST,$M_PHPR_DB_PORT,$M_PHPR_DB_USER,$M_PHPR_DB_PASS,$M_PHPR_LOAD_EXT,$M_PHPR_TAB_PRE,$estendi_ultima_data,$file_css_frame,$tema_modello;
+function crea_modello_cal ($percorso_cartella_modello,$anno_modello,$PHPR_TAB_PRE,$pag,$lingua_modello,$silenzio,$fr_frase,$frase,$num_frasi,$tipo_periodi,$lingua_orig="") {
+global $num_periodi_date,$M_PHPR_DB_TYPE,$M_PHPR_DB_NAME,$M_PHPR_DB_HOST,$M_PHPR_DB_PORT,$M_PHPR_DB_USER,$M_PHPR_DB_PASS,$M_PHPR_LOAD_EXT,$M_PHPR_TAB_PRE,$estendi_ultima_data,$file_css_frame,$tema_modello,$id_transazione,$id_utente;
 global $modello_esistente,$cambia_frasi,$template_data_dir,$template_file_name,$parola_settimane,$stile_tabella_cal,$prima_parte_html,$ultima_parte_html,$num_motivazioni,$apertura_tag_font,$chiusura_tag_font,$data_presel,$data_fissa_sel,$numero_giorni,$allinea_disponibilita_con_arrivo;
 global $mostra_quadro_disp,$mostra_numero_liberi_quadro_disponibilita,$colore_inizio_settimana_quadro_disponibilita,$colore_libero_quadro_disponibilita,$colore_occupato_quadro_disponibilita,$apertura_font_quadro_disponibilita,$chiusura_font_quadro_disponibilita;
 $tablenometariffe_modello = $PHPR_TAB_PRE."ntariffe".$anno_modello;
@@ -342,6 +342,30 @@ if (numlin_query($anno_esistente) != 1) $continua = "NO";
 } # fine else if (controlla_anno($anno_modello) != "SI")
 if ($continua != "NO") {
 
+if (!$lingua_orig) {
+global $lingua_mex;
+$lingua_orig = $lingua_mex;
+} # fine if (!$lingua_orig)
+$SI = mex("SI",$pag);
+$NO = mex("NO",$pag);
+
+if ($id_utente != 1) {
+global $anno,$attiva_regole1_consentite,$regole1_consentite,$attiva_tariffe_consentite,$tariffe_consentite_vett;
+$tariffe_mostra_tr = array();
+$considera_motivazioni_regola1_tr = array();
+if ($id_transazione) {
+$dati_transazione = recupera_dati_transazione($id_transazione,"",$anno,"SI",$tipo_transazione,"","NO");
+if ($tipo_transazione == "cpweb" and risul_query($dati_transazione,0,'spostamenti') == "cal") {
+$tariffe_mostra_tr = unserialize(risul_query($dati_transazione,0,'dati_transazione2'));
+$considera_motivazioni_regola1_tr = unserialize(risul_query($dati_transazione,0,'dati_transazione4'));
+} # fine if ($tipo_transazione == "cpweb" and risul_query($dati_transazione,0,'spostamenti') == "cal")
+} # fine if ($id_transazione)
+} # fine if ($id_utente != 1)
+else {
+$attiva_regole1_consentite = "n";
+$attiva_tariffe_consentite = "n";
+} # fine else if ($id_utente != 1)
+
 if ($estendi_ultima_data != "SI") $estendi_ultima_data = "NO";
 
 $date_in_menu = "";
@@ -378,7 +402,7 @@ ${"intervalloperiodo".$num1} = 1;
 if (!${"intervalloperiodo".$num1} or controlla_num_pos(${"intervalloperiodo".$num1}) == "NO" or ${"intervalloperiodo".$num1} > 99) $continua = "NO";
 } # fine for $num1
 if ($continua == "NO") {
-if ($silenzio == "NO") echo mex("Le date sono sbagliate",$pag).". <br>";
+if ($silenzio == "NO") echo mex2("Le date sono sbagliate",$pag,$lingua_orig).". <br>";
 } # fine if ($continua == "NO")
 else {
 $file_intero = file(C_DATI_PATH."/selectperiodi$anno_modello.1.php");
@@ -459,13 +483,15 @@ $numero_tariffe = risul_query($rigatariffe,0,'nomecostoagg');
 $tariffe_mostra = "";
 $nomi_tariffe_imposte = "";
 for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa++) {
+if ($attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[$numtariffa] == "SI" or strtoupper($tariffe_mostra_tr[$numtariffa]) == $SI) {
 $tariffa = "tariffa".$numtariffa;
 global $$tariffa;
-if ($$tariffa == "SI") $tariffe_mostra .= " $numtariffa => \"".mex("SI",$pag)."\",";
+if ($$tariffa == "SI") $tariffe_mostra .= " $numtariffa => \"$SI\",";
 $nome_tariffa_imposto = "nome_tariffa_imposto".$numtariffa;
 global $$nome_tariffa_imposto;
 $$nome_tariffa_imposto = formatta_input_var_x_file($$nome_tariffa_imposto);
 if ($$nome_tariffa_imposto) $nomi_tariffe_imposte .= "$numtariffa => \"".$$nome_tariffa_imposto."\",";
+} # fine if ($attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[$numtariffa] == "SI" or...
 } # fine for $numtariffa
 if ($tariffe_mostra) $tariffe_mostra = substr($tariffe_mostra,0,-1);
 if ($nomi_tariffe_imposte) $nomi_tariffe_imposte = substr($nomi_tariffe_imposte,0,-1);
@@ -473,7 +499,7 @@ if ($nomi_tariffe_imposte) $nomi_tariffe_imposte = substr($nomi_tariffe_imposte,
 if ($mostra_quadro_disp == "reg2") {
 $raggruppa_quadro_disponibilita_con_regola_2 = "SI";
 $regole2_esist = esegui_query("select * from $tableregole where tariffa_per_app is not NULL and tariffa_per_app != '' ");
-if (!numlin_query($regole2_esist) and $silenzio == "NO") echo "<span class=\"colblu\">".mext_cal("Attenzione",$pag)."</span>: ".mext_cal("è stato selezionato di raggruppare con le regole 2, ma non ne è stata inserita nessuna, quindi la tabella non verrà mostrata",$pag).".<br><br>";
+if (!numlin_query($regole2_esist) and $silenzio == "NO") echo "<span class=\"colblu\">".mext_cal("Attenzione",$pag,$lingua_orig)."</span>: ".mext_cal("è stato selezionato di raggruppare con le regole 2, ma non ne è stata inserita nessuna, quindi la tabella non verrà mostrata",$pag,$lingua_orig).".<br><br>";
 } # fine if ($mostra_quadro_disp == "reg2")
 else $raggruppa_quadro_disponibilita_con_regola_2 = "NO";
 if ($mostra_quadro_disp == "pers") $raggruppa_quadro_disponibilita_con_persone = "SI";
@@ -487,7 +513,10 @@ global $$var_motivazione;
 $motivazione = $$var_motivazione;
 if ($motivazione) {
 $motivazione = formatta_input_var_x_file($motivazione);
-$motivazioni_regola1 .= "\"$motivazione\" => \"".mex("SI",$pag)."\",";
+$regola1_consentita = 0;
+if ($attiva_regole1_consentite == "n" or strtoupper($considera_motivazioni_regola1_tr[$motivazione]) == $SI) $regola1_consentita = 1;
+else for ($num2 = 0 ; $num2 < count($regole1_consentite) ; $num2++) if ($regole1_consentite[$num2] == $motivazione) $regola1_consentita = 1;
+if ($regola1_consentita) $motivazioni_regola1 .= "\"$motivazione\" => \"$SI\",";
 } # fine if ($motivazione)
 } # fine for $num1
 if ($motivazioni_regola1) $motivazioni_regola1 = substr($motivazioni_regola1,0,-1);
@@ -520,6 +549,13 @@ elseif (strcmp($valori_tema[$num1]['replace'],"")) $valore_sost = str_replace("[
 $prima_parte_html = str_replace("[theme_value_$num1]",$valore_sost,$prima_parte_html);
 $ultima_parte_html = str_replace("[theme_value_$num1]",$valore_sost,$ultima_parte_html);
 $extra_head_frame = str_replace("[theme_value_$num1]",$valore_sost,$extra_head_frame);
+if ($valori_tema[$num1]['img'] and function_exists('upload_hd_img')) {
+global $lingua_mex;
+$lingua_mex_orig = $lingua_mex;
+$lingua_mex = $lingua_orig;
+upload_hd_img(${"valore_tema_".$num1},$num1);
+$lingua_mex = $lingua_mex_orig;
+} # fine if ($valori_tema[$num1]['img'] and function_exists('upload_hd_img'))
 } # fine for $num1
 $colori_tema = $template_theme_colors[$tema_sel];
 $num_colori = count($colori_tema);
@@ -570,13 +606,13 @@ $apertura_tag_font = formatta_input_var_x_file($apertura_tag_font);
 $chiusura_tag_font = formatta_input_var_x_file($chiusura_tag_font);
 $file_css_frame = formatta_input_var_x_file($file_css_frame);
 $extra_head_frame = formatta_input_var_x_file($extra_head_frame);
-if (get_magic_quotes_gpc()) $prima_parte_html = stripslashes($prima_parte_html);
+if (@get_magic_quotes_gpc()) $prima_parte_html = stripslashes($prima_parte_html);
 $prima_parte_html = str_replace("<?","ERROR",$prima_parte_html);
 $prima_parte_html = str_replace("?>","ERROR",$prima_parte_html);
 $prima_parte_html = str_replace("<%","ERROR",$prima_parte_html);
 $prima_parte_html = str_replace("%>","ERROR",$prima_parte_html);
 $prima_parte_html = preg_replace("/<script[^>]*php.*>/i","ERROR",$prima_parte_html);
-if (get_magic_quotes_gpc()) $ultima_parte_html = stripslashes($ultima_parte_html);
+if (@get_magic_quotes_gpc()) $ultima_parte_html = stripslashes($ultima_parte_html);
 $ultima_parte_html = str_replace("<?","ERROR",$ultima_parte_html);
 $ultima_parte_html = str_replace("?>","ERROR",$ultima_parte_html);
 $ultima_parte_html = str_replace("<%","ERROR",$ultima_parte_html);
@@ -717,7 +753,7 @@ define('C_PAGINA_WEB','1');
 \$PHPR_DB_PORT = \$".mex("var_porta_db",$pag).";
 \$PHPR_DB_USER = \$".mex("var_utente_db",$pag).";
 \$PHPR_DB_PASS = \$".mex("var_password_db",$pag).";
-if (strtoupper(\$".mex("var_carica_estensione_db",$pag).") == \"".mex("SI",$pag)."\") \$PHPR_LOAD_EXT = \"SI\";
+if (strtoupper(\$".mex("var_carica_estensione_db",$pag).") == \"$SI\") \$PHPR_LOAD_EXT = \"SI\";
 else \$PHPR_LOAD_EXT = \"NO\";
 \$PHPR_TAB_PRE = \$".mex("var_prefisso_tabelle_db",$pag).";
 ");
@@ -738,36 +774,36 @@ if (strcmp(\$HOTELD_DB_PASS,\"\")) \$PHPR_DB_PASS = \$HOTELD_DB_PASS;
 if (\$HOTELD_TAB_PRE) \$PHPR_TAB_PRE = \$HOTELD_TAB_PRE;
 ");
 fwrite($file,"\$lingua_modello = \$".mex("var_lingua_modello",$pag).";
-if (strtoupper(\$".mex("var_estendi_ultima_data",$pag).") == \"".mex("SI",$pag)."\") \$estendi_ultima_data = \"SI\";
+if (strtoupper(\$".mex("var_estendi_ultima_data",$pag).") == \"$SI\") \$estendi_ultima_data = \"SI\";
 else \$estendi_ultima_data = \"NO\";
 unset(\$tariffe_mostra);
 reset (\$".mex("var_tariffe_mostra",$pag).");
 foreach (\$".mex("var_tariffe_mostra",$pag)." as \$key => \$val) {
-if (strtoupper(\$val) == \"".mex("SI",$pag)."\") \$tariffe_mostra[\$key] = \"SI\";
-if (strtoupper(\$val) == \"".mex("NO",$pag)."\") \$tariffe_mostra[\$key] = \"NO\";
+if (strtoupper(\$val) == \"$SI\") \$tariffe_mostra[\$key] = \"SI\";
+if (strtoupper(\$val) == \"$NO\") \$tariffe_mostra[\$key] = \"NO\";
 } # fine foreach
 \$n_tariffe_imposte = \$".mex("var_nomi_tariffe_imposte",$pag).";
 unset(\$motivazioni_regola1);
 reset (\$".mex("var_considera_motivazioni_regola1",$pag).");
 foreach (\$".mex("var_considera_motivazioni_regola1",$pag)." as \$key => \$val) {
-if (strtoupper(\$val) == \"".mex("SI",$pag)."\") \$motivazioni_regola1[\$key] = \"SI\";
-if (strtoupper(\$val) == \"".mex("NO",$pag)."\") \$motivazioni_regola1[\$key] = \"NO\";
+if (strtoupper(\$val) == \"$SI\") \$motivazioni_regola1[\$key] = \"SI\";
+if (strtoupper(\$val) == \"$NO\") \$motivazioni_regola1[\$key] = \"NO\";
 } # fine foreach
 \$data_preselezionata = \$".mext_cal("var_data_preselezionata",$pag).";
 \$numero_giorni = \$".mext_cal("var_numero_giorni",$pag).";
-if (strtoupper(\$".mex("var_allinea_disponibilita_con_arrivo",$pag).") == \"".mex("SI",$pag)."\") \$allinea_disponibilita_con_arrivo = \"SI\";
+if (strtoupper(\$".mex("var_allinea_disponibilita_con_arrivo",$pag).") == \"$SI\") \$allinea_disponibilita_con_arrivo = \"SI\";
 else \$allinea_disponibilita_con_arrivo = \"NO\";
 
 \$mostra_quadro_disp = \"app\";
-if (strtoupper(\$".mex("var_raggruppa_quadro_disponibilita_con_persone",$pag).") == \"".mex("SI",$pag)."\") \$mostra_quadro_disp = \"pers\";
-if (strtoupper(\$".mex("var_raggruppa_quadro_disponibilita_con_regola_2",$pag).") == \"".mex("SI",$pag)."\") \$mostra_quadro_disp = \"reg2\";
+if (strtoupper(\$".mex("var_raggruppa_quadro_disponibilita_con_persone",$pag).") == \"$SI\") \$mostra_quadro_disp = \"pers\";
+if (strtoupper(\$".mex("var_raggruppa_quadro_disponibilita_con_regola_2",$pag).") == \"$SI\") \$mostra_quadro_disp = \"reg2\";
 \$stile_tabella_cal = \$".mext_cal("var_stile_tabella_cal",$pag).";
 \$c_inisett_tab_disp = \$".mex("var_colore_inizio_settimana_quadro_disponibilita",$pag).";
 \$c_libero_tab_disp = \$".mex("var_colore_libero_quadro_disponibilita",$pag).";
 \$c_occupato_tab_disp = \$".mex("var_colore_occupato_quadro_disponibilita",$pag) .";
 \$aper_font_tab_disp = \$".mex("var_apertura_font_quadro_disponibilita",$pag).";
 \$chiu_font_tab_disp = \$".mex("var_chiusura_font_quadro_disponibilita",$pag).";
-if (strtoupper(\$".mex("var_mostra_numero_liberi_quadro_disponibilita",$pag).") == \"".mex("SI",$pag)."\") \$mostra_num_liberi = \"SI\";
+if (strtoupper(\$".mex("var_mostra_numero_liberi_quadro_disponibilita",$pag).") == \"$SI\") \$mostra_num_liberi = \"SI\";
 else \$mostra_num_liberi = \"NO\";
 
 \$apertura_tag_font = \$".mex("var_apertura_tag_font",$pag).";
@@ -807,6 +843,13 @@ includi_file("./includes/funzioni.php",$file);
 includi_file("./includes/liberasettimane.php",$file);
 includi_file("./includes/funzioni_tariffe.php",$file);
 includi_file("./includes/funzioni_quadro_disp.php",$file);
+
+if (defined('C_NUM_HOSTING') and C_NUM_HOSTING != "") {
+fwrite($file,"
+if (!defined('C_NUM_HOSTING')) define('C_NUM_HOSTING','".C_NUM_HOSTING."');
+");
+} # fine if (defined('C_NUM_HOSTING') and C_NUM_HOSTING != "")
+
 if (defined("C_FILE_SCADENZA_ACCOUNT") and C_FILE_SCADENZA_ACCOUNT != "") {
 $f_scad_acc = explode("/",$percorso_cartella_modello);
 $num_f_scad_acc = count($f_scad_acc);
@@ -857,10 +900,10 @@ else $url_pagina_link = "$percorso_cartella_modello/$nome_file";
 } # fine if ($silenzio != "totale")
 
 if ($silenzio == "NO") echo "<br>";
-if ($silenzio != "totale") echo mex("Una pagina chiamata",$pag)." <b><a href=\"$url_pagina_link\" target=\"_blank\">$nome_file</a></b> ".mex("è stata creata nella directory",$pag)." \"$percorso_cartella_modello\".<br>";
+if ($silenzio != "totale") echo mex2("Una pagina chiamata",$pag,$lingua_orig)." <b><a href=\"$url_pagina_link\" target=\"_blank\">$nome_file</a></b> ".mex2("è stata creata nella directory",$pag,$lingua_orig)." \"$percorso_cartella_modello\".<br>";
 if ($silenzio == "NO") {
-if (defined("C_CARTELLA_CREA_MODELLI")) echo mex("Si può creare un link verso questa pagina dal proprio sito internet",$pag).".<br>";
-else echo mex("Si può cambiare la directory dove vengono create le pagine da \"configura e personalizza\"",$pag).".<br>";
+if (defined("C_CARTELLA_CREA_MODELLI")) echo mex2("Si può creare un link verso questa pagina dal proprio sito internet",$pag,$lingua_orig).".<br>";
+else echo mex2("Si può cambiare la directory dove vengono create le pagine da \"configura e personalizza\"",$pag,$lingua_orig).".<br>";
 
 if (defined("C_FILE_DOMINIO") and C_FILE_DOMINIO != "" and C_NASCONDI_MARCA != "SI") {
 $altri_domini = @file(C_FILE_DOMINIO);
@@ -878,18 +921,18 @@ else $altro_dominio = "http://";
 $altro_dominio .= trim($altri_domini[$num1])."/$percorso_cartella_dominio$nome_file";
 if ($altro_dominio != $url_pagina_link) {
 $lista_altri_domini .= "<b><a href=\"$altro_dominio\" target=\"_blank\">$altro_dominio</a></b>";
-if ($num1 == 0) $lista_altri_domini .= " (".mex("sicuro",$pag).")";
+if ($num1 == 0) $lista_altri_domini .= " (".mex2("sicuro",$pag,$lingua_orig).")";
 $lista_altri_domini .= "<br>";
 } # fine if ($altro_dominio != $url_pagina_link)
 } # fine for $num1
-if ($lista_altri_domini) echo "<br><br>".mex("Indirizzi alternativi da cui la pagina è raggiungibile",$pag).":<br><div class=\"linhbox\">$lista_altri_domini</div>";
+if ($lista_altri_domini) echo "<br><br>".mex2("Indirizzi alternativi da cui la pagina è raggiungibile",$pag,$lingua_orig).":<br><div class=\"linhbox\">$lista_altri_domini</div>";
 } # fine if ($altri_domini)
 } # fine if (defined("C_FILE_DOMINIO") and C_FILE_DOMINIO != "" and C_NASCONDI_MARCA != "SI")
 
 echo "<br>";
 } # fine if ($silenzio == "NO")
 } # fine if ($file)
-else if ($silenzio == "NO") echo mex("Non ho il permesso di scrittura nella cartella",$pag)." $percorso_cartella_modello.<br>";
+else if ($silenzio == "NO") echo mex2("Non ho il permesso di scrittura nella cartella",$pag),$lingua_orig." $percorso_cartella_modello.<br>";
 
 } # fine if ($continua != "NO")
 
