@@ -26,6 +26,7 @@ global $template_theme_name,$template_theme_colors,$template_theme_values,$templ
 
 $template_theme_name = array();
 $template_theme_colors = array();
+$template_theme_values = array();
 $template_theme_html_pre = array();
 $template_theme_html_post = array();
 
@@ -43,6 +44,7 @@ $template_theme_values[1][2]['name'] = mex("URL del logo",$pag);
 $template_theme_values[1][2]['default'] = $dati_struttura[15];
 $template_theme_values[1][2]['replace'] = "<img style=\"text-decoration: none; border: 0px;\" src=\"[theme_value_2]\" alt=\"[theme_value_3]\">";
 $template_theme_values[1][2]['null'] = "[theme_value_3]";
+$template_theme_values[1][2]['img'] = 1;
 $template_theme_values[1][3]['name'] = mex("Torna alla HOME",$pag);
 $template_theme_values[1][3]['default'] = mex2("Torna alla HOME",$pag,$lingua_modello);
 $template_theme_values[1][4]['name'] = mex("URL file css",$pag);
