@@ -119,11 +119,14 @@ $url_dir = "";
 global $PHP_SELF,$SERVER_NAME,$HTTP_SERVER_VARS,$HTTPS,$SERVER_PORT;
 if (@$SERVER_NAME or @$_SERVER['SERVER_NAME'] or @$HTTP_SERVER_VARS['SERVER_NAME']) {
 if (@$PHP_SELF or @$_SERVER['PHP_SELF']) {
+if ($_SERVER['SERVER_PORT']) $SERVER_PORT = $_SERVER['SERVER_PORT'];
+elseif ($HTTP_SERVER_VARS['SERVER_PORT']) $SERVER_PORT = $HTTP_SERVER_VARS['SERVER_PORT'];
 if ($_SERVER['SERVER_NAME']) $SERVER_NAME = $_SERVER['SERVER_NAME'];
 elseif ($HTTP_SERVER_VARS['SERVER_NAME']) $SERVER_NAME = $HTTP_SERVER_VARS['SERVER_NAME'];
 if ($_SERVER['PHP_SELF']) $PHP_SELF = $_SERVER['PHP_SELF'];
-if ($HTTPS == "on" or $_SERVER['HTTPS'] == "on" or $SERVER_PORT == "443" or $_SERVER['SERVER_PORT'] == "443") $url_server = "https://".$SERVER_NAME;
+if ($HTTPS == "on" or $_SERVER['HTTPS'] == "on" or $SERVER_PORT == "443") $url_server = "https://".$SERVER_NAME;
 else $url_server = "http://".$SERVER_NAME;
+if ($SERVER_PORT and $SERVER_PORT != "80" and $SERVER_PORT != "443") $url_server .= ":$SERVER_PORT";
 if (substr($PHP_SELF,0,1) != "/") $PHP_SELF = "/".$PHP_SELF;
 $url_dir = $url_server.$PHP_SELF;
 if (substr($url_dir,(strlen($pag) * -1)) == $pag) $url_dir = substr($url_dir,0,(strlen($pag) * -1));
