@@ -22,6 +22,8 @@
 
 
 
+if (function_exists('esegui_query')) {
+
 if (preg_replace("/[a-z]/","",$template_data_dir) != "") $template_data_dir = "";
 include("./includes/templates/$template_data_dir/phrases.php");
 
@@ -34,22 +36,42 @@ esegui_query("insert into $tablepersonalizza (idpersonalizza,valpersonalizza,idu
 # Prendo i dati dal file se già esistente
 if ($template_file_name[$lingua_modello]) $nome_file = $template_file_name[$lingua_modello];
 else {
-$nome_file = mext_rat($template_file_name["ita"],$pag,$lingua_modello);
-if ($nome_file == $template_file_name["en"] or $nome_file == $template_file_name["ita"]) $nome_file = $lingua_modello."_".$template_file_name['en'];
+$nome_file = mext_rat($template_file_name['ita'],$pag,$lingua_modello);
+if ($nome_file == $template_file_name['en'] or $nome_file == $template_file_name['ita']) $nome_file = $lingua_modello."_".$template_file_name['en'];
 } # fine else if ($template_file_name[$lingua_modello])
-$SI = mex("SI",$pag);
-$NO = mex("NO",$pag);
+$SI = mex2("SI",$pag,$lingua_mex_1);
+$NO = mex2("NO",$pag,$lingua_mex_1);
 $modello_esistente = "NO";
+unset($id_transazione);
 if (@is_file("$percorso_cartella_modello/$nome_file")) {
 $modello_esistente = "SI";
+$lingua_mex = $lingua_mex_1;
 include("./includes/templates/$template_data_dir/functions.php");
 recupera_var_modello_rat($nome_file,$percorso_cartella_modello,$pag,$fr_frase,$num_frasi,$var_mod,$num_var_mod,$tipo_periodi,"NO",$anno_modello,$PHPR_TAB_PRE);
+$lingua_mex = $lingua_orig;
+
+$tabelle_lock = array($tableversioni,$tabletransazioni);
+$tabelle_lock = lock_tabelle($tabelle_lock);
+$adesso = date("YmdHis",(time() + (C_DIFF_ORE * 3600)));
+list($usec, $sec) = explode(' ', microtime());
+mt_srand((float) $sec + ((float) $usec * 100000));
+$val_casuale = mt_rand(100000,999999);
+$versione_transazione = prendi_numero_versione($tableversioni);
+$id_transazione = $adesso.$val_casuale.$versione_transazione;
+$ultimo_accesso = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
+esegui_query("delete from $tabletransazioni where spostamenti = '$modello_ext' and tipo_transazione = 'cpweb' ");
+$dati_tr2 = aggslashdb(serialize($tariffe_mostra));
+$dati_tr3 = aggslashdb(serialize($costi_aggiuntivi_mostra));
+esegui_query("insert into $tabletransazioni (idtransazioni,idsessione,tipo_transazione,anno,spostamenti,dati_transazione2,dati_transazione3,ultimo_accesso) 
+values ('$id_transazione','$id_sessione','cpweb','$anno','$modello_ext','$dati_tr2','$dati_tr3','$ultimo_accesso')");
+unlock_tabelle($tabelle_lock);
 } # fine if (@is_file("$percorso_cartella_modello/$nome_file"))
 
 
-echo "<form method=\"post\" action=\"crea_modelli.php\"><div>
+echo "<form method=\"post\" action=\"crea_modelli.php\" enctype=\"multipart/form-data\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
+<input type=\"hidden\" name=\"id_transazione\" value=\"$id_transazione\">
 <input type=\"hidden\" name=\"crea_modello\" value=\"SI\">
 <input type=\"hidden\" name=\"fonte_dati_conn\" value=\"$fonte_dati_conn\">
 <input type=\"hidden\" name=\"T_PHPR_DB_TYPE\" value=\"".htmlspecialchars($T_PHPR_DB_TYPE)."\">
@@ -160,6 +182,9 @@ $tablenometariffe_modello = $PHPR_TAB_PRE."ntariffe".$anno_modello;
 $rigatariffe = esegui_query("select * from $tablenometariffe_modello where idntariffe = 1 ");
 $numero_tariffe = risul_query($rigatariffe,0,'nomecostoagg');
 for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa++) {
+if (strtoupper($tariffe_mostra[$numtariffa]) == $SI) $checked = " checked";
+else $checked = "";
+if ($attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[$numtariffa] == "SI" or $checked) {
 if ($celle == 1) echo "<tr>";
 $tariffa = "tariffa".$numtariffa;
 $nometariffa=risul_query($rigatariffe,0,$tariffa);
@@ -169,8 +194,6 @@ $nometariffa_vedi = mex("tariffa",$pag).$numtariffa;
 } # fine if ($nometariffa == "")
 else $nometariffa_vedi = $nometariffa;
 $nome_tariffa_imposto = "nome_tariffa_imposto".$numtariffa;
-if (strtoupper($tariffe_mostra[$numtariffa]) == $SI) $checked = " checked";
-else $checked = "";
 if (!$tariffe_mostra["array_esistente"]) $checked = " checked";
 $val = "";
 if ($nomi_tariffe_imposte["array_esistente"]) $val = $nomi_tariffe_imposte[$numtariffa];
@@ -181,6 +204,7 @@ echo "</tr>";
 $celle = 0;
 } # fine if ($celle == $num_colonne)
 $celle++;
+} # fine if ($attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[$numtariffa] == "SI" or $checked)
 } # fine for $numtariffa
 if ($celle != 1) {
 for ($num1 = $celle ; $num1 <= $num_colonne ; $num1++) echo "<td>&nbsp;</td>";
@@ -202,12 +226,14 @@ echo "".mex("Costi aggiuntivi da mostrare ed eventuali loro nomi sostitutivi con
 $celle = 1;
 $num_colonne = 2;
 for ($numca = 0 ; $numca < $dati_ca['num'] ; $numca++) {
+if (strtoupper($costi_aggiuntivi_mostra[$dati_ca[$numca]['id']]) == $SI) $checked = " checked";
+else $checked = "";
+if ($attiva_costi_agg_consentiti == "n" or $costi_agg_consentiti_vett[$dati_ca[$numca]['id']] == "SI" or $checked) {
 if ($celle == 1) echo "<tr>";
 if ($dati_ca[$numca]['tipo'] == "u") $tipo_costo = "Costo unico";
 if ($dati_ca[$numca]['tipo'] == "s") $tipo_costo = "Costo $parola_settimanale";
 $nome_costo_imposto = "nome_costo_imposto".$dati_ca[$numca]['id'];
-if (!$costi_aggiuntivi_mostra["array_esistente"] or strtoupper($costi_aggiuntivi_mostra[$dati_ca[$numca]['id']]) == $SI) $checked = " checked";
-else $checked = "";
+if (!$costi_aggiuntivi_mostra["array_esistente"]) $checked = " checked";
 if ($nomi_costi_agg_imposti[$dati_ca[$numca]['id']]) $val = htmlspecialchars($nomi_costi_agg_imposti[$dati_ca[$numca]['id']]);
 else $val = "";
 echo "<td><label><input type=\"checkbox\" name=\"attiva_costo".$dati_ca[$numca]['id']."\" value=\"SI\"$checked>".mex("$tipo_costo",$pag)." <em>".$dati_ca[$numca]['nome']."</em></label>:
@@ -217,6 +243,7 @@ echo "</tr>";
 $celle = 0;
 } # fine if ($celle == $num_colonne)
 $celle++;
+} # fine if ($attiva_costi_agg_consentiti == "n" or $costi_agg_consentiti_vett[$dati_ca[$numca]['id']] == "SI" or $checked)
 } # fine for $numca
 if ($celle != 1) {
 for ($num1 = $celle ; $num1 <= $num_colonne ; $num1++) echo "<td>&nbsp;</td>";
@@ -280,7 +307,9 @@ for ($num2 = 1 ; $num2 <= $num_valori ; $num2++) {
 $valore_corr = $valori_tema[$num2]['default'];
 if ($sel and $modello_esistente == "SI") $valore_corr = ${"valore_tema_".$num2};
 $js_opz_tema .= "".mex("Valore del tema",$pag)." \"".mex($template_theme_name[$num1],$pag)."\" ".mex("per",$pag)." \"".$valori_tema[$num2]['name']."\":\\
- <input type=\"text\" name=\"valore_tema_$num2\" id=\"valtema$num2\" size=\"24\" value=\"$valore_corr\"><br>";
+ <input type=\"text\" name=\"valore_tema_$num2\" id=\"valtema$num2\" size=\"24\" value=\"$valore_corr\">";
+if ($valori_tema[$num2]['img']) $js_opz_tema .= " ".upload_hd_img_form("valtema$num2",$tablepersonalizza,$num2,1);
+$js_opz_tema .= "<br>";
 } # fine for $num2
 $js_opz_tema .= "<\/td><\/tr><\/table>';
 }";
@@ -318,6 +347,7 @@ echo "<br>".mex("Parte html del file prima della form di disponibilità",$pag)."
 <textarea name=\"ultima_parte_html\" id=\"html_post\" rows=12 cols=110>
 $ultima_parte_html
 </textarea><br>
+".upload_hd_img_form("","","",2)."
 <script type=\"text/javascript\">
 <!--
 options_colori = '<option value=\"#ffffff\" style=\"background-color: #ffffff;\">&nbsp;<\/option>\\
@@ -392,6 +422,8 @@ echo "<br><div style=\"text-align: center;\"><input type=\"hidden\" name=\"$temp
 <button class=\"gobk\" type=\"submit\"><div>".mex("Torna indietro",$pag)."</div></button>
 </div></form><br></div>";
 
+} # fine if (function_exists('esegui_query'))
+
 
 
 ?>
\ No newline at end of file
