@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2018 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2019 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -281,10 +281,10 @@ $$nome_costo_imposto = $nomi_costi_agg_imposti[$dati_ca[$numca]['id']];
 if (strtoupper($mostra_caparra) == $SI) $mostra_caparra = "SI";
 else $mostra_caparra = "NO";
 
-if (get_magic_quotes_gpc()) {
+if (@get_magic_quotes_gpc()) {
 $prima_parte_html = addslashes($prima_parte_html);
 $ultima_parte_html = addslashes($ultima_parte_html);
-} # fine if (get_magic_quotes_gpc())
+} # fine if (@get_magic_quotes_gpc())
 
 } # fine if ($continua != "NO")
 } # fine if ($var_per_crea_mod == "SI")
@@ -298,10 +298,10 @@ $ultima_parte_html = addslashes($ultima_parte_html);
 
 
 
-function crea_modello_rat ($percorso_cartella_modello,$anno_modello,$PHPR_TAB_PRE,$pag,$lingua_modello,$silenzio,$fr_frase,$frase,$num_frasi,$tipo_periodi) {
+function crea_modello_rat ($percorso_cartella_modello,$anno_modello,$PHPR_TAB_PRE,$pag,$lingua_modello,$silenzio,$fr_frase,$frase,$num_frasi,$tipo_periodi,$lingua_orig="") {
 global $num_periodi_date,$M_PHPR_DB_TYPE,$M_PHPR_DB_NAME,$M_PHPR_DB_HOST,$M_PHPR_DB_PORT,$M_PHPR_DB_USER,$M_PHPR_DB_PASS,$M_PHPR_LOAD_EXT,$M_PHPR_TAB_PRE,$estendi_ultima_data,$mostra_date_passate;
-global $m_stile_soldi,$m_stile_data,$anteponi_nome_valuta,$mostra_caparra,$modello_esistente,$cambia_frasi,$template_data_dir,$template_file_name,$parola_settimane;
-global $apertura_tag_font,$chiusura_tag_font,$stile_tabella_tariffe,$m_valuta_sing,$m_valuta_plur,$prima_parte_html,$ultima_parte_html,$file_css_frame,$tema_modello;
+global $m_stile_soldi,$m_stile_data,$anteponi_nome_valuta,$mostra_caparra,$modello_esistente,$cambia_frasi,$template_data_dir,$template_file_name,$parola_settimane,$id_utente;
+global $apertura_tag_font,$chiusura_tag_font,$stile_tabella_tariffe,$m_valuta_sing,$m_valuta_plur,$prima_parte_html,$ultima_parte_html,$file_css_frame,$tema_modello,$id_transazione;
 $tablenometariffe_modello = $PHPR_TAB_PRE."ntariffe".$anno_modello;
 $tableperiodi_modello = $PHPR_TAB_PRE."periodi".$anno_modello;
 $tableanni = $PHPR_TAB_PRE."anni";
@@ -316,6 +316,30 @@ if (numlin_query($anno_esistente) != 1) $continua = "NO";
 } # fine else if (controlla_anno($anno_modello) != "SI")
 if ($continua != "NO") {
 
+if (!$lingua_orig) {
+global $lingua_mex;
+$lingua_orig = $lingua_mex;
+} # fine if (!$lingua_orig)
+$SI = mex("SI",$pag);
+$NO = mex("NO",$pag);
+
+if ($id_utente != 1) {
+global $anno,$attiva_tariffe_consentite,$tariffe_consentite_vett,$attiva_costi_agg_consentiti,$costi_agg_consentiti_vett;
+$tariffe_mostra_tr = array();
+$costi_aggiuntivi_mostra_tr = array();
+if ($id_transazione) {
+$dati_transazione = recupera_dati_transazione($id_transazione,"",$anno,"SI",$tipo_transazione,"","NO");
+if ($tipo_transazione == "cpweb" and risul_query($dati_transazione,0,'spostamenti') == "rat") {
+$tariffe_mostra_tr = unserialize(risul_query($dati_transazione,0,'dati_transazione2'));
+$costi_aggiuntivi_mostra_tr = unserialize(risul_query($dati_transazione,0,'dati_transazione3'));
+} # fine if ($tipo_transazione == "cpweb" and risul_query($dati_transazione,0,'spostamenti') == "rat")
+} # fine if ($id_transazione)
+} # fine if ($id_utente != 1)
+else {
+$attiva_tariffe_consentite = "n";
+$attiva_costi_agg_consentiti = "n";
+} # fine else if ($id_utente != 1)
+
 if ($estendi_ultima_data != "SI") $estendi_ultima_data = "NO";
 if ($mostra_date_passate != "NO") $mostra_date_passate = "SI";
 
@@ -351,7 +375,7 @@ ${"intervalloperiodo".$num1} = aggslashdb(${"intervalloperiodo".$num1});
 if (!${"intervalloperiodo".$num1} or controlla_num_pos(${"intervalloperiodo".$num1}) == "NO" or ${"intervalloperiodo".$num1} > 99) $continua = "NO";
 } # fine for $num1
 if ($continua == "NO") {
-if ($silenzio == "NO") echo mex("Le date sono sbagliate",$pag).". <br>";
+if ($silenzio == "NO") echo mex2("Le date sono sbagliate",$pag,$lingua_orig).". <br>";
 } # fine if ($continua == "NO")
 else {
 $file_intero = file(C_DATI_PATH."/selectperiodi$anno_modello.1.php");
@@ -426,13 +450,15 @@ $numero_tariffe = risul_query($rigatariffe,0,'nomecostoagg');
 $tariffe_mostra = "";
 $nomi_tariffe_imposte = "";
 for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa++) {
+if ($attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[$numtariffa] == "SI" or strtoupper($tariffe_mostra_tr[$numtariffa]) == $SI) {
 $tariffa = "tariffa".$numtariffa;
 global $$tariffa;
-if ($$tariffa == "SI") $tariffe_mostra .= " $numtariffa => \"".mex("SI",$pag)."\",";
+if ($$tariffa == "SI") $tariffe_mostra .= " $numtariffa => \"$SI\",";
 $nome_tariffa_imposto = "nome_tariffa_imposto".$numtariffa;
 global $$nome_tariffa_imposto;
 $$nome_tariffa_imposto = formatta_input_var_x_file($$nome_tariffa_imposto);
 if ($$nome_tariffa_imposto) $nomi_tariffe_imposte .= "$numtariffa => \"".$$nome_tariffa_imposto."\",";
+} # fine if ($attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[$numtariffa] == "SI" or...
 } # fine for $numtariffa
 if ($tariffe_mostra) $tariffe_mostra = substr($tariffe_mostra,0,-1);
 if ($nomi_tariffe_imposte) $nomi_tariffe_imposte = substr($nomi_tariffe_imposte,0,-1);
@@ -440,15 +466,17 @@ if ($nomi_tariffe_imposte) $nomi_tariffe_imposte = substr($nomi_tariffe_imposte,
 unset($nomi_costi_imposti);
 unset($costi_attivati);
 for ($numca = 0 ; $numca < $dati_ca['num'] ; $numca++) {
+if ($attiva_costi_agg_consentiti == "n" or $costi_agg_consentiti_vett[$dati_ca[$numca]['id']] == "SI" or strtoupper($costi_aggiuntivi_mostra_tr[$dati_ca[$numca]['id']]) == $SI) {
 global ${"attiva_costo".$dati_ca[$numca]['id']};
 if (${"attiva_costo".$dati_ca[$numca]['id']} == "SI") {
-$costi_attivati .= " ".$dati_ca[$numca]['id']." => \"".mex("SI",$pag)."\",";
+$costi_attivati .= " ".$dati_ca[$numca]['id']." => \"$SI\",";
 $nome_costo_imposto = "nome_costo_imposto".$dati_ca[$numca]['id'];
 global $$nome_costo_imposto;
 $$nome_costo_imposto = formatta_input_var_x_file($$nome_costo_imposto);
 if ($$nome_costo_imposto) $nomi_costi_imposti .= $dati_ca[$numca]['id']." => \"".$$nome_costo_imposto."\",";
 } # fine if (${"attiva_costo".$dati_ca[$numca][id]} == "SI")
-} # fine for $num1
+} # fine if ($attiva_costi_agg_consentiti == "n" or $costi_agg_consentiti_vett[$dati_ca[$numca]['id']] == "SI" or...
+} # fine for $numca
 if ($nomi_costi_imposti) $nomi_costi_imposti = substr($nomi_costi_imposti,0,-1);
 if ($costi_attivati) $costi_attivati = substr($costi_attivati,0,-1);
 
@@ -480,6 +508,13 @@ elseif (strcmp($valori_tema[$num1]['replace'],"")) $valore_sost = str_replace("[
 $prima_parte_html = str_replace("[theme_value_$num1]",$valore_sost,$prima_parte_html);
 $ultima_parte_html = str_replace("[theme_value_$num1]",$valore_sost,$ultima_parte_html);
 $extra_head_frame = str_replace("[theme_value_$num1]",$valore_sost,$extra_head_frame);
+if ($valori_tema[$num1]['img'] and function_exists('upload_hd_img')) {
+global $lingua_mex;
+$lingua_mex_orig = $lingua_mex;
+$lingua_mex = $lingua_orig;
+upload_hd_img(${"valore_tema_".$num1},$num1);
+$lingua_mex = $lingua_mex_orig;
+} # fine if ($valori_tema[$num1]['img'] and function_exists('upload_hd_img'))
 } # fine for $num1
 $colori_tema = $template_theme_colors[$tema_sel];
 $num_colori = count($colori_tema);
@@ -531,13 +566,13 @@ $m_valuta_sing = formatta_input_var_x_file($m_valuta_sing);
 $m_valuta_plur = formatta_input_var_x_file($m_valuta_plur);
 $file_css_frame = formatta_input_var_x_file($file_css_frame);
 $extra_head_frame = formatta_input_var_x_file($extra_head_frame);
-if (get_magic_quotes_gpc()) $prima_parte_html = stripslashes($prima_parte_html);
+if (@get_magic_quotes_gpc()) $prima_parte_html = stripslashes($prima_parte_html);
 $prima_parte_html = str_replace("<?","ERROR",$prima_parte_html);
 $prima_parte_html = str_replace("?>","ERROR",$prima_parte_html);
 $prima_parte_html = str_replace("<%","ERROR",$prima_parte_html);
 $prima_parte_html = str_replace("%>","ERROR",$prima_parte_html);
 $prima_parte_html = preg_replace("/<script[^>]*php.*>/i","ERROR",$prima_parte_html);
-if (get_magic_quotes_gpc()) $ultima_parte_html = stripslashes($ultima_parte_html);
+if (@get_magic_quotes_gpc()) $ultima_parte_html = stripslashes($ultima_parte_html);
 $ultima_parte_html = str_replace("<?","ERROR",$ultima_parte_html);
 $ultima_parte_html = str_replace("?>","ERROR",$ultima_parte_html);
 $ultima_parte_html = str_replace("<%","ERROR",$ultima_parte_html);
@@ -674,7 +709,7 @@ define('C_PAGINA_WEB','1');
 \$PHPR_DB_PORT = \$".mex("var_porta_db",$pag).";
 \$PHPR_DB_USER = \$".mex("var_utente_db",$pag).";
 \$PHPR_DB_PASS = \$".mex("var_password_db",$pag).";
-if (strtoupper(\$".mex("var_carica_estensione_db",$pag).") == \"".mex("SI",$pag)."\") \$PHPR_LOAD_EXT = \"SI\";
+if (strtoupper(\$".mex("var_carica_estensione_db",$pag).") == \"$SI\") \$PHPR_LOAD_EXT = \"SI\";
 else \$PHPR_LOAD_EXT = \"NO\";
 \$PHPR_TAB_PRE = \$".mex("var_prefisso_tabelle_db",$pag).";
 ");
@@ -699,27 +734,27 @@ if (\$".mex("var_stile_soldi",$pag)." == \"".mex("europa",$pag)."\") \$stile_sol
 if (\$".mex("var_stile_soldi",$pag)." == \"".mex("usa",$pag)."\") \$stile_soldi = \"usa\";
 if (\$".mex("var_stile_data",$pag)." == \"".mex("europa",$pag)."\") \$stile_data = \"europa\";
 if (\$".mex("var_stile_data",$pag)." == \"".mex("usa",$pag)."\") \$stile_data = \"usa\";
-if (strtoupper(\$".mex("var_anteponi_nome_valuta",$pag).") == \"".mex("SI",$pag)."\") \$anteponi_nome_valuta = \"SI\";
+if (strtoupper(\$".mex("var_anteponi_nome_valuta",$pag).") == \"$SI\") \$anteponi_nome_valuta = \"SI\";
 else \$anteponi_nome_valuta = \"NO\";
-if (strtoupper(\$".mex("var_estendi_ultima_data",$pag).") == \"".mex("SI",$pag)."\") \$estendi_ultima_data = \"SI\";
+if (strtoupper(\$".mex("var_estendi_ultima_data",$pag).") == \"$SI\") \$estendi_ultima_data = \"SI\";
 else \$estendi_ultima_data = \"NO\";
-if (strtoupper(\$".mex("var_mostra_date_passate",$pag).") == \"".mex("NO",$pag)."\") \$mostra_date_passate = \"NO\";
+if (strtoupper(\$".mex("var_mostra_date_passate",$pag).") == \"$NO\") \$mostra_date_passate = \"NO\";
 else \$mostra_date_passate = \"SI\";
 unset(\$tariffe_mostra);
 reset (\$".mex("var_tariffe_mostra",$pag).");
 foreach (\$".mex("var_tariffe_mostra",$pag)." as \$key => \$val) {
-if (strtoupper(\$val) == \"".mex("SI",$pag)."\") \$tariffe_mostra[\$key] = \"SI\";
-if (strtoupper(\$val) == \"".mex("NO",$pag)."\") \$tariffe_mostra[\$key] = \"NO\";
+if (strtoupper(\$val) == \"$SI\") \$tariffe_mostra[\$key] = \"SI\";
+if (strtoupper(\$val) == \"$NO\") \$tariffe_mostra[\$key] = \"NO\";
 } # fine foreach
 \$n_tariffe_imposte = \$".mex("var_nomi_tariffe_imposte",$pag).";
 unset(\$costi_agg_mostra);
 reset (\$".mex("var_costi_aggiuntivi_mostra",$pag).");
 foreach (\$".mex("var_costi_aggiuntivi_mostra",$pag)." as \$key => \$val) {
-if (strtoupper(\$val) == \"".mex("SI",$pag)."\") \$costi_agg_mostra[\$key] = \"SI\";
-if (strtoupper(\$val) == \"".mex("NO",$pag)."\") \$costi_agg_mostra[\$key] = \"NO\";
+if (strtoupper(\$val) == \"$SI\") \$costi_agg_mostra[\$key] = \"SI\";
+if (strtoupper(\$val) == \"$NO\") \$costi_agg_mostra[\$key] = \"NO\";
 } # fine foreach
 \$n_costi_agg_imposti = \$".mex("var_nomi_costi_agg_imposti",$pag).";
-if (strtoupper(\$".mex("var_mostra_caparra",$pag).") == \"".mex("SI",$pag)."\") \$mostra_caparra = \"SI\";
+if (strtoupper(\$".mex("var_mostra_caparra",$pag).") == \"$SI\") \$mostra_caparra = \"SI\";
 else \$mostra_caparra = \"NO\";
 
 \$apertura_tag_font = \$".mex("var_apertura_tag_font",$pag).";
@@ -760,6 +795,13 @@ includi_file("./includes/funzioni.php",$file);
 includi_file("./includes/funzioni_testo.php",$file);
 includi_file("./includes/funzioni_tariffe.php",$file);
 includi_file("./includes/funzioni_costi_agg.php",$file);
+
+if (defined('C_NUM_HOSTING') and C_NUM_HOSTING != "") {
+fwrite($file,"
+if (!defined('C_NUM_HOSTING')) define('C_NUM_HOSTING','".C_NUM_HOSTING."');
+");
+} # fine if (defined('C_NUM_HOSTING') and C_NUM_HOSTING != "")
+
 if (defined("C_FILE_SCADENZA_ACCOUNT") and C_FILE_SCADENZA_ACCOUNT != "") {
 $f_scad_acc = explode("/",$percorso_cartella_modello);
 $num_f_scad_acc = count($f_scad_acc);
@@ -810,10 +852,10 @@ else $url_pagina_link = "$percorso_cartella_modello/$nome_file";
 } # fine if ($silenzio != "totale")
 
 if ($silenzio == "NO") echo "<br>";
-if ($silenzio != "totale") echo mex("Una pagina chiamata",$pag)." <b><a href=\"$url_pagina_link\" target=\"_blank\">$nome_file</a></b> ".mex("è stata creata nella directory",$pag)." \"$percorso_cartella_modello\".<br>";
+if ($silenzio != "totale") echo mex2("Una pagina chiamata",$pag,$lingua_orig)." <b><a href=\"$url_pagina_link\" target=\"_blank\">$nome_file</a></b> ".mex2("è stata creata nella directory",$pag,$lingua_orig)." \"$percorso_cartella_modello\".<br>";
 if ($silenzio == "NO") {
-if (defined("C_CARTELLA_CREA_MODELLI")) echo mex("Si può creare un link verso questa pagina dal proprio sito internet",$pag).".<br>";
-else echo mex("Si può cambiare la directory dove vengono create le pagine da \"configura e personalizza\"",$pag).".<br>";
+if (defined("C_CARTELLA_CREA_MODELLI")) echo mex2("Si può creare un link verso questa pagina dal proprio sito internet",$pag,$lingua_orig).".<br>";
+else echo mex2("Si può cambiare la directory dove vengono create le pagine da \"configura e personalizza\"",$pag,$lingua_orig).".<br>";
 
 if (defined("C_FILE_DOMINIO") and C_FILE_DOMINIO != "" and (!defined('C_NASCONDI_MARCA') or C_NASCONDI_MARCA != "SI")) {
 $altri_domini = @file(C_FILE_DOMINIO);
@@ -831,18 +873,18 @@ else $altro_dominio = "http://";
 $altro_dominio .= trim($altri_domini[$num1])."/$percorso_cartella_dominio$nome_file";
 if ($altro_dominio != $url_pagina_link) {
 $lista_altri_domini .= "<b><a href=\"$altro_dominio\" target=\"_blank\">$altro_dominio</a></b>";
-if ($num1 == 0) $lista_altri_domini .= " (".mex("sicuro",$pag).")";
+if ($num1 == 0) $lista_altri_domini .= " (".mex2("sicuro",$pag,$lingua_orig).")";
 $lista_altri_domini .= "<br>";
 } # fine if ($altro_dominio != $url_pagina_link)
 } # fine for $num1
-if ($lista_altri_domini) echo "<br><br>".mex("Indirizzi alternativi da cui la pagina è raggiungibile",$pag).":<br><div class=\"linhbox\">$lista_altri_domini</div>";
+if ($lista_altri_domini) echo "<br><br>".mex2("Indirizzi alternativi da cui la pagina è raggiungibile",$pag,$lingua_orig).":<br><div class=\"linhbox\">$lista_altri_domini</div>";
 } # fine if ($altri_domini)
 } # fine if (defined("C_FILE_DOMINIO") and C_FILE_DOMINIO != "" and (!defined('C_NASCONDI_MARCA') or C_NASCONDI_MARCA != "SI"))
 
 echo "<br>";
 } # fine if ($silenzio == "NO")
 } # fine if ($file)
-else if ($silenzio == "NO") echo mex("Non ho il permesso di scrittura nella cartella",$pag)." $percorso_cartella_modello.<br>";
+else if ($silenzio == "NO") echo mex2("Non ho il permesso di scrittura nella cartella",$pag,$lingua_orig)." $percorso_cartella_modello.<br>";
 
 } # fine if ($continua != "NO")
 
