@@ -157,6 +157,8 @@ $priv_vedi_tab_doc = substr($priv_vedi_tab,7,1);
 $priv_ins_tariffe = risul_query($privilegi_annuali_utente,0,'priv_ins_tariffe');
 $priv_mod_tariffe = substr($priv_ins_tariffe,0,1);
 $priv_ins_costi_agg = substr($priv_ins_tariffe,1,1);
+$priv_mod_reg1 = substr($priv_ins_tariffe,4,1);
+$priv_mod_reg2 = substr($priv_ins_tariffe,5,1);
 } # fine else if (numlin_query($privilegi_annuali_utente) == 0)
 unset($utenti_gruppi);
 $utenti_gruppi[$id_utente] = 1;
@@ -202,6 +204,8 @@ $priv_vedi_tab_appartamenti = "s";
 $priv_vedi_tab_doc = "s";
 $priv_vedi_tab_stat = "s";
 $priv_mod_tariffe = "s";
+$priv_mod_reg1 = "s";
+$priv_mod_reg2 = "s";
 $priv_ins_costi_agg = "s";
 } # fine else if ($id_utente != 1)
 
@@ -232,6 +236,8 @@ $priv_ins_nuove_prenota = "n";
 $priv_ins_spese = "n";
 $priv_ins_entrate = "n";
 $priv_mod_tariffe = "n";
+$priv_mod_reg1 = "n";
+$priv_mod_reg2 = "n";
 $priv_ins_costi_agg = "n";
 $priv_mod_costi_agg = "n";
 $priv_mod_checkin = "n";
@@ -756,13 +762,13 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"creaprezzi.php\"><
 <button class=\"ipri\" type=\"submit\"><div>".mex("Inserisci o modifica i prezzi",$pag)."</div></button>
 </div></form><div class=\"mm_sub7\"></div>";
 } # fine if ($priv_mod_tariffe != "n" or $priv_ins_costi_agg != "n")
-if ($id_utente == 1 and $installazione_subordinata != "SI") {
+if ($priv_mod_reg1 != "n" or $priv_mod_reg2 != "n") {
 echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"crearegole.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <button class=\"irul\" type=\"submit\"><div>".mex("Inserisci o modifica le regole di assegnazione",$pag)."</div></button><br>
 </div></form><div class=\"mm_sub7\"></div>";
-} # fine if ($id_utente == 1 and $installazione_subordinata != "SI")
+} # fine if ($priv_mod_reg1 != "n" or $priv_mod_reg2 != "n")
 if ($modifica_pers != "NO" or $priv_crea_backup == "s" or $priv_crea_interconnessioni == "s" or $priv_gest_pass_cc == "s") {
 echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"personalizza.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
