@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2017 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2019 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -51,12 +51,18 @@ $tableregole = $PHPR_TAB_PRE."regole".$anno;
 $tableappartamenti = $PHPR_TAB_PRE."appartamenti";
 $tableinterconnessioni = $PHPR_TAB_PRE."interconnessioni";
 $tablecache = $PHPR_TAB_PRE."cache";
+$tabletransazioni = $PHPR_TAB_PRE."transazioni";
 
 if ($user) $nome_utente_phpr = $user;
 if ($password) $password_phpr = $password;
 $id_utente_azione_ic = "";
 
 if (defined("C_UTENTE_AZIONE_IC") and C_UTENTE_AZIONE_IC != "" and $utente_azione_ic == C_UTENTE_AZIONE_IC) {
+if (defined('C_FILE_SCADENZA_ACCOUNT') and C_FILE_SCADENZA_ACCOUNT != "") {
+$scadenza = trim(@implode("",@file("./".C_FILE_SCADENZA_ACCOUNT)));
+$adesso = date("YmdHis");
+if (!$scadenza or $scadenza < $adesso) exit();
+} # fine if (defined('C_FILE_SCADENZA_ACCOUNT') and C_FILE_SCADENZA_ACCOUNT != "")
 #$id_utente_az = esegui_query("select idlocale from $tableinterconnessioni where tipoid = 'id_utente_az' ");
 #if (!numlin_query($id_utente_az)) {
 $id_utente = "a";
@@ -92,17 +98,35 @@ esegui_query("insert into $tablesessioni (idsessioni,idutente,indirizzo_ip,tipo_
 if (!$id_utente_azione_ic) $id_utente = controlla_login($numconnessione,$PHPR_TAB_PRE,$id_sessione,$nome_utente_phpr,$password_phpr,$anno);
 
 if ($id_utente != 1 and $id_utente != "a") {
-$privilegi_annuali_utente = esegui_query("select * from $tableprivilegi where idutente = '$id_utente' and anno = '$anno'");
-if (numlin_query($privilegi_annuali_utente) == 0) $anno_utente_attivato = "NO";
-else $anno_utente_attivato = "SI";
 $privilegi_globali_utente = esegui_query("select * from $tableprivilegi where idutente = '$id_utente' and anno = '1'");
 $priv_mod_pers = risul_query($privilegi_globali_utente,0,'priv_mod_pers');
 $priv_crea_interconnessioni = substr($priv_mod_pers,3,1);
+$privilegi_annuali_utente = esegui_query("select * from $tableprivilegi where idutente = '$id_utente' and anno = '$anno'");
+if (numlin_query($privilegi_annuali_utente) == 0) $anno_utente_attivato = "NO";
+else {
+$anno_utente_attivato = "SI";
+$priv_ins_tariffe = risul_query($privilegi_annuali_utente,0,'priv_ins_tariffe');
+$priv_mod_reg2 = substr($priv_ins_tariffe,5,1);
+$regole1_consentite = risul_query($privilegi_annuali_utente,0,'regole1_consentite');
+$attiva_regole1_consentite = substr($regole1_consentite,0,1);
+$applica_regole1 = substr($regole1_consentite,1,1);
+if ($attiva_regole1_consentite != "n" or $applica_regole1 == "n") $regole1_consentite = explode("#@^",substr($regole1_consentite,3));
+$tariffe_consentite = risul_query($privilegi_annuali_utente,0,'tariffe_consentite');
+$attiva_tariffe_consentite = substr($tariffe_consentite,0,1);
+if ($attiva_tariffe_consentite == "s") {
+$tariffe_consentite = explode(",",substr($tariffe_consentite,2));
+unset($tariffe_consentite_vett);
+for ($num1 = 0 ; $num1 < count($tariffe_consentite) ; $num1++) if ($tariffe_consentite[$num1]) $tariffe_consentite_vett[$tariffe_consentite[$num1]] = "SI";
+} # fine if ($attiva_tariffe_consentite == "s")
+} # fine if else if (numlin_query($privilegi_annuali_utente) == 0)
 } # fine if ($id_utente != 1 and $id_utente != "a")
 else {
 if ($id_utente == 1) {
 $priv_crea_interconnessioni = "s";
 $anno_utente_attivato = "SI";
+$attiva_regole1_consentite = "n";
+$attiva_tariffe_consentite = "n";
+$priv_mod_reg2 = "s";
 } # fine if ($id_utente == 1)
 else $priv_crea_interconnessioni = "n";
 } # fine else if ($id_utente != 1 and $id_utente != "a")
@@ -116,17 +140,12 @@ if ($id_utente and (($priv_crea_interconnessioni == "s" and $anno_utente_attivat
 
 if (@is_file(C_DATI_PATH."/dati_subordinazione.php")) {
 $installazione_subordinata = "SI";
-$inserimento_nuovi_clienti = "NO";
-$priv_ins_nuove_prenota = "n";
-$priv_mod_prenotazioni = "n";
-$modifica_clienti = "NO";
-$priv_ins_nuove_prenota = "n";
-$priv_ins_spese = "n";
-$priv_ins_entrate = "n";
-$priv_ins_costi_agg = "n";
+$priv_crea_interconnessioni = "n";
+$priv_mod_reg2 = "n";
 } # fine if (@is_file(C_DATI_PATH."/dati_subordinazione.php"))
 
 
+$titolo = "HotelDruid: ".mex("Interconnessioni",$pag);
 if ($tema[$id_utente] and $tema[$id_utente] != "base" and @is_dir("./themes/".$tema[$id_utente]."/php")) include("./themes/".$tema[$id_utente]."/php/head.php");
 else include("./includes/head.php");
 
@@ -377,11 +396,11 @@ if ($crea_subordinazione) {
 $file_backup = C_DATI_PATH."/sub_backup.php";
 $filelock = crea_lock_file($file_backup);
 $errore = "NO";
-if (get_magic_quotes_gpc()) {
+if (@get_magic_quotes_gpc()) {
 $url_subordinazione = stripslashes($url_subordinazione);
 $utente_subordinazione = stripslashes($utente_subordinazione);
 $password_subordinazione = stripslashes($password_subordinazione);
-} # fine if (get_magic_quotes_gpc())
+} # fine if (@get_magic_quotes_gpc())
 if ($compresso_subordinazione != "SI") $compresso_subordinazione = "";
 if ($mantieni_anni != 1) $mantieni_anni = "";
 if (substr($url_subordinazione,0,7) != "http://" and substr($url_subordinazione,0,8) != "https://") $errore = "SI";
