@@ -187,6 +187,7 @@ $priv_mod_checkin = "n";
 } # fine if (@is_file(C_DATI_PATH."/dati_subordinazione.php"))
 
 
+$titolo = "HotelDruid: ".mex("Inventario",$pag);
 if ($tema[$id_utente] and $tema[$id_utente] != "base" and @is_dir("./themes/".$tema[$id_utente]."/php")) include("./themes/".$tema[$id_utente]."/php/head.php");
 else include("./includes/head.php");
 
@@ -369,7 +370,7 @@ $frase_modifica .= "".mex("Nuovo bene",$pag)." \"<em>$nome_bene</em>\" ".mex("ag
 if ($crea_ca) {
 $prezzo_costo_agg = formatta_soldi($prezzo_costo_agg);
 if (strcmp($prezzo_costo_agg,"") and controlla_soldi($prezzo_costo_agg) == "SI") {
-if (get_magic_quotes_gpc()) $nome_costo_agg = stripslashes($nome_costo_agg);
+if (@get_magic_quotes_gpc()) $nome_costo_agg = stripslashes($nome_costo_agg);
 $costiagg_esist = esegui_query("select * from $tablenometariffe where nomecostoagg = '".aggslashdb($nome_costo_agg)."' and idntariffe > 10 ");
 if (!numlin_query($costiagg_esist)) {
 include_once("./includes/funzioni_costi_agg.php");
@@ -386,7 +387,7 @@ esegui_query("update $tablenometariffe set tasseperc_ca = '".aggslashdb($tassepe
 if ($tipo_categoria_ca != "ce") $categoria = $n_categoria_ca;
 else $categoria = $categoria_esist_ca;
 if ($categoria) {
-if (get_magic_quotes_gpc()) $categoria = stripslashes($categoria);
+if (@get_magic_quotes_gpc()) $categoria = stripslashes($categoria);
 esegui_query("update $tablenometariffe set categoria_ca = '".aggslashdb($categoria)."' where idntariffe = '$idntariffe' ");
 } # fine if ($categoria)
 aggiorna_privilegi_ins_costo($idntariffe,$tableprivilegi,$id_utente,$anno,$attiva_costi_agg_consentiti,$priv_ins_costi_agg,$utenti_gruppi);
