@@ -38,6 +38,7 @@ $tableutenti = $PHPR_TAB_PRE."utenti";
 $tableprivilegi = $PHPR_TAB_PRE."privilegi";
 $tablecontratti = $PHPR_TAB_PRE."contratti";
 $tableprenota = $PHPR_TAB_PRE."prenota".$anno;
+$tableprenotacanc = $PHPR_TAB_PRE."prenotacanc".$anno;
 $tablecache = $PHPR_TAB_PRE."cache";
 
 
@@ -119,6 +120,7 @@ $priv_ins_costi_agg = "n";
 } # fine if (@is_file(C_DATI_PATH."/dati_subordinazione.php"))
 
 
+$titolo = "HotelDruid: ".mex("Messaggi",$pag);
 if ($tema[$id_utente] and $tema[$id_utente] != "base" and @is_dir("./themes/".$tema[$id_utente]."/php")) include("./themes/".$tema[$id_utente]."/php/head.php");
 else include("./includes/head.php");
 
@@ -740,7 +742,16 @@ $prenota_inserite = explode(",",$stato_prenota);
 $num_prenota_inserite = count($prenota_inserite);
 for ($num2 = 0 ; $num2 < $num_prenota_inserite ; $num2++) {
 $link_modifica = "SI";
+$stilebarrato = "";
+$pcanc = "";
 $dati_prenota = esegui_query("select utente_inserimento,iddatainizio,datainserimento from $tableprenota where idprenota = '".aggslashdb($prenota_inserite[$num2])."'");
+if (!numlin_query($dati_prenota)) {
+$dati_prenota = esegui_query("select utente_inserimento,iddatainizio,datainserimento from $PHPR_TAB_PRE"."prenotacanc$anno where idprenota = '".aggslashdb($prenota_inserite[$num2])."'");
+if (numlin_query($dati_prenota)) {
+$stilebarrato = " style=\"text-decoration: line-through\"";
+$pcanc = "&amp;pcanc=1";
+} # fine if (numlin_query($dati_prenota))
+} # fine if (!numlin_query($dati_prenota))
 if (numlin_query($dati_prenota) != 1) $link_modifica = "NO";
 else {
 $utente_ins_prenota = risul_query($dati_prenota,0,'utente_inserimento');
@@ -757,7 +768,7 @@ $limite = date("YmdHis",mktime((substr($data_ins_prenota,11,2) + $priv_mod_preno
 if ($adesso > $limite) $link_modifica = "NO";
 } # fine if ($priv_mod_prenota_ore != "000")
 if ($link_modifica == "SI") {
-$link_modifica_inizio = "<a href=\"modifica_prenota.php?id_prenota=".$prenota_inserite[$num2]."&anno=$anno&id_sessione=$id_sessione&origine=messaggi.php\">";
+$link_modifica_inizio = "<a$stilebarrato href=\"modifica_prenota.php?id_prenota=".$prenota_inserite[$num2]."$pcanc&anno=$anno&id_sessione=$id_sessione&origine=messaggi.php\">";
 $link_modifica_fine = "</a>";
 #$checkbox_modifica = "<input type=\"checkbox\" name=\"cambia$numero\" value=\"SI\">";
 } # fine if ($link_modifica == "SI")
@@ -924,6 +935,9 @@ if ($num_commenti_pers < 1) $num_commenti_pers = 1;
 $campi_pers_clienti = $dati_richiedente_dt[22];
 $codfiscale = $dati_richiedente_dt[23];
 $partitaiva = $dati_richiedente_dt[24];
+$valuta_pagamento = $dati_richiedente_dt[25];
+$cambio_pagamento = $dati_richiedente_dt[26];
+$arrotond_pagamento = $dati_richiedente_dt[27];
 
 if ($stato_prenota == "da_inserire") {
 if ($priv_ins_nuove_prenota == "s" and $inizioperiodo[1]) {
@@ -943,6 +957,7 @@ $tasto_prenota .= "<input type=\"hidden\" name=\"inizioperiodo$n_t\" value=\"".$
 for ($num2 = 0 ; $num2 < count($cat_numpers[$n_t]) ; $num2++) if ($cat_numpers[$n_t][$num2]) $tasto_prenota .= "<input type=\"hidden\" name=\"cat$num2"."_numpers$n_t\" value=\"".$cat_numpers[$n_t][$num2]."\">";
 $tasto_prenota .= "<input type=\"hidden\" name=\"num_app_richiesti$n_t\" value=\"".$num_app_tipo_richiesti[$n_t]."\">
 <input type=\"hidden\" name=\"nometipotariffa$n_t\" value=\"tariffa".$numero_tariffa[$n_t]."\">
+<input type=\"hidden\" name=\"tipo_val_caparra$n_t\" value=\"".htmlspecialchars(">".$valuta_pagamento)."\">
 <input type=\"hidden\" name=\"met_paga_caparra$n_t\" value=\"$metodo_pagamento\">
 <input type=\"hidden\" name=\"origine_prenota$n_t\" value=\"$origine_prenota_dt\">
 <input type=\"hidden\" name=\"commento1_$n_t\" value=\"$commento\">
