@@ -28,6 +28,7 @@ include(C_DATI_PATH."/dati_connessione.php");
 include("./includes/funzioni_$PHPR_DB_TYPE.php");
 $numconnessione = connetti_db($PHPR_DB_NAME,$PHPR_DB_HOST,$PHPR_DB_PORT,$PHPR_DB_USER,$PHPR_DB_PASS,$PHPR_LOAD_EXT);
 include("./includes/funzioni.php");
+include("./includes/funzioni_web.php");
 $tablenometariffe = $PHPR_TAB_PRE."ntariffe".$anno;
 $tableprenota = $PHPR_TAB_PRE."prenota".$anno;
 $tableperiodi = $PHPR_TAB_PRE."periodi".$anno;
@@ -44,13 +45,16 @@ $id_utente = controlla_login($numconnessione,$PHPR_TAB_PRE,$id_sessione,$nome_ut
 if ($id_utente and $id_utente == 1) {
 
 
+$titolo = "HotelDruid: ".ucfirst(mex("modifica",$pag))." ".mex("Appartamenti",'unit.php');
 if ($tema[$id_utente] and $tema[$id_utente] != "base" and @is_dir("./themes/".$tema[$id_utente]."/php")) include("./themes/".$tema[$id_utente]."/php/head.php");
 else include("./includes/head.php");
 
 
 
-$idappartamenti = htmlspecialchars($idappartamenti);
-$idappartamenti = aggslashdb($idappartamenti);
+$idapp_contr = str_replace("&amp;","",str_replace("&quot;","",str_replace("&lt;","",str_replace("&gt;","",$idappartamenti))));
+if (strstr($idapp_contr,">") or strstr($idapp_contr,"<") or strstr($idapp_contr,"\"") or strstr($idapp_contr,"&")) $idappartamenti = htmlspecialchars($idappartamenti);
+$dest = "";
+
 
 if ($cancella_app) {
 $mostra_form_modifica = "NO";
@@ -130,7 +134,7 @@ else $min_periodo = 1;
 $max_periodo = esegui_query("select max(idperiodi) from $tableperiodi_controlla");
 $max_periodo = risul_query($max_periodo,0,0);
 liberasettimane ($min_periodo,$max_periodo,$limiti_var,$anno_controlla,$fatto_libera,$app_liberato,$profondita,$app_richiesti,$app_prenota_id,$app_orig_prenota_id,$inizio_prenota_id,$fine_prenota_id,$app_assegnabili_id,$prenota_in_app_sett,$dati_app,$PHPR_TAB_PRE."prenota");
-$prenota_presenti = esegui_query("select * from $tableprenota_controlla where idappartamenti = '$idappartamenti' and iddatainizio >= '$min_periodo'");
+$prenota_presenti = esegui_query("select * from $tableprenota_controlla where idappartamenti = '".aggslashdb($idappartamenti)."' and iddatafine >= '$min_periodo'");
 $num_prenota_presenti = numlin_query($prenota_presenti);
 if ($num_prenota_presenti != 0) {
 $cancellare = "NO";
@@ -139,7 +143,7 @@ break;
 } # fine if ($num_prenota_presenti != 0)
 } # fine for $num1
 
-$app_esiste = esegui_query("select * from $tableappartamenti where idappartamenti = '$idappartamenti'");
+$app_esiste = esegui_query("select * from $tableappartamenti where idappartamenti = '".aggslashdb($idappartamenti)."'");
 $num_app_esiste = numlin_query($app_esiste);
 if ($num_app_esiste != 1) {
 echo mex("L'appartamento",'unit.php')." $idappartamenti ".mex("è già stato cancellato",'unit.php').".<br>";
@@ -160,7 +164,7 @@ echo mex("Sei sicuro di voler <b>cancellare</b> l'appartamento",'unit.php')." <b
 } # fine if ($cancella_sicuro != "SI")
 
 else {
-$d_app_vicini = esegui_query("select app_vicini from $tableappartamenti where idappartamenti = '$idappartamenti' ");
+$d_app_vicini = esegui_query("select app_vicini from $tableappartamenti where idappartamenti = '".aggslashdb($idappartamenti)."' ");
 $d_app_vicini = risul_query($d_app_vicini,0,'app_vicini');
 $d_app_vicini_vett = explode(",",$d_app_vicini);
 for ($num2 = 0 ; $num2 < count($d_app_vicini_vett) ; $num2++) {
@@ -172,9 +176,9 @@ $app_reciprici = substr(str_replace(",".$idappartamenti.",",",",",".$app_recipri
 esegui_query("update $tableappartamenti set app_vicini = '".aggslashdb($app_reciprici)."' where idappartamenti = '".aggslashdb($d_app_vicino)."' ");
 } # fine if (numlin_query($app_reciprici) == 1)
 } # fine for $num2
-esegui_query("delete from $tableappartamenti where idappartamenti = '$idappartamenti'");
-esegui_query("delete from $tablerelinventario where idappartamento = '$idappartamenti'");
-esegui_query("delete from $tabledescrizioni where nome = '$idappartamenti' and (tipo = 'appdescr' or tipo = 'appfoto') ");
+esegui_query("delete from $tableappartamenti where idappartamenti = '".aggslashdb($idappartamenti)."'");
+esegui_query("delete from $tablerelinventario where idappartamento = '".aggslashdb($idappartamenti)."'");
+esegui_query("delete from $tabledescrizioni where nome = '".aggslashdb($idappartamenti)."' and (tipo = 'appdescr' or tipo = 'appfoto') ");
 $id_appartamenti = esegui_query("select idappartamenti from $tableappartamenti order by idappartamenti ");
 $num_appartamenti = numlin_query($id_appartamenti);
 $fileaperto = fopen(C_DATI_PATH."/selectappartamenti.php","w+");
@@ -271,10 +275,10 @@ ${"n_numpiano".$num2} = $n_nump_app_unita;
 } # fine if (${"num_unita_app".$num1} and strcmp(${"nome_unita_app".$num1},""))
 ${"idappartamenti".$num1} = htmlspecialchars(${"idappartamenti".$num1});
 ${"idappartamenti".$num1} = aggslashdb(${"idappartamenti".$num1});
-if (get_magic_quotes_gpc()) {
+if (@get_magic_quotes_gpc()) {
 ${"n_commento".$num1} = stripslashes(${"n_commento".$num1});
 ${"d_commento".$num1} = stripslashes(${"d_commento".$num1});
-} # fine if (get_magic_quotes_gpc())
+} # fine if (@get_magic_quotes_gpc())
 ${"n_nome_app".$num1} = str_replace(",","",${"n_nome_app".$num1});
 if (str_replace (" ","",${"n_nome_app".$num1}) == "") ${"n_nome_app".$num1} = str_replace(" ","_",${"n_nome_app".$num1});
 ${"n_nome_app".$num1} = trim(${"n_nome_app".$num1});
@@ -580,7 +584,7 @@ $app_reciprici = substr(str_replace(",".$idappartamenti.",",",".$n_nome_app.",",
 esegui_query("update $tableappartamenti set app_vicini = '".aggslashdb($app_reciprici)."' where idappartamenti = '".aggslashdb($d_app_vicino)."' ");
 } # fine if (numlin_query($app_reciprici) == 1)
 } # fine for $num2
-esegui_query("update $tabledescrizioni set nome = '$n_nome_app' where nome = '$idappartamenti' and (tipo = 'appdescr' or tipo = 'appfoto' or tipo = 'appcommfoto') ");
+esegui_query("update $tabledescrizioni set nome = '$n_nome_app' where nome = '".aggslashdb($idappartamenti)."' and (tipo = 'appdescr' or tipo = 'appfoto' or tipo = 'appcommfoto') ");
 $idappartamenti = $n_nome_app;
 $id_appartamenti = esegui_query("select idappartamenti from $tableappartamenti order by idappartamenti ");
 $num_appartamenti = numlin_query($id_appartamenti);
@@ -684,29 +688,29 @@ $mostra_form_modifica = "NO";
 $tabelle_lock = array($tabledescrizioni);
 $altre_tab_lock = array($tableappartamenti);
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
-$app_esist = esegui_query("select idappartamenti from $tableappartamenti where idappartamenti = '$idappartamenti' ");
+$app_esist = esegui_query("select idappartamenti from $tableappartamenti where idappartamenti = '".aggslashdb($idappartamenti)."' ");
 if (numlin_query($app_esist)) {
 if (strcmp($n_descrizione_ita,"")) {
-if (get_magic_quotes_gpc()) $n_descrizione_ita = stripslashes($n_descrizione_ita);
+if (@get_magic_quotes_gpc()) $n_descrizione_ita = stripslashes($n_descrizione_ita);
 $n_descrizione_ita = aggslashdb(htmlspecialchars($n_descrizione_ita));
-$descr_esistente = esegui_query("select testo from $tabledescrizioni where nome = '$idappartamenti' and tipo = 'appdescr' and lingua = 'ita' and numero = '1' ");
-if (numlin_query($descr_esistente)) esegui_query("update $tabledescrizioni set testo = '$n_descrizione_ita' where nome = '$idappartamenti' and tipo = 'appdescr' and lingua = 'ita' and numero = '1' ");
-else esegui_query("insert into $tabledescrizioni (nome,tipo,lingua,numero,testo) values ('$idappartamenti','appdescr','ita','1','$n_descrizione_ita') ");
+$descr_esistente = esegui_query("select testo from $tabledescrizioni where nome = '".aggslashdb($idappartamenti)."' and tipo = 'appdescr' and lingua = 'ita' and numero = '1' ");
+if (numlin_query($descr_esistente)) esegui_query("update $tabledescrizioni set testo = '$n_descrizione_ita' where nome = '".aggslashdb($idappartamenti)."' and tipo = 'appdescr' and lingua = 'ita' and numero = '1' ");
+else esegui_query("insert into $tabledescrizioni (nome,tipo,lingua,numero,testo) values ('".aggslashdb($idappartamenti)."','appdescr','ita','1','$n_descrizione_ita') ");
 } # fine if (strcmp($n_descrizione_ita,""))
-else esegui_query("delete from $tabledescrizioni where nome = '$idappartamenti' and tipo = 'appdescr' and lingua = 'ita' and numero = '1' ");
+else esegui_query("delete from $tabledescrizioni where nome = '".aggslashdb($idappartamenti)."' and tipo = 'appdescr' and lingua = 'ita' and numero = '1' ");
 $lang_dir = opendir("./includes/lang/");
 include(C_DATI_PATH."/lingua.php");
 while ($ini_lingua = readdir($lang_dir)) {
 if ($ini_lingua != "." && $ini_lingua != ".." and strlen($ini_lingua) <= 3 and preg_replace("/[a-z]/","",$ini_lingua) == "") {
 $n_descrizione = ${"n_descrizione_".$ini_lingua};
 if (strcmp($n_descrizione,"")) {
-if (get_magic_quotes_gpc()) $n_descrizione = stripslashes($n_descrizione);
+if (@get_magic_quotes_gpc()) $n_descrizione = stripslashes($n_descrizione);
 $n_descrizione = aggslashdb(htmlspecialchars($n_descrizione));
-$descr_esistente = esegui_query("select testo from $tabledescrizioni where nome = '$idappartamenti' and tipo = 'appdescr' and lingua = '$ini_lingua' and numero = '1' ");
-if (numlin_query($descr_esistente)) esegui_query("update $tabledescrizioni set testo = '$n_descrizione' where nome = '$idappartamenti' and tipo = 'appdescr' and lingua = '$ini_lingua' and numero = '1' ");
-else esegui_query("insert into $tabledescrizioni (nome,tipo,lingua,numero,testo) values ('$idappartamenti','appdescr','$ini_lingua','1','$n_descrizione') ");
+$descr_esistente = esegui_query("select testo from $tabledescrizioni where nome = '".aggslashdb($idappartamenti)."' and tipo = 'appdescr' and lingua = '$ini_lingua' and numero = '1' ");
+if (numlin_query($descr_esistente)) esegui_query("update $tabledescrizioni set testo = '$n_descrizione' where nome = '".aggslashdb($idappartamenti)."' and tipo = 'appdescr' and lingua = '$ini_lingua' and numero = '1' ");
+else esegui_query("insert into $tabledescrizioni (nome,tipo,lingua,numero,testo) values ('".aggslashdb($idappartamenti)."','appdescr','$ini_lingua','1','$n_descrizione') ");
 } # fine if (strcmp($n_descrizione,""))
-else esegui_query("delete from $tabledescrizioni where nome = '$idappartamenti' and tipo = 'appdescr' and lingua = '$ini_lingua' and numero = '1' ");
+else esegui_query("delete from $tabledescrizioni where nome = '".aggslashdb($idappartamenti)."' and tipo = 'appdescr' and lingua = '$ini_lingua' and numero = '1' ");
 } # fine if ($file != "." && $file != ".." and...
 } # fine while ($file = readdir($lang_dig))
 closedir($lang_dir);
@@ -714,38 +718,39 @@ echo "<br>".ucfirst(mex("descrizione dell'appartamento",'unit.php'))." $idappart
 } # fine if (numlin_query($app_esist))
 unlock_tabelle($tabelle_lock);
 $mostra_torna_indietro = "SI";
+$dest = "#descrcocont";
 } # fine if ($modificadescr)
 
 
 if ($commentofoto) {
 $mostra_form_modifica = "NO";
-$app_esist = esegui_query("select idappartamenti from $tableappartamenti where idappartamenti = '$idappartamenti' ");
+$app_esist = esegui_query("select idappartamenti from $tableappartamenti where idappartamenti = '".aggslashdb($idappartamenti)."' ");
 if ($numfoto and controlla_num_pos($numfoto) == "SI" and numlin_query($app_esist)) {
 $tabelle_lock = array($tabledescrizioni);
 $tabelle_lock = lock_tabelle($tabelle_lock);
-$foto_esistente = esegui_query("select testo from $tabledescrizioni where nome = '$idappartamenti' and tipo = 'appfoto' and numero = '$numfoto' ");
+$foto_esistente = esegui_query("select testo from $tabledescrizioni where nome = '".aggslashdb($idappartamenti)."' and tipo = 'appfoto' and numero = '$numfoto' ");
 if (numlin_query($foto_esistente)) {
 if (strcmp($n_commento_ita,"")) {
-if (get_magic_quotes_gpc()) $n_commento_ita = stripslashes($n_commento_ita);
+if (@get_magic_quotes_gpc()) $n_commento_ita = stripslashes($n_commento_ita);
 $n_commento_ita = aggslashdb(htmlspecialchars($n_commento_ita));
-$comm_esistente = esegui_query("select testo from $tabledescrizioni where nome = '$idappartamenti' and tipo = 'appcommfoto' and lingua = 'ita' and numero = '$numfoto' ");
-if (numlin_query($comm_esistente)) esegui_query("update $tabledescrizioni set testo = '$n_commento_ita' where nome = '$idappartamenti' and tipo = 'appcommfoto' and lingua = 'ita' and numero = '$numfoto' ");
-else esegui_query("insert into $tabledescrizioni (nome,tipo,lingua,numero,testo) values ('$idappartamenti','appcommfoto','ita','$numfoto','$n_commento_ita') ");
+$comm_esistente = esegui_query("select testo from $tabledescrizioni where nome = '".aggslashdb($idappartamenti)."' and tipo = 'appcommfoto' and lingua = 'ita' and numero = '$numfoto' ");
+if (numlin_query($comm_esistente)) esegui_query("update $tabledescrizioni set testo = '$n_commento_ita' where nome = '".aggslashdb($idappartamenti)."' and tipo = 'appcommfoto' and lingua = 'ita' and numero = '$numfoto' ");
+else esegui_query("insert into $tabledescrizioni (nome,tipo,lingua,numero,testo) values ('".aggslashdb($idappartamenti)."','appcommfoto','ita','$numfoto','$n_commento_ita') ");
 } # fine if (strcmp($n_commento_ita,""))
-else esegui_query("delete from $tabledescrizioni where nome = '$idappartamenti' and tipo = 'appcommfoto' and lingua = 'ita' and numero = '$numfoto' ");
+else esegui_query("delete from $tabledescrizioni where nome = '".aggslashdb($idappartamenti)."' and tipo = 'appcommfoto' and lingua = 'ita' and numero = '$numfoto' ");
 $lang_dir = opendir("./includes/lang/");
 include(C_DATI_PATH."/lingua.php");
 while ($ini_lingua = readdir($lang_dir)) {
 if ($ini_lingua != "." && $ini_lingua != ".." and strlen($ini_lingua) <= 3 and preg_replace("/[a-z]/","",$ini_lingua) == "") {
 $n_commento = ${"n_commento_".$ini_lingua};
 if (strcmp($n_commento,"")) {
-if (get_magic_quotes_gpc()) $n_commento = stripslashes($n_commento);
+if (@get_magic_quotes_gpc()) $n_commento = stripslashes($n_commento);
 $n_commento = aggslashdb(htmlspecialchars($n_commento));
-$comm_esistente = esegui_query("select testo from $tabledescrizioni where nome = '$idappartamenti' and tipo = 'appcommfoto' and lingua = '$ini_lingua' and numero = '$numfoto' ");
-if (numlin_query($comm_esistente)) esegui_query("update $tabledescrizioni set testo = '$n_commento' where nome = '$idappartamenti' and tipo = 'appcommfoto' and lingua = '$ini_lingua' and numero = '$numfoto' ");
-else esegui_query("insert into $tabledescrizioni (nome,tipo,lingua,numero,testo) values ('$idappartamenti','appcommfoto','$ini_lingua','$numfoto','$n_commento') ");
+$comm_esistente = esegui_query("select testo from $tabledescrizioni where nome = '".aggslashdb($idappartamenti)."' and tipo = 'appcommfoto' and lingua = '$ini_lingua' and numero = '$numfoto' ");
+if (numlin_query($comm_esistente)) esegui_query("update $tabledescrizioni set testo = '$n_commento' where nome = '".aggslashdb($idappartamenti)."' and tipo = 'appcommfoto' and lingua = '$ini_lingua' and numero = '$numfoto' ");
+else esegui_query("insert into $tabledescrizioni (nome,tipo,lingua,numero,testo) values ('".aggslashdb($idappartamenti)."','appcommfoto','$ini_lingua','$numfoto','$n_commento') ");
 } # fine if (strcmp($n_commento,""))
-else esegui_query("delete from $tabledescrizioni where nome = '$idappartamenti' and tipo = 'appcommfoto' and lingua = '$ini_lingua' and numero = '$numfoto' ");
+else esegui_query("delete from $tabledescrizioni where nome = '".aggslashdb($idappartamenti)."' and tipo = 'appcommfoto' and lingua = '$ini_lingua' and numero = '$numfoto' ");
 } # fine if ($file != "." && $file != ".." and...
 } # fine while ($file = readdir($lang_dig))
 closedir($lang_dir);
@@ -754,36 +759,41 @@ echo "<br>".ucfirst(mex("commento della foto",$pag))." $numfoto ".mex("aggiornat
 unlock_tabelle($tabelle_lock);
 } # fine if ($numfoto and controlla_num_pos($numfoto) == "SI" and...
 $mostra_torna_indietro = "SI";
+$dest = "#fotocont";
 } # fine if ($commentofoto)
 
 
 if ($cancurlfoto) {
 $mostra_form_modifica = "NO";
 if ($numfoto and controlla_num_pos($numfoto) == "SI") {
-esegui_query("delete from $tabledescrizioni where nome = '$idappartamenti' and (tipo = 'appfoto' or tipo = 'appcommfoto') and numero = '$numfoto' ");
+esegui_query("delete from $tabledescrizioni where nome = '".aggslashdb($idappartamenti)."' and (tipo = 'appfoto' or tipo = 'appcommfoto') and numero = '$numfoto' ");
 echo "".ucfirst(mex("foto eliminata",$pag)).".<br>";
-} # fine if ($numfoto and controlla_num_pos($numfoto) == "SI") 
+} # fine if ($numfoto and controlla_num_pos($numfoto) == "SI")
 $mostra_torna_indietro = "SI";
+$dest = "#fotocont";
 } # fine if ($aggurlfoto)
 
 
 if ($aggurlfoto) {
 $mostra_form_modifica = "NO";
-if (get_magic_quotes_gpc()) $n_urlfoto = stripslashes($n_urlfoto);
+$dest = "#aggfoto";
+if (@get_magic_quotes_gpc()) $n_urlfoto = stripslashes($n_urlfoto);
 $lowurl = strtolower($n_urlfoto);
-if (substr($lowurl,-4) != ".jpg" and substr($lowurl,-5) != ".jpeg" and substr($lowurl,-4) != ".gif" and substr($lowurl,-4) != ".png") $errore = "SI";
+if (substr($lowurl,-4) != ".jpg" and substr($lowurl,-5) != ".jpeg" and substr($lowurl,-4) != ".gif" and substr($lowurl,-4) != ".png" and substr($lowurl,-5) != ".webp") $errore = "SI";
 if (str_replace("<","",$n_urlfoto) != $n_urlfoto or str_replace(">","",$n_urlfoto) != $n_urlfoto or str_replace("\"","",$n_urlfoto) != $n_urlfoto) $errore = "SI";
-$app_esist = esegui_query("select idappartamenti from $tableappartamenti where idappartamenti = '$idappartamenti' ");
+$app_esist = esegui_query("select idappartamenti from $tableappartamenti where idappartamenti = '".aggslashdb($idappartamenti)."' ");
 if (!numlin_query($app_esist)) $errore = "SI";
 if ($errore != "SI") {
 $tabelle_lock = array($tabledescrizioni);
 $tabelle_lock = lock_tabelle($tabelle_lock);
-$foto_esistenti = esegui_query("select * from $tabledescrizioni where nome = '$idappartamenti' and tipo = 'appfoto' order by numero desc ");
+$foto_esistenti = esegui_query("select * from $tabledescrizioni where nome = '".aggslashdb($idappartamenti)."' and tipo = 'appfoto' order by numero desc ");
 if (numlin_query($foto_esistenti)) $numfoto = (risul_query($foto_esistenti,0,'numero') + 1);
 else $numfoto = 1;
-esegui_query("insert into $tabledescrizioni (nome,tipo,numero,testo) values ('$idappartamenti','appfoto','$numfoto','".aggslashdb($n_urlfoto)."') ");
+upload_hd_img($n_urlfoto);
+esegui_query("insert into $tabledescrizioni (nome,tipo,numero,testo) values ('".aggslashdb($idappartamenti)."','appfoto','$numfoto','".aggslashdb($n_urlfoto)."') ");
 echo "<br>".ucfirst(mex("la nuova foto è stata aggiunta",$pag)).".<br>";
 unlock_tabelle($tabelle_lock);
+$dest = "#ultimafoto";
 } # fine if ($errore != "SI")
 else echo "".ucfirst(mex("l'url della foto è sbagliata",$pag)).".<br>";
 $mostra_torna_indietro = "SI";
@@ -793,7 +803,7 @@ $mostra_torna_indietro = "SI";
 
 if ($mostra_torna_indietro == "SI") {
 echo "<div style=\"text-align: center;\">
-<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
+<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag$dest\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"idappartamenti\" value=\"$idappartamenti\">";
@@ -808,7 +818,7 @@ if ($mostra_form_modifica != "NO") {
 
 
 # Form per modificare l'appartamento.
-$appartamento = esegui_query("select * from $tableappartamenti where idappartamenti = '$idappartamenti'");
+$appartamento = esegui_query("select * from $tableappartamenti where idappartamenti = '".aggslashdb($idappartamenti)."'");
 if (numlin_query($appartamento)) {
 $d_numcasa = risul_query($appartamento,0,'numcasa');
 $d_numpiano = risul_query($appartamento,0,'numpiano');
@@ -865,10 +875,10 @@ echo "</td></tr>
 </div><br></div></form>
 <hr style=\"width: 95%\">";
 
-$d_descrizione = esegui_query("select testo from $tabledescrizioni where nome = '$idappartamenti' and tipo = 'appdescr' and lingua = 'ita' and numero = '1' ");
+$d_descrizione = esegui_query("select testo from $tabledescrizioni where nome = '".aggslashdb($idappartamenti)."' and tipo = 'appdescr' and lingua = 'ita' and numero = '1' ");
 if (numlin_query($d_descrizione)) $d_descrizione = risul_query($d_descrizione,0,'testo');
 else $d_descrizione = "";
-echo "<br><form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
+echo "<br><div id=\"descrcocont\" class=\"rbox\"><form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div style=\"padding: 2px 0 5px; 0;\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"idappartamenti\" value=\"".$idappartamenti."\">
@@ -886,7 +896,7 @@ if ($ini_lingua != "." && $ini_lingua != ".." and strlen($ini_lingua) <= 3 and p
 $nome_lingua = file("./includes/lang/$ini_lingua/l_n");
 $nome_lingua = togli_acapo($nome_lingua[0]);
 $lingue_vett[$ini_lingua] = $nome_lingua;
-$d_descrizione = esegui_query("select testo from $tabledescrizioni where nome = '$idappartamenti' and tipo = 'appdescr' and lingua = '$ini_lingua' and numero = '1' ");
+$d_descrizione = esegui_query("select testo from $tabledescrizioni where nome = '".aggslashdb($idappartamenti)."' and tipo = 'appdescr' and lingua = '$ini_lingua' and numero = '1' ");
 if (numlin_query($d_descrizione)) $d_descrizione = risul_query($d_descrizione,0,'testo');
 else $d_descrizione = "";
 $col++;
@@ -901,15 +911,17 @@ echo "<textarea name=\"n_descrizione_$ini_lingua\" rows=4 cols=60 style=\"white-
 } # fine while ($file = readdir($lang_dig))
 closedir($lang_dir);
 echo "</tr></table>
-<button class=\"edit\" type=\"submit\"><div>".ucfirst(mex("modifica",$pag))."</div></button></div></form><br><br>";
+<button class=\"edit\" type=\"submit\"><div>".ucfirst(mex("modifica",$pag))."</div></button></div></form></div><br><br>";
 
 $foto = esegui_query("select * from $tabledescrizioni where nome = '".$idappartamenti."' and tipo = 'appfoto' order by numero ");
 $num_foto = numlin_query($foto);
-echo "".ucfirst(mex($fr1."foto dell'appartamento",'unit.php'))." <em>".$idappartamenti."</em>:<br>";
+echo "<div id=\"fotocont\" class=\"rbox\"><div style=\"padding-top: 2px;\">".ucfirst(mex($fr1."foto dell'appartamento",'unit.php'))." <em>".$idappartamenti."</em>:<br>";
 for ($num1 = 1 ; $num1 <= $num_foto ; $num1++) {
 $url_foto = risul_query($foto,($num1 - 1),'testo');
 $numfoto = risul_query($foto,($num1 - 1),'numero');
-echo "<table><tr><td valign=\"top\">$num1.</td><td>
+if ($num1 == $num_foto) $id_foto = " id=\"ultimafoto\"";
+else $id_foto = "";
+echo "<table$id_foto><tr><td valign=\"top\">$num1.</td><td>
 <a href=\"$url_foto\"><img class=\"dphoto\" style=\"border: 0px none ; text-decoration: none;\" src=\"$url_foto\" alt=\"".htmlspecialchars($url_foto)."\"></a>
 </td><td style=\"width: 20px;\"></td><td>
 <form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div class=\"linhbox\">
@@ -919,14 +931,14 @@ echo "<table><tr><td valign=\"top\">$num1.</td><td>
 <input type=\"hidden\" name=\"commentofoto\" value=\"SI\">
 <input type=\"hidden\" name=\"numfoto\" value=\"$numfoto\">
 ".ucfirst(mex("commento",$pag)).":<br>";
-$d_commento = esegui_query("select testo from $tabledescrizioni where nome = '$idappartamenti' and tipo = 'appcommfoto' and lingua = 'ita' and numero = '$numfoto' ");
+$d_commento = esegui_query("select testo from $tabledescrizioni where nome = '".aggslashdb($idappartamenti)."' and tipo = 'appcommfoto' and lingua = 'ita' and numero = '$numfoto' ");
 if (numlin_query($d_commento)) $d_commento = risul_query($d_commento,0,'testo');
 else $d_commento = "";
 if ($priv_mod_tariffe != "n") echo "Italiano: <input type=\"text\" name=\"n_commento_ita\" value=\"$d_commento\" size=\"24\"><br>";
 else echo "<div style=\"width: 300px;\">Italiano: \"<em>$d_commento</em>\"</div>";
 reset($lingue_vett);
 foreach ($lingue_vett as $ini_lingua => $nome_lingua) {
-$d_commento = esegui_query("select testo from $tabledescrizioni where nome = '$idappartamenti' and tipo = 'appcommfoto' and lingua = '$ini_lingua' and numero = '$numfoto' ");
+$d_commento = esegui_query("select testo from $tabledescrizioni where nome = '".aggslashdb($idappartamenti)."' and tipo = 'appcommfoto' and lingua = '$ini_lingua' and numero = '$numfoto' ");
 if (numlin_query($d_commento)) $d_commento = risul_query($d_commento,0,'testo');
 else $d_commento = "";
 echo "".ucfirst($nome_lingua).": <input type=\"text\" name=\"n_commento_$ini_lingua\" value=\"$d_commento\" size=\"24\"><br>";
@@ -945,15 +957,15 @@ echo "<button class=\"edtm\" type=\"submit\"><div>".ucfirst(mex("modifica",$pag)
 
 if (defined('C_RESTRIZIONI_DEMO_ADMIN') and C_RESTRIZIONI_DEMO_ADMIN == "SI") $readonly = " readonly=\"readonly\"";
 else $readonly = "";
-echo "<br><form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
+echo "<br><form id=\"aggfoto\" accept-charset=\"utf-8\" method=\"post\" action=\"$pag\" enctype=\"multipart/form-data\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"idappartamenti\" value=\"".$idappartamenti."\">
 <input type=\"hidden\" name=\"aggurlfoto\" value=\"SI\">
 ".ucfirst(mex("url di una nuova foto",$pag)).":
-<input type=\"text\" name=\"n_urlfoto\" size=\"30\" value=\"http://\"$readonly>
-<button class=\"apho\" type=\"submit\"><div>".ucfirst(mex("aggiungi",$pag))."</div></button>
-</div></form>";
+<input id=\"n_urlf\" type=\"text\" name=\"n_urlfoto\" size=\"30\" value=\"http://\"$readonly>
+<button class=\"apho\" type=\"submit\"><div>".ucfirst(mex("aggiungi",$pag))."</div></button><br>
+".upload_hd_img_form('n_urlf',$tablepersonalizza)."</div></form><br></div></div>";
 
 echo "<hr style=\"width: 95%\"><br><div style=\"text-align: center;\">
 <form accept-charset=\"utf-8\" method=\"post\" action=\"modifica_app.php\"><div>
