@@ -78,6 +78,7 @@ if (numlin_query($api_esistente)) $priv_mod_doc = "n";
 if ($priv_mod_doc == "s") {
 
 
+$titolo = "HotelDruid: ".mex("Modifica Documento",$pag);
 if ($tema[$id_utente] and $tema[$id_utente] != "base" and @is_dir("./themes/".$tema[$id_utente]."/php")) include("./themes/".$tema[$id_utente]."/php/head.php");
 else include("./includes/head.php");
 
@@ -181,6 +182,25 @@ unlock_tabelle($tabelle_lock);
 } # fine if ($formato)
 } # fine if ($cambia_formato)
 
+if ($cambia_formati_dati) {
+$tabelle_lock = array($tablecontratti);
+$tabelle_lock = lock_tabelle($tabelle_lock);
+$mostra_form_iniziale = "NO";
+$formati = "";
+if ($stile_soldi_contr == "europa" or $stile_soldi_contr == "usa") $formati = $stile_soldi_contr;
+$formati .= ">";
+if ($stile_data_contr == "europa" or $stile_data_contr == "usa") $formati .= $stile_data_contr;
+if (str_replace(">","",$formati) == "") $formati = "";
+$formati_esist = esegui_query("select * from $tablecontratti where numero = '$num_contratto' and tipo = 'formati' ");
+if (numlin_query($formati_esist)) {
+if ($formati) esegui_query("update $tablecontratti set testo = '".aggslashdb($formati)."' where numero = '$num_contratto' and tipo = 'formati' ");
+else esegui_query("delete from $tablecontratti where numero = '$num_contratto' and tipo = 'formati' ");
+} # fine if (numlin_query($formati_esist))
+elseif ($formati) esegui_query("insert into $tablecontratti (numero,tipo,testo) values ('$num_contratto','formati','".aggslashdb($formati)."') ");
+echo "".mex("Formati predefiniti del documento cambiati",$pag).".<br>";
+unlock_tabelle($tabelle_lock);
+} # fine if ($cambia_formati_dati)
+
 if ($cambia_dir_salva) {
 if (@get_magic_quotes_gpc()) $nuova_dir_salva = stripslashes($nuova_dir_salva);
 $nuova_dir_salva = htmlspecialchars($nuova_dir_salva);
@@ -742,10 +762,15 @@ $testo_agg2 = "\n".mex("SOSTITUISCI CON LISTA APPARTAMENTI",'unit.php')."\n";
 $testo_agg3 = "[/r6]";
 } # fine if ($tipo_rip == 6)
 if ($tipo_rip == 7) {
+$testo_agg1 = "[r7]";
+$testo_agg2 = "\n".mex("SOSTITUISCI CON LISTA DOCUMENTI SALVATI",$pag)."\n";
+$testo_agg3 = "[/r7]";
+} # fine if ($tipo_rip == )
+if ($tipo_rip == 8) {
 $testo_agg1 = "[c ".mex("nome_variabile",$pag)."=\"".mex("valore",$pag)."\"]";
 $testo_agg2 = "\n".mex("SOSTITUISCI CON PARTE DA MOSTRARE SOLO SE E' SODDISFATTA LA CONDIZIONE PRECEDENTE",$pag)." (".mex("nome_variabile",$pag)." = ".mex("OPPURE",$pag)." != ".mex("valore",$pag).")\n";
 $testo_agg3 = "[/c]";
-} # fine if ($tipo_rip == 7)
+} # fine if ($tipo_rip == 8)
 if (!strcmp($pos_curs,"")) $testo_contratto_mod = $n_contratto.$testo_agg1.$testo_agg2.$testo_agg3;
 else {
 $pos_curs = strlen(utf8_encode(substr(utf8_decode($n_contratto),0,$pos_curs)));
@@ -864,6 +889,46 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
 </div></form><br>";
 
 
+$formati = esegui_query("select * from $tablecontratti where numero = '$num_contratto' and tipo = 'formati'");
+if (numlin_query($formati)) {
+$formati = explode(">",risul_query($formati,0,'testo'));
+$stile_soldi_contr = $formati[0];
+$stile_data_contr = $formati[1];
+} # fine if (numlin_query($formati))
+else {
+$stile_soldi_contr = "";
+$stile_data_contr = "";
+} # fine else if (numlin_query($formati))
+echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
+<input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
+<input type=\"hidden\" name=\"num_contratto\" value=\"$num_contratto\">
+<input type=\"hidden\" name=\"cambia_qualcosa\" value=\"SI\">
+<input type=\"hidden\" name=\"cambia_formati_dati\" value=\"1\">
+<table border=0 cellspacing=0 cellpadding=0><tr>
+<td align=\"center\">".mex("Formato dei soldi",$pag).":</td>";
+if ($stile_soldi_contr != "europa" and $stile_soldi_contr != "usa") $check_soldi_ut = " selected";
+if ($stile_soldi_contr == "europa") $check_soldi_eu = " selected";
+if ($stile_soldi_contr == "usa") $check_soldi_usa = " selected";
+if ($stile_data_contr != "europa" and $stile_data_contr != "usa") $check_data_ut = " selected";
+if ($stile_data_contr == "europa") $check_data_eu = " selected";
+if ($stile_data_contr == "usa") $check_data_usa = " selected";
+echo "<td align=\"left\"><select name=\"stile_soldi_contr\">
+<option value=\"\"$check_soldi_ut>".mex("formato dell'utente",$pag)."</option>
+<option value=\"europa\"$check_soldi_eu>1.050.000,32</option>
+<option value=\"usa\"$check_soldi_usa>1,050,000.32</option>
+</select></td><td>&nbsp;&nbsp;&nbsp;</td>
+<td align=\"center\">".mex("Formato delle date",$pag).":</td>
+<td align=\"left\"><select name=\"stile_data_contr\">
+<option value=\"\"$check_data_ut>".mex("formato dell'utente",$pag)."</option>
+<option value=\"europa\"$check_data_eu>27-08-2002</option>
+<option value=\"usa\"$check_data_usa>08-27-2002</option>
+</select></td><td align=\"center\">&nbsp;&nbsp;
+<button class=\"edtm\" type=\"submit\"><div>".mex("Cambia",$pag)."</div></button>
+</td></tr></table>
+</div></form><br>";
+
+
 if ($tipo_contratto == "rtf" or $tipo_contratto == "htm" or $tipo_contratto == "txt") {
 $dir_salva = esegui_query("select * from $tablecontratti where numero = '$num_contratto' and tipo = 'dir'");
 if (numlin_query($dir_salva) == 1) {
@@ -1096,6 +1161,7 @@ $link5 = "$link_api?doc=$num_contratto&pass=$pass_api&res_arr=$oggi";
 $link6 = "$link_api?doc=$num_contratto&pass=$pass_api&res_dep=today";
 $link7 = "$link_api?doc=$num_contratto&pass=$pass_api&clients=all";
 $link8 = "$link_api?doc=$num_contratto&pass=$pass_api&clients=guests";
+$link9 = "$link_api?doc=$num_contratto&pass=$pass_api&cashbox=".mex("nome_cassa",$pag);
 echo "<div style=\"padding-top: 4px;\"></div>
 <table class=\"rbox\" cellspacing=0 cellpadding=0><tr><td>
 <div style=\"padding-top: 4px;\"><em>".mex("Esempi di URL per chiamare il documento",$pag)."</em>:</div>
@@ -1110,6 +1176,7 @@ echo "<div style=\"padding-top: 4px;\"></div>
 <div style=\"padding-top: 6px;\">".mex("Tutti le partenze del",$pag)." ".formatta_data($oggi,$stile_data).": <input type=\"text\" readonly onClick=\"this.select();\" value=\"$link6\" size=\"".(strlen($link6) + 1)."\"></div>
 <div style=\"padding-top: 6px;\">".mex("Tutti i clienti",$pag)." (".mex("escludendo gli ospiti",$pag)."): <input type=\"text\" readonly onClick=\"this.select();\" value=\"$link7\" size=\"".(strlen($link7) + 1)."\"></div>
 <div style=\"padding-top: 6px;\">".mex("Tutti i clienti",$pag)." (".mex("inclusi gli ospiti",$pag)."): <input type=\"text\" readonly onClick=\"this.select();\" value=\"$link8\" size=\"".(strlen($link8) + 1)."\"></div>
+<div style=\"padding-top: 6px;\">".mex("Tutti i pagamenti nella cassa",$pag)." \"".mex("nome_cassa",$pag)."\": <input type=\"text\" readonly onClick=\"this.select();\" value=\"$link9\" size=\"".(strlen($link9) + 1)."\"></div>
 </td></tr></table>
 </td></tr></table>";
 } # fine if ($checked)
@@ -1401,7 +1468,13 @@ $option_array .= "<option value=\"a$arr_pers\">".mex("ripetizione array",$pag)."
 } # fine for $num1
 
 for ($num1 = 0 ; $num1 < $num_var_predef ; $num1++) {
-$linea_mod .= "<option value=\"".mex2($var_predef[$num1])."\">".mex2($var_predef[$num1])."</option>";
+$linea_mod .= "<option value=\"".mex2($var_predef[$num1])."\">".mex2($var_predef[$num1]);
+if (substr($var_predef[$num1],-7) == "_ospite") $linea_mod .= " (r2)";
+if (substr($var_predef[$num1],-10) == "_costo_agg" or substr($var_predef[$num1],-12) == "_costo_agg_p" or substr($var_predef[$num1],0,28) == "valore_costo_agg_senza_tasse") $linea_mod .= " (r3)";
+if ((substr($var_predef[$num1],-10) == "_pagamento" or substr($var_predef[$num1],-12) == "_pagamento_p") and !strstr($var_predef[$num1],"_ultimo_pagamento")) $linea_mod .= " (r5)";
+if (substr($var_predef[$num1],-6) == "_unita") $linea_mod .= " (r6)";
+if (substr($var_predef[$num1],-18) == "_documento_salvato") $linea_mod .= " (r7)";
+$linea_mod .= "</option>";
 } # fine for $num1
 $linea_mod .= "</select>
 <input class=\"sbutton\" type=\"submit\" name=\"aggiungi_var\" value=\"".mex("Aggiungi",$pag)."\">
@@ -1414,7 +1487,8 @@ $linea_mod .= "<option value=\"2\">".mex("ripetizione ospiti",$pag)." [r2]...[/r
 $option_array
 <option value=\"5\">".mex("ripetizione pagamenti",$pag)." [r5]...[/r5]</option>
 <option value=\"6\">".mex("ripetizione unità",$pag)." [r6]...[/r6]</option>
-<option value=\"7\">".mex("parte sotto condizione",$pag)." [c]...[/c]</option>
+<option value=\"7\">".mex("ripetizione documenti salvati",$pag)." [r7]...[/r7]</option>
+<option value=\"8\">".mex("parte sotto condizione",$pag)." [c]...[/c]</option>
 </select>
 <input class=\"sbutton\" type=\"submit\" name=\"aggiungi_ripetizione\" value=\"".mex("Aggiungi",$pag)."\">
 </td></tr>";
