@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2017 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2019 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -21,7 +21,7 @@
 ##################################################################################
 
 $pag = "modifica_costi.php";
-$titolo = "HotelDruid: Modifica Costi";
+$titolo = "HotelDruid: Modifica Costi Aggiuntivi";
 $base_js = 1;
 
 include("./costanti.php");
@@ -170,6 +170,7 @@ $priv_mod_costo_agg = "s";
 if ($anno_utente_attivato == "SI" and $priv_mod_costo_agg != "n") {
 
 
+$titolo = "HotelDruid: ".mex("Modifica Costi Aggiuntivi",$pag);
 if ($tema[$id_utente] and $tema[$id_utente] != "base" and @is_dir("./themes/".$tema[$id_utente]."/php")) include("./themes/".$tema[$id_utente]."/php/head.php");
 else include("./includes/head.php");
 
@@ -230,7 +231,7 @@ $mostra_form_iniziale = "NO";
 $conflitti = "";
 $note_mantenere = "";
 
-if (get_magic_quotes_gpc()) $n_nome = (string) stripslashes($n_nome);
+if (@get_magic_quotes_gpc()) $n_nome = (string) stripslashes($n_nome);
 if ($n_nome != "") $nomecostoagg = (string) htmlspecialchars($n_nome);
 else $nomecostoagg = (string) $dati_ca[$num_costo]['nome'];
 $nomecostoagg = str_replace("#?&","",$nomecostoagg);
@@ -240,7 +241,7 @@ if (!$nomecostoagg) {
 $messaggio_errore = mex("Si deve inserire il nome del costo aggiuntivo",$pag).".<br>";
 $errore = "SI";
 } # fine if (!$nomecostoagg)
-if (get_magic_quotes_gpc()) $categoria_ca = stripslashes($categoria_ca);
+if (@get_magic_quotes_gpc()) $categoria_ca = stripslashes($categoria_ca);
 $categoria_ca = htmlspecialchars($categoria_ca);
 if ($tipo_ca != "u" and $tipo_ca != "s") $errore = "SI";
 if ($errore != "SI" and (($n_nome != "" and $n_nome != $dati_ca[$num_costo]['nome']) or $tipo_ca != $dati_ca[$num_costo]['tipo'])) {
@@ -257,7 +258,7 @@ $arrotonda_ca = formatta_soldi($arrotonda_ca);
 $tasseperc_ca = formatta_soldi($tasseperc_ca);
 if (!strcmp($valore_f_ca,"") and !strcmp($valore_p_ca,"")) $errore = "SI";
 if (strcmp($valore_f_ca,"") and controlla_soldi($valore_f_ca) == "NO") $errore = "SI";
-if (strcmp($valore_p_ca,"") and (controlla_soldi($valore_p_ca) == "NO" or !strcmp($arrotonda_ca,"") or controlla_soldi($arrotonda_ca,"SI") == "NO")) $errore = "SI";
+if (strcmp($valore_p_ca,"") and (controlla_soldi($valore_p_ca) == "NO" or !$arrotonda_ca or controlla_soldi($arrotonda_ca,"SI") == "NO")) $errore = "SI";
 if ($valore_p_ca and $tipo_percentuale != "tariffa" and $tipo_percentuale != "tariffafissa" and $tipo_percentuale != "tariffapers" and $tipo_percentuale != "totale" and $tipo_percentuale != "caparra" and $tipo_percentuale != "resto") $errore = "SI";
 if ($valore_p_ca and $tipo_ca == "s" and substr($tipo_percentuale,0,7) != "tariffa") { $errore = "SI"; $conflitti .= "2-3;"; }
 if (($tasseperc_ca and controlla_soldi($tasseperc_ca) == "NO") or $tasseperc_ca > 100 or $tasseperc_ca < 0) $errore = "SI";
