@@ -70,6 +70,7 @@ $attiva_contratti_consentiti = "n";
 if ($anno_utente_attivato == "SI" and $priv_mod_doc == "s" and $modifica_pers != "NO") {
 
 
+$titolo = "HotelDruid: ".mex("Modifica Variabili Documenti",$pag);
 if ($tema[$id_utente] and $tema[$id_utente] != "base" and @is_dir("./themes/".$tema[$id_utente]."/php")) include("./themes/".$tema[$id_utente]."/php/head.php");
 else include("./includes/head.php");
 
@@ -459,7 +460,7 @@ $inizializza = "rar$num_arr_rip";
 $arr_esistente = esegui_query("select * from $tablecontratti where (tipo = 'vett' or tipo = 'vett$contr_cond') and numero = '".aggslashdb($num_arr_rip)."'");
 if (numlin_query($arr_esistente) != 1) $continua = "NO";
 } # fine if (substr($inizializza,0,1) == "a")
-if ($inizializza != "rpt" and $inizializza != "inr" and $inizializza != "ind" and $inizializza != "ros" and $inizializza != "rca" and $inizializza != "rpa" and $inizializza != "run" and preg_replace("/rar[1-9][0-9]*/","",$inizializza) != "") $continua = "NO";
+if ($inizializza != "rpt" and $inizializza != "inr" and $inizializza != "ind" and $inizializza != "ros" and $inizializza != "rca" and $inizializza != "rpa" and $inizializza != "run" and $inizializza != "rds" and preg_replace("/rar[1-9][0-9]*/","",$inizializza) != "") $continua = "NO";
 if (strcmp($cond_sempre,"") and $cond_sempre != "SI" and $cond_sempre != "NO") $continua = "NO";
 if ($azione != "set" and $azione != "trunc" and $azione != "oper" and $azione != "date" and $azione != "unset" and $azione != "array" and $azione != "break" and $azione != "cont") $continua = "NO";
 if ($oper_data and $azione = "date") $azione = "opdat";
@@ -874,7 +875,7 @@ $ordine_rar .= ", testo $LIKE 'rar$num_arr_rip%' desc";
 
 $azione_orig = $azione;
 $num_cond_mod_vedi = "";
-$condizioni = esegui_query("select * from $tablecontratti where tipo = 'cond$contr_cond' order by testo $LIKE 'ind%' desc, testo $LIKE 'inr%' desc, testo $LIKE 'rpt%' desc, testo $LIKE 'ros%' desc, testo $LIKE 'rca%' desc, testo $LIKE 'rpa%' desc, testo $LIKE 'run%' desc$ordine_rar, numero");
+$condizioni = esegui_query("select * from $tablecontratti where tipo = 'cond$contr_cond' order by testo $LIKE 'ind%' desc, testo $LIKE 'inr%' desc, testo $LIKE 'rpt%' desc, testo $LIKE 'ros%' desc, testo $LIKE 'rca%' desc, testo $LIKE 'rpa%' desc, testo $LIKE 'run%' desc, testo $LIKE 'rds%' desc$ordine_rar, numero");
 $num_condizioni = numlin_query($condizioni);
 $num_cond_ini_d = 0;
 $num_cond_ini_r = 0;
@@ -883,6 +884,7 @@ $num_cond_rip_o = 0;
 $num_cond_rip_c = 0;
 $num_cond_rip_p = 0;
 $num_cond_rip_u = 0;
+$num_cond_rip_d = 0;
 for ($num1 = 0 ; $num1 < $num_condizioni ; $num1++) {
 $n_cond = risul_query($condizioni,$num1,'numero');
 $cond = risul_query($condizioni,$num1,'testo');
@@ -893,6 +895,7 @@ if (substr($cond,0,3) == "ros") $num_cond_rip_o = $num1 + 1;
 if (substr($cond,0,3) == "rca") $num_cond_rip_c = $num1 + 1;
 if (substr($cond,0,3) == "rpa") $num_cond_rip_p = $num1 + 1;
 if (substr($cond,0,3) == "run") $num_cond_rip_u = $num1 + 1;
+if (substr($cond,0,3) == "rds") $num_cond_rip_d = $num1 + 1;
 if (substr($cond,0,3) == "rar") {
 $num_arr_rip = substr($cond,3,(strlen(strstr($cond,"#@?")) * -1));
 $num_cond_rip_a[$num_cond_rip_a['num'][$num_arr_rip]] = $num1 + 1;
@@ -906,14 +909,15 @@ if ($num_cond_rip_o < $num_cond_rpt) $num_cond_rip_o = $num_cond_rpt;
 if ($num_cond_rip_c < $num_cond_rip_o) $num_cond_rip_c = $num_cond_rip_o;
 if ($num_cond_rip_p < $num_cond_rip_c) $num_cond_rip_p = $num_cond_rip_c;
 if ($num_cond_rip_u < $num_cond_rip_p) $num_cond_rip_u = $num_cond_rip_p;
-if ($num_cond_rip_a[1] < $num_cond_rip_u) $num_cond_rip_a[1] = $num_cond_rip_u;
+if ($num_cond_rip_d < $num_cond_rip_u) $num_cond_rip_d = $num_cond_rip_u;
+if ($num_cond_rip_a[1] < $num_cond_rip_d) $num_cond_rip_a[1] = $num_cond_rip_d;
 for ($num1 = 1 ; $num1 < $num_rip_a ; $num1++) if ($num_cond_rip_a[($num1 + 1)] < $num_cond_rip_a[$num1]) $num_cond_rip_a[($num1 + 1)] = $num_cond_rip_a[$num1];
 if ($num_cond and $num_cond_passa < 20) echo "<a name=\"condizioni\"></a>";
 echo "<div class=\"rbox\">".mex("<b>Condizioni</b> applicate",$pag)." $frase_cond_contr:<br>
 <table><tr><td style=\"height: 5px;\"></td></tr></table>";
 
 if ($num_condizioni > 0) {
-$tab_cond = "";
+echo "<table>";
 for ($num1 = 0 ; $num1 < $num_condizioni ; $num1++) {
 $condizione = risul_query($condizioni,$num1,'testo');
 $num_cond = risul_query($condizioni,$num1,'numero');
@@ -927,14 +931,15 @@ $num_cond_mod_orig = $num_cond_mod;
 if ($agg_se or $canc_se) $num_cond_mod = "";
 } # fine if ($num_cond_mod == $num_cond)
 
-if ($num1 == $num_cond_rpt and $condizione[0] == "ros") $tab_cond .= "</table><br>".mex("Condizioni applicate",$pag)." ".mex("solo nelle ripetizioni degli ospiti",$pag)." (<em>".mex("tutte le altre condizioni non verranno più applicate in queste ripetizioni",$pag)."</em>):<br><table>";
-if ($num1 == $num_cond_rip_o and $condizione[0] == "rca") $tab_cond .= "</table><br>".mex("Condizioni applicate",$pag)." ".mex("solo nelle ripetizioni dei costi aggiuntivi",$pag)." (<em>".mex("tutte le altre condizioni non verranno più applicate in queste ripetizioni",$pag)."</em>):<br><table>";
-if ($num1 == $num_cond_rip_c and $condizione[0] == "rpa") $tab_cond .= "</table><br>".mex("Condizioni applicate",$pag)." ".mex("solo nelle ripetizioni dei pagamenti",$pag)." (<em>".mex("tutte le altre condizioni non verranno più applicate in queste ripetizioni",$pag)."</em>):<br><table>";
-if ($num1 == $num_cond_rip_p and $condizione[0] == "run") $tab_cond .= "</table><br>".mex("Condizioni applicate",$pag)." ".mex("solo nelle ripetizioni delle unità",$pag)." (<em>".mex("tutte le altre condizioni non verranno più applicate in queste ripetizioni",$pag)."</em>):<br><table>";
-if ($num1 == $num_cond_rip_u and $condizione[0] == "rar".$num_cond_rip_a['arr'][1]) $tab_cond .= "</table><br>".mex("Condizioni applicate",$pag)." ".mex("solo nelle ripetizioni dell'array",$pag)." [".$nome_var["a".$num_cond_rip_a['arr'][1]]."] (<em>".mex("tutte le altre condizioni non verranno più applicate in queste ripetizioni",$pag)."</em>):<br><table>";
-for ($num2 = 1 ; $num2 < $num_rip_a ; $num2++) if ($num1 == $num_cond_rip_a[$num2] and $condizione[0] == "rar".$num_cond_rip_a['arr'][($num2 + 1)]) $tab_cond .= "</table><br>".mex("Condizioni applicate",$pag)." ".mex("solo nelle ripetizioni dell'array",$pag)." [".$nome_var["a".$num_cond_rip_a['arr'][($num2 + 1)]]."] (<em>".mex("tutte le altre condizioni non verranno più applicate in queste ripetizioni",$pag)."</em>):<br><table>";
-$tab_cond .= "<tr style=\"background-color: ".rowbgcolor().";\"><td><b>".($num1 + 1)."</b>. ";
-if ($num_cond_passa == ($num1 + 20)) $tab_cond .= "<a name=\"condizioni\"></a>";
+if ($num1 == $num_cond_rpt and $condizione[0] == "ros") echo "</table><br>".mex("Condizioni applicate",$pag)." ".mex("solo nelle ripetizioni degli ospiti",$pag)." (<em>".mex("tutte le altre condizioni non verranno più applicate in queste ripetizioni",$pag)."</em>):<br><table>";
+if ($num1 == $num_cond_rip_o and $condizione[0] == "rca") echo "</table><br>".mex("Condizioni applicate",$pag)." ".mex("solo nelle ripetizioni dei costi aggiuntivi",$pag)." (<em>".mex("tutte le altre condizioni non verranno più applicate in queste ripetizioni",$pag)."</em>):<br><table>";
+if ($num1 == $num_cond_rip_c and $condizione[0] == "rpa") echo "</table><br>".mex("Condizioni applicate",$pag)." ".mex("solo nelle ripetizioni dei pagamenti",$pag)." (<em>".mex("tutte le altre condizioni non verranno più applicate in queste ripetizioni",$pag)."</em>):<br><table>";
+if ($num1 == $num_cond_rip_p and $condizione[0] == "run") echo "</table><br>".mex("Condizioni applicate",$pag)." 111".mex("solo nelle ripetizioni delle unità",$pag)." (<em>".mex("tutte le altre condizioni non verranno più applicate in queste ripetizioni",$pag)."</em>):<br><table>";
+if ($num1 == $num_cond_rip_u and $condizione[0] == "rds") echo "</table><br>".mex("Condizioni applicate",$pag)." ".mex("solo nelle ripetizioni dei documenti salvati",$pag)." (<em>".mex("tutte le altre condizioni non verranno più applicate in queste ripetizioni",$pag)."</em>):<br><table>";
+if ($num1 == $num_cond_rip_d and $condizione[0] == "rar".$num_cond_rip_a['arr'][1]) echo "</table><br>".mex("Condizioni applicate",$pag)." ".mex("solo nelle ripetizioni dell'array",$pag)." [".$nome_var["a".$num_cond_rip_a['arr'][1]]."] (<em>".mex("tutte le altre condizioni non verranno più applicate in queste ripetizioni",$pag)."</em>):<br><table>";
+for ($num2 = 1 ; $num2 < $num_rip_a ; $num2++) if ($num1 == $num_cond_rip_a[$num2] and $condizione[0] == "rar".$num_cond_rip_a['arr'][($num2 + 1)]) echo "</table><br>".mex("Condizioni applicate",$pag)." ".mex("solo nelle ripetizioni dell'array",$pag)." [".$nome_var["a".$num_cond_rip_a['arr'][($num2 + 1)]]."] (<em>".mex("tutte le altre condizioni non verranno più applicate in queste ripetizioni",$pag)."</em>):<br><table>";
+echo "<tr style=\"background-color: ".rowbgcolor().";\"><td><b>".($num1 + 1)."</b>. ";
+if ($num_cond_passa == ($num1 + 20)) echo "<a name=\"condizioni\"></a>";
 $str_cond = "";
 
 if ($condizione[1]) {
@@ -1129,14 +1134,16 @@ if ($condizione[0] == "ros") $str_cond .= " ".mex("solo nelle ripetizioni degli
 if ($condizione[0] == "rca") $str_cond .= " ".mex("solo nelle ripetizioni dei costi aggiuntivi",$pag);
 if ($condizione[0] == "rpa") $str_cond .= " ".mex("solo nelle ripetizioni dei pagamenti",$pag);
 if ($condizione[0] == "run") $str_cond .= " ".mex("solo nelle ripetizioni delle unità",$pag);
+if ($condizione[0] == "rds") $str_cond .= " ".mex("solo nelle ripetizioni dei documenti salvati",$pag);
 if (substr($condizione[0],0,3) == "rar") $str_cond .= " ".mex("solo nelle ripetizioni dell'array",$pag)." [".$nome_var["a".substr($condizione[0],3)]."]";
-$tab_cond .= ucfirst($str_cond).".</td>";
+echo ucfirst($str_cond).".</td>";
 $fine_cond_rip_a = 0;
 for ($num2 = 1 ; $num2 <= $num_rip_a ; $num2++) if ($num1 == ($num_cond_rip_a[$num2] - 1)) $fine_cond_rip_a = 1;
-if ($num1 != ($num_condizioni - 1) and $num1 != ($num_cond_ini_r - 1) and $num1 != ($num_cond_ini_d - 1) and $num1 != ($num_cond_rpt - 1) and $num1 != ($num_cond_rip_o - 1) and $num1 != ($num_cond_rip_c - 1) and $num1 != ($num_cond_rip_p - 1) and $num1 != ($num_cond_rip_u - 1) and !$fine_cond_rip_a) {
+if ($num1 != ($num_condizioni - 1) and $num1 != ($num_cond_ini_r - 1) and $num1 != ($num_cond_ini_d - 1) and $num1 != ($num_cond_rpt - 1) and $num1 != ($num_cond_rip_o - 1) and $num1 != ($num_cond_rip_c - 1) and $num1 != ($num_cond_rip_p - 1) and $num1 != ($num_cond_rip_u - 1) and $num1 != ($num_cond_rip_d - 1) and !$fine_cond_rip_a) {
 $opt_giu = "";
 $fine_opt = $num_condizioni;
 for ($num2 = $num_rip_a ; $num2 > 0 ; $num2--) if ($num1 < ($num_cond_rip_a[$num2] - 1)) $fine_opt = $num_cond_rip_a[$num2];
+if ($num1 < ($num_cond_rip_d - 1)) $fine_opt = $num_cond_rip_d;
 if ($num1 < ($num_cond_rip_u - 1)) $fine_opt = $num_cond_rip_u;
 if ($num1 < ($num_cond_rip_p - 1)) $fine_opt = $num_cond_rip_p;
 if ($num1 < ($num_cond_rip_c - 1)) $fine_opt = $num_cond_rip_c;
@@ -1145,7 +1152,7 @@ if ($num1 < ($num_cond_rpt - 1)) $fine_opt = $num_cond_rpt;
 if ($num1 < ($num_cond_ini_r - 1)) $fine_opt = $num_cond_ini_r;
 if ($num1 < ($num_cond_ini_d - 1)) $fine_opt = $num_cond_ini_d;
 for ($num2 = ($num1 + 2) ; $num2 <= $fine_opt ; $num2++) $opt_giu .= "<option value=\"".$cond_vett[($num2 - 1)]."\">$num2</option>";
-$tab_cond .= "<td><form accept-charset=\"utf-8\" method=\"post\" action=\"$pag#condizioni\"><div>
+echo "<td><form accept-charset=\"utf-8\" method=\"post\" action=\"$pag#condizioni\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 $input_cond_contr
@@ -1156,10 +1163,10 @@ $input_cond_contr
 <img style=\"display: block;\" src=\"./img/freccia_giu_marg.png\" alt=\"&lt;\">
 </button></td></tr></table></div></form></td>";
 } # fine if ($num1 != ($num_condizioni - 1) and $num1 != ($num_cond_ini_r - 1) and...
-else $tab_cond .= "<td></td>";
+else echo "<td></td>";
 $fine_cond_rip_a = 0;
 for ($num2 = 1 ; $num2 <= $num_rip_a ; $num2++) if ($num1 == $num_cond_rip_a[$num2]) $fine_cond_rip_a = 1;
-if ($num1 != 0 and $num1 != $num_cond_ini_r and $num1 != $num_cond_ini_d and $num1 != $num_cond_rpt and $num1 != $num_cond_rip_o and $num1 != $num_cond_rip_c and $num1 != $num_cond_rip_p and $num1 != $num_cond_rip_u and !$fine_cond_rip_a) {
+if ($num1 != 0 and $num1 != $num_cond_ini_r and $num1 != $num_cond_ini_d and $num1 != $num_cond_rpt and $num1 != $num_cond_rip_o and $num1 != $num_cond_rip_c and $num1 != $num_cond_rip_p and $num1 != $num_cond_rip_u and $num1 != $num_cond_rip_d and !$fine_cond_rip_a) {
 $opt_su = "";
 $fine_opt = 1;
 if ($num1 > $num_cond_ini_d) $fine_opt = ($num_cond_ini_d + 1);
@@ -1169,9 +1176,10 @@ if ($num1 > $num_cond_rip_o) $fine_opt = ($num_cond_rip_o + 1);
 if ($num1 > $num_cond_rip_c) $fine_opt = ($num_cond_rip_c + 1);
 if ($num1 > $num_cond_rip_p) $fine_opt = ($num_cond_rip_p + 1);
 if ($num1 > $num_cond_rip_u) $fine_opt = ($num_cond_rip_u + 1);
+if ($num1 > $num_cond_rip_d) $fine_opt = ($num_cond_rip_d + 1);
 for ($num2 = 1 ; $num2 <= $num_rip_a ; $num2++) if ($num1 > $num_cond_rip_a[$num2]) $fine_opt = ($num_cond_rip_a[$num2] + 1);
 for ($num2 = $num1 ; $num2 >= $fine_opt ; $num2--) $opt_su .= "<option value=\"".$cond_vett[($num2 - 1)]."\">$num2</option>";
-$tab_cond .= "<td><form accept-charset=\"utf-8\" method=\"post\" action=\"$pag#condizioni\"><div>
+echo "<td><form accept-charset=\"utf-8\" method=\"post\" action=\"$pag#condizioni\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 $input_cond_contr
@@ -1182,8 +1190,8 @@ $input_cond_contr
 </button></td><td><select class=\"smallsel\" name=\"salta_a\">$opt_su</select>
 </td></tr></table></div></form></td>";
 } # fine if ($num1 != 0 and $num1 != $num_cond_ini_r and $num1 != $num_cond_ini_d and...
-else $tab_cond .= "<td></td>";
-$tab_cond .= "<td><form accept-charset=\"utf-8\" method=\"post\" action=\"$pag#modcond\"><div>
+else echo "<td></td>";
+echo "<td><form accept-charset=\"utf-8\" method=\"post\" action=\"$pag#modcond\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 $input_cond_contr
@@ -1200,9 +1208,7 @@ $input_cond_contr
 </div></form></td></tr>";
  if ($num_cond_mod_orig == $num_cond) $num_cond_mod = $num_cond_mod_orig;
 } # fine for $num1
-echo "<table>
-$tab_cond
-</table>";
+echo "</table>";
 } # fine if ($num_condizioni > 0)
 else echo "<br>";
 echo "</div><br>";
@@ -1284,6 +1290,7 @@ $sel_iniros = "";
 $sel_inirca = "";
 $sel_inirpa = "";
 $sel_inirun = "";
+$sel_inirds = "";
 if (!$inizializza or $inizializza == "rpt") $sel_rip = " selected";
 if ($inizializza == "inr") $sel_inirip = " selected";
 if ($inizializza == "ind") $sel_inidoc = " selected";
@@ -1291,6 +1298,7 @@ if ($inizializza == "ros") $sel_iniros = " selected";
 if ($inizializza == "rca") $sel_inirca = " selected";
 if ($inizializza == "rpa") $sel_inirpa = " selected";
 if ($inizializza == "run") $sel_inirun = " selected";
+if ($inizializza == "rds") $sel_inirds = " selected";
 $option_arr_rip = str_replace("\">","\">".mex("solo nelle ripetizioni dell'array",$pag)." ",$option_arr_pers);
 if (substr($inizializza,0,3) == "rar") {
 $num_arr_rip = substr($inizializza,3);
@@ -1317,6 +1325,7 @@ echo " <select name=\"inizializza\">
 <option value=\"rca\"$sel_inirca>".mex("solo nelle ripetizioni dei costi aggiuntivi",$pag)."</option>
 <option value=\"rpa\"$sel_inirpa>".mex("solo nelle ripetizioni dei pagamenti",$pag)."</option>
 <option value=\"run\"$sel_inirun>".mex("solo nelle ripetizioni delle unità",$pag)."</option>
+<option value=\"rds\"$sel_inirds>".mex("solo nelle ripetizioni dei documenti salvati",$pag)."</option>
 $option_arr_rip
 </select>:<br>
 
