@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2018 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2019 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -152,6 +152,7 @@ if ($anno_utente_attivato == "SI" and $priv_mod_prenotazioni != "n" and $priv_mo
 
 
 if ($priv_ins_nuove_prenota == "n") $show_bar = "NO";
+$titolo = "HotelDruid: ".mex("Punto Vendita",$pag);
 if ($tema[$id_utente] and $tema[$id_utente] != "base" and @is_dir("./themes/".$tema[$id_utente]."/php")) include("./themes/".$tema[$id_utente]."/php/head.php");
 else include("./includes/head.php");
 
@@ -689,7 +690,7 @@ if ($id_cassa_sel == $id_cassa) $cassa_trovata = 1;
 } # fine for $num1
 if (!$num_casse_attive) {
 $errore_cassa = 1;
-if ($tabelle_lock) unlock($tabelle_lock);
+if ($tabelle_lock) unlock_tabelle($tabelle_lock);
 } # fine if (!$num_casse_attive)
 if (!$cassa_trovata) $id_cassa_sel = "";
 } # fine if ($id_costi and !$errore_cassa)
@@ -700,17 +701,35 @@ $azione = 1;
 
 $metodi_pagamento = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'metodi_pagamento' and idutente = '$id_utente'");
 $metodi_pagamento = risul_query($metodi_pagamento,0,'valpersonalizza');
-if (($num_casse_attive > 1 or $metodi_pagamento) and !$id_cassa_sel) {
+$altre_valute = altre_valute();
+if (($num_casse_attive > 1 or $metodi_pagamento or $altre_valute['num']) and !$id_cassa_sel) {
 $testo_azione = "<input type=\"hidden\" name=\"id_costi\" value=\"$id_costi\">
 <input type=\"hidden\" name=\"incassa\" value=\"1\">
 <input type=\"hidden\" name=\"categoria\" value=\"".htmlspecialchars($categoria)."\">
 <input type=\"hidden\" name=\"id_prenota\" value=\"$id_prenota\">";
+if ($altre_valute['num']) {
+$val_entrata = formatta_soldi($val_tot);
+$testo_azione .= "<br>".mex("Valuta",$pag).":<br><br>
+<select name=\"valuta_pagamento_sel\" style=\"font-size: xx-large;\">
+<option value=\"\">".punti_in_num($val_entrata,$stile_soldi)." $Euro</option>";
+for ($num1 = 0 ; $num1 < $altre_valute['num'] ; $num1++) {
+$val_entrata_valuta = (double) $val_entrata * (double) $altre_valute[$num1]['cambio'];
+$val_entrata_valuta = $val_entrata_valuta / (double) $altre_valute[$num1]['arrotond'];
+$val_entrata_valuta = round($val_entrata_valuta);
+$val_entrata_valuta = $val_entrata_valuta * (double) $altre_valute[$num1]['arrotond'];
+$val_entrata_valuta_p = punti_in_num($val_entrata_valuta,$stile_soldi);
+#if (substr($val_entrata_valuta_p,0,1) != "-") $val_entrata_valuta_p = "+".$val_entrata_valuta_p;
+$testo_azione .=  "<option value=\"".htmlspecialchars($altre_valute[$num1]['nome'])."\">$val_entrata_valuta_p ".$altre_valute[$num1]['nome']."</option>";
+} # fine for $num1
+$testo_azione .= "</select>";
+if ($metodi_pagamento) $testo_azione .= "<br><br>";
+} # fine if ($altre_valute['num'])
 if ($metodi_pagamento) {
 $testo_azione .= "<br>".mex("Metodo pagamento",$pag).":<br><br>
 <select name=\"metodo_pagamento_sel\" style=\"font-size: xx-large;\">
 <option value=\"\">----</option>";
 $metodi_pagamento = explode(",",$metodi_pagamento);
-for ($num1 = 0 ; $num1 < count($metodi_pagamento) ; $num1++) $testo_azione .= "<option value=\"".$metodi_pagamento[$num1]."\"$sel>".$metodi_pagamento[$num1]."</option>";
+for ($num1 = 0 ; $num1 < count($metodi_pagamento) ; $num1++) $testo_azione .= "<option value=\"".htmlspecialchars($metodi_pagamento[$num1])."\"$sel>".$metodi_pagamento[$num1]."</option>";
 $testo_azione .= "</select>";
 } # fine if ($metodi_pagamento)
 for ($num1 = 1 ; $num1 <= $num_casse_attive ; $num1++) {
@@ -719,14 +738,14 @@ if ($id_casse[$num1] == 1) $testo_azione .= mex("in cassa principale",$pag)."</b
 else $testo_azione .= mex("in cassa",$pag)." \"".$nomi_casse[$id_casse[$num1]]."\"</b></button>";
 } # fine for $num1
 $testo_azione .= "<button class=\"pos\" type=\"submit\" name=\"canc_incassa\" value=\"1\" style=\"height: 60px; width: 140px; margin: 2px;\"><b>".mex("Annulla",$pag)."</b></button>";
-} # fine if (($num_casse_attive > 1 or $metodi_pagamento) and !$id_cassa_sel)
+} # fine if (($num_casse_attive > 1 or $metodi_pagamento or $altre_valute['num']) and !$id_cassa_sel)
 
 else {
 if ($num_casse_attive == 1) $id_cassa = $id_casse[1];
 else $id_cassa = $id_cassa_sel;
 $nome_cassa = $nomi_casse[$id_cassa];
 if (strcmp($metodo_pagamento_sel,"")) {
-if (get_magic_quotes_gpc()) $metodo_pagamento_sel = stripslashes($metodo_pagamento_sel);
+if (@get_magic_quotes_gpc()) $metodo_pagamento_sel = stripslashes($metodo_pagamento_sel);
 $metodo_pagamento_sel = htmlspecialchars($metodo_pagamento_sel);
 if (str_replace(",$metodo_pagamento_sel,",",",",$metodi_pagamento,") == ",$metodi_pagamento,") $metodo_pagamento_sel = "";
 } # fine if (strcmp($metodo_pagamento_sel,""))
@@ -741,6 +760,23 @@ $provenienza_costo = "";
 $idcosti = esegui_query("select max(idcosti) from $tablecosti");
 $idcosti = risul_query($idcosti,0,0) + 1;
 esegui_query("insert into $tablecosti (idcosti,nome_costo,val_costo,tipo_costo,nome_cassa,persona_costo,provenienza_costo,metodo_pagamento,datainserimento,hostinserimento,utente_inserimento) values ('$idcosti','".aggslashdb($testo_costi)."','$val_entrata','e','".aggslashdb($nome_cassa)."','".aggslashdb($persona_costo)."','".aggslashdb($provenienza_costo)."','".aggslashdb($metodo_pagamento_sel)."','$datainserimento','$HOSTNAME','$id_utente') ");
+if ($altre_valute['num'] and strcmp($altre_valute['id'][$valuta_pagamento_sel],"")) {
+$valuta_corr = $altre_valute['id'][$valuta_pagamento_sel];
+$val_entrata_valuta = (double) $val_entrata * (double) $altre_valute[$valuta_corr]['cambio'];
+$val_entrata_valuta = $val_entrata_valuta / (double) $altre_valute[$valuta_corr]['arrotond'];
+$val_entrata_valuta = round($val_entrata_valuta);
+$val_entrata_valuta = $val_entrata_valuta * (double) $altre_valute[$valuta_corr]['arrotond'];
+$valuta = $altre_valute[$valuta_corr]['nome'].">".$altre_valute[$valuta_corr]['cambio'].">".$altre_valute[$valuta_corr]['arrotond'];
+esegui_query("update $tablecosti set valuta = '".aggslashdb($valuta)."', costo_valuta = '".aggslashdb($val_entrata_valuta)."' where idcosti = '$idcosti' ");
+$val_valuta_paga = $val_entrata_valuta;
+$tasso_cambio_paga = $altre_valute[$valuta_corr]['cambio'];
+$valuta_paga = $altre_valute[$valuta_corr]['nome'];
+} # fine if ($altre_valute['num'] and strcmp($altre_valute['id'][$valuta_pagamento_sel],""))
+else {
+$val_valuta_paga = "";
+$tasso_cambio_paga = "";
+$valuta_paga = "";
+} # fine else if ($altre_valute['num'] and strcmp($altre_valute['id'][$valuta_pagamento_sel],""))
 $testo_azione = "<br>".mex("I costi sono stati inseriti",$pag)." <b>";
 if ($id_cassa == 1) $testo_azione .= mex("nella cassa principale",$pag);
 else $testo_azione .= mex("nella cassa",$pag)." \"$nome_cassa\"";
@@ -763,7 +799,7 @@ esegui_query("update $tablerelinventario set quantita = '".$beniinv_presenti["ma
 } # fine for $num2
 } # fine ($dati_ca[$numca]['tipo_beniinv'] == "mag")
 } # fine for $num1
-} # fine else if (($num_casse_attive > 1 or $metodi_pagamento) and !$nome_cassa_sel)
+} # fine else if (($num_casse_attive > 1 or $metodi_pagamento or $altre_valute['num']) and !$nome_cassa_sel)
 
 unlock_tabelle($tabelle_lock);
 } # fine if ($incassa and !$errore_cassa and...
@@ -905,6 +941,10 @@ esegui_query("update $tableprenota set tariffa_tot = '$n_costo_tot', data_modifi
 $testo_azione = "<br>".mex("I costi sono stati inseriti sulla prenotazione dell'appartamento",'unit.php')." <b>$app_prenota</b>.<br><br>
 <button class=\"pos\" type=\"submit\" style=\"height: 60px; width: 140px; margin: 2px;\"><b>".mex("OK",$pag)."</b></button>";
 $mostra_contr = 1;
+$metodo_pagamento_sel = "";
+$val_valuta_paga = "";
+$tasso_cambio_paga = "";
+$valuta_paga = "";
 } # fine elseif ($id_costi)
 } # fine if ($inprenota and !$errore_prenota and !$azione)
 
@@ -1042,6 +1082,9 @@ echo "<input type=\"hidden\" name=\"num_costi_aggiuntivi_1\" value=\"$num_costi\
 <input type=\"hidden\" name=\"utente_paga0_1\" value=\"$id_utente\">
 <input type=\"hidden\" name=\"metodo_paga0_1\" value=\"$metodo_pagamento_sel\">
 <input type=\"hidden\" name=\"saldo_paga0_1\" value=\"$val_tot\">
+<input type=\"hidden\" name=\"valuta_paga0_1\" value=\"$valuta_paga\">
+<input type=\"hidden\" name=\"tasso_cambio_paga0_1\" value=\"$tasso_cambio_paga\">
+<input type=\"hidden\" name=\"valore_valuta_paga0_1\" value=\"$val_valuta_paga\">
 <input type=\"hidden\" name=\"num_pagamenti_1\" value=\"1\">
 <input type=\"hidden\" name=\"num_ripeti\" value=\"1\">";
 } # fine if ($incassa)
