@@ -30,6 +30,7 @@ $numconnessione = connetti_db($PHPR_DB_NAME,$PHPR_DB_HOST,$PHPR_DB_PORT,$PHPR_DB
 include("./includes/funzioni.php");
 $tablenometariffe = $PHPR_TAB_PRE."ntariffe".$anno;
 $tableprenota = $PHPR_TAB_PRE."prenota".$anno;
+$tableprenotacanc = $PHPR_TAB_PRE."prenotacanc".$anno;
 $tableperiodi = $PHPR_TAB_PRE."periodi".$anno;
 $tablecosti = $PHPR_TAB_PRE."costi".$anno;
 $tablesoldi = $PHPR_TAB_PRE."soldi".$anno;
@@ -103,12 +104,14 @@ $priv_ins_costi_agg = "n";
 } # fine if (@is_file(C_DATI_PATH."/dati_subordinazione.php"))
 
 
+$titolo = "HotelDruid: ".mex("Storico Entrate",$pag);
 if ($tema[$id_utente] and $tema[$id_utente] != "base" and @is_dir("./themes/".$tema[$id_utente]."/php")) include("./themes/".$tema[$id_utente]."/php/head.php");
 else include("./includes/head.php");
 
 
 $stile_soldi = stile_soldi();
 $stile_data = stile_data();
+$Euro = nome_valuta();
 
 if ($senza_colori) $senza_colori = "SI";
 if ($pagina_prenota and controlla_num_pos($pagina_prenota) != "SI") $pagina_prenota = "";
@@ -275,6 +278,7 @@ $frase_periodo .= " ".mex("fino al",$pag)." $cerca_fineperiodo_f";
 } # fine else if (!$cerca_prenota)
 
 $saldo_prenota_TOT = 0;
+$saldo_valuta_TOT = array();
 if (!$senza_colori) $colore = "$t1color";
 else $colore = "#ffffff";
 
@@ -296,7 +300,7 @@ $condizione_variazioni_proprie .= " )";
 else $condizione_variazioni_proprie = "";
 
 if ($metodo_selezionato) {
-if (get_magic_quotes_gpc()) $metodo_selezionato = stripslashes($metodo_selezionato);
+if (@get_magic_quotes_gpc()) $metodo_selezionato = stripslashes($metodo_selezionato);
 $cond_metodo = "and metodo_pagamento = '".aggslashdb($metodo_selezionato)."'";
 } # fine if ($metodo_selezionato)
 
@@ -387,7 +391,16 @@ else $data_fine_f = "&nbsp;";
 if ($motivazione[3]) {
 $num_prenota = $motivazione[3];
 if ($priv_mod_prenotazioni != "n") {
+$stilebarrato = "";
+$pcanc = "";
 $prenota_esist = esegui_query("select iddatainizio,datainserimento,utente_inserimento from $tableprenota where idprenota = '$num_prenota' ");
+if (!numlin_query($prenota_esist)) {
+$prenota_esist = esegui_query("select iddatainizio,datainserimento,utente_inserimento from $tableprenotacanc where idprenota = '$num_prenota' ");
+if (numlin_query($prenota_esist)) {
+$stilebarrato = " style=\"text-decoration: line-through\"";
+$pcanc = "&amp;pcanc=1";
+} # fine if (numlin_query($prenota_esist))
+} # fine if (!numlin_query($prenota_esist))
 if (numlin_query($prenota_esist)) {
 $link_modifica = 1;
 $utente_ins_pren = risul_query($prenota_esist,0,'utente_inserimento');
@@ -401,7 +414,7 @@ $data_ins = risul_query($prenota_esist,0,'datainserimento');
 $limite = date("YmdHis",mktime((substr($data_ins,11,2) + $priv_mod_prenota_ore),substr($data_ins,14,2),substr($data_ins,17,2),substr($data_ins,5,2),substr($data_ins,8,2),substr($data_ins,0,4)));
 if ($adesso > $limite) $link_modifica = 0;
 } # fine if ($priv_mod_prenota_ore != "000")
-if ($link_modifica) $num_prenota = "<a href=\"modifica_prenota.php?id_prenota=$num_prenota&amp;anno=$anno&amp;id_sessione=$id_sessione&amp;origine=storia_soldi.php\">$num_prenota</a>";
+if ($link_modifica) $num_prenota = "<a$stilebarrato href=\"modifica_prenota.php?id_prenota=$num_prenota$pcanc&amp;anno=$anno&amp;id_sessione=$id_sessione&amp;origine=storia_soldi.php\">$num_prenota</a>";
 } # fine if (numlin_query($prenota_esist))
 } # fine if ($priv_mod_prenotazioni != "n")
 } # fine if ($motivazione[3])
@@ -420,7 +433,17 @@ $nome_utente_inserimento = $nome_utente_id[$utente_inserimento];
 
 $soldi_prima_p = punti_in_num($soldi_prima,$stile_soldi);
 $soldi_dopo_p = punti_in_num($soldi_dopo,$stile_soldi);
-$saldo_prenota_p = punti_in_num($saldo_prenota,$stile_soldi);
+$saldo_prenota_vedi = punti_in_num($saldo_prenota,$stile_soldi);
+
+$valuta = risul_query($storia_soldi_prenota,$num1,'valuta');
+if ($valuta) {
+$valuta = explode(">",$valuta);
+$saldo_valuta = risul_query($storia_soldi_prenota,$num1,'saldo_valuta');
+$saldo_valuta_TOT[$valuta[0]] += $saldo_valuta;
+$saldo_valuta_p = punti_in_num($saldo_valuta,$stile_soldi);
+$saldo_prenota_vedi .= "<small> ($saldo_valuta_p&nbsp;".$valuta[0].")</small>";
+} # fine if ($valuta)
+else $saldo_valuta_TOT[$Euro] += $saldo_prenota;
 
 if ($cerca_prenota or (($num1+1) > (($pagina_prenota - 1)*$num_vedi_in_tab) and ($num1+1) <= (($pagina_prenota)*$num_vedi_in_tab)) ) {
 
@@ -430,7 +453,7 @@ echo "<tr><td>$num_prenota</td>
 <td>$data_fine_f</td>
 <td>$soldi_prima_p</td>
 <td>$soldi_dopo_p</td>
-<td>$saldo_prenota_p</td>
+<td>$saldo_prenota_vedi</td>
 <td>$id_pagamento</td>
 <td>$metodo_pagamento</td>";
 if ($num_tutti_utenti > 1) echo "<td><small>$nome_utente_inserimento</small></td>";
@@ -442,9 +465,18 @@ echo "<td><small>$data_inserimento_f</small></td></tr>";
 
 if (!$cerca_prenota and $num_storia_soldi_prenota > $num_vedi_in_tab and $pagina_prenota != $num_pagine_prenota) echo $stringa_puntini_tab;
 
-$saldo_prenota_TOT_p = punti_in_num($saldo_prenota_TOT,$stile_soldi);
+$saldo_prenota_TOT_vedi = punti_in_num($saldo_prenota_TOT,$stile_soldi);
+$altre_valute_TOT = "";
+reset($saldo_valuta_TOT);
+foreach ($saldo_valuta_TOT as $valuta_corr => $saldo_corr) if ($valuta_corr != $Euro) $altre_valute_TOT .= "$saldo_corr&nbsp;$valuta_corr + ";
+if ($altre_valute_TOT) {
+$saldo_prenota_TOT_vedi .= "<small> (";
+if ($saldo_valuta_TOT[$Euro]) $saldo_prenota_TOT_vedi .= $saldo_valuta_TOT[$Euro]."&nbsp;".$Euro." + ";
+$saldo_prenota_TOT_vedi .= substr($altre_valute_TOT,0,-3).")</small>";
+} # fine if ($altre_valute_TOT)
+
 echo "<tr><td colspan=6><b>".mex("TOTALE",$pag)."</b></td>
-<td>$saldo_prenota_TOT_p</td>";
+<td>$saldo_prenota_TOT_vedi</td>";
 if ($num_tutti_utenti > 1) echo "<td>&nbsp;</td>";
 echo "<td>&nbsp;</td>
 <td>&nbsp;</td>
