@@ -29,6 +29,7 @@ include("./includes/funzioni_$PHPR_DB_TYPE.php");
 $numconnessione = connetti_db($PHPR_DB_NAME,$PHPR_DB_HOST,$PHPR_DB_PORT,$PHPR_DB_USER,$PHPR_DB_PASS,$PHPR_LOAD_EXT);
 include("./includes/funzioni.php");
 include("./includes/funzioni_testo.php");
+include("./includes/funzioni_web.php");
 include("./includes/sett_gio.php");
 $base_js = 1;
 $tablenometariffe = $PHPR_TAB_PRE."ntariffe".$anno;
@@ -38,6 +39,7 @@ $tabledescrizioni = $PHPR_TAB_PRE."descrizioni";
 $tableregole = $PHPR_TAB_PRE."regole".$anno;
 $tableappartamenti = $PHPR_TAB_PRE."appartamenti";
 $tablerelgruppi = $PHPR_TAB_PRE."relgruppi";
+$tablepersonalizza = $PHPR_TAB_PRE."personalizza";
 
 
 $id_utente = controlla_login($numconnessione,$PHPR_TAB_PRE,$id_sessione,$nome_utente_phpr,$password_phpr,$anno);
@@ -84,6 +86,8 @@ $priv_mod_tariffe = substr($priv_ins_tariffe,0,1);
 $priv_ins_costi_agg = substr($priv_ins_tariffe,1,1);
 $priv_mod_costo_agg = substr($priv_ins_tariffe,2,1);
 $priv_canc_costi_agg = substr($priv_ins_tariffe,3,1);
+$priv_mod_reg1 = substr($priv_ins_tariffe,4,1);
+$priv_mod_reg2 = substr($priv_ins_tariffe,5,1);
 } # fine else if (numlin_query($privilegi_annuali_utente) == 0)
 
 unset($attiva_regole1_consentite_gr);
@@ -187,6 +191,8 @@ $priv_mod_tariffe = "s";
 $priv_ins_costi_agg = "s";
 $priv_mod_costo_agg = "s";
 $priv_canc_costi_agg = "s";
+$priv_mod_reg1 = "s";
+$priv_mod_reg2 = "s";
 } # fine else if ($id_utente != 1)
 if ($anno_utente_attivato == "SI" and $priv_vedi_tab_periodi != "n") {
 
@@ -197,9 +203,12 @@ $priv_mod_tariffe = "n";
 $priv_ins_costi_agg = "n";
 $priv_mod_costo_agg = "n";
 $priv_canc_costi_agg = "n";
+$priv_mod_reg1 = "n";
+$priv_mod_reg2 = "n";
 } # fine if (@is_file(C_DATI_PATH."/dati_subordinazione.php"))
 
 
+$titolo = "HotelDruid: ".mex("Tariffe",$pag);
 if ($tema[$id_utente] and $tema[$id_utente] != "base" and @is_dir("./themes/".$tema[$id_utente]."/php")) include("./themes/".$tema[$id_utente]."/php/head.php");
 else include("./includes/head.php");
 
@@ -209,6 +218,7 @@ include("./includes/funzioni_costi_agg.php");
 $Euro = nome_valuta();
 $stile_soldi = stile_soldi();
 $stile_data = stile_data();
+$dest = "";
 
 unset($tabelle_lock);
 $tabelle_lock = array();
@@ -242,7 +252,7 @@ unset($tariffe_consentite_vett);
 foreach ($tariffe_consentite_vett_gr as $idut_gr => $val) {
 if (is_array($val)) {
 $tar_cons_vett_tmp = $val;
-foreach ($tar_cons_vett_tmp as $val2) if ($val2 == "SI") $tariffe_consentite_vett[$tar] = "SI";
+foreach ($tar_cons_vett_tmp as $tar => $val2) if ($val2 == "SI") $tariffe_consentite_vett[$tar] = "SI";
 } # fine if (is_array($val))
 } # fine foreach ($tariffe_consentite_vett_gr as $idut_gr => $val)
 $attiva_costi_agg_consentiti = $attiva_costi_agg_consentiti_gr;
@@ -259,7 +269,7 @@ if ($modificadescr and $priv_mod_tariffe != "n") {
 $tabelle_lock = array($tabledescrizioni);
 $tabelle_lock = lock_tabelle($tabelle_lock);
 if (strcmp($n_descrizione_ita,"")) {
-if (get_magic_quotes_gpc()) $n_descrizione_ita = stripslashes($n_descrizione_ita);
+if (@get_magic_quotes_gpc()) $n_descrizione_ita = stripslashes($n_descrizione_ita);
 $n_descrizione_ita = aggslashdb(htmlspecialchars($n_descrizione_ita));
 $descr_esistente = esegui_query("select testo from $tabledescrizioni where nome = 'tariffa".$numtariffa1."' and tipo = 'tardescr' and lingua = 'ita' and numero = '1' ");
 if (numlin_query($descr_esistente)) esegui_query("update $tabledescrizioni set testo = '$n_descrizione_ita' where nome = 'tariffa".$numtariffa1."' and tipo = 'tardescr' and lingua = 'ita' and numero = '1' ");
@@ -272,7 +282,7 @@ while ($ini_lingua = readdir($lang_dir)) {
 if ($ini_lingua != "." && $ini_lingua != ".." and strlen($ini_lingua) <= 3 and preg_replace("/[a-z]/","",$ini_lingua) == "") {
 $n_descrizione = ${"n_descrizione_".$ini_lingua};
 if (strcmp($n_descrizione,"")) {
-if (get_magic_quotes_gpc()) $n_descrizione = stripslashes($n_descrizione);
+if (@get_magic_quotes_gpc()) $n_descrizione = stripslashes($n_descrizione);
 $n_descrizione = aggslashdb(htmlspecialchars($n_descrizione));
 $descr_esistente = esegui_query("select testo from $tabledescrizioni where nome = 'tariffa".$numtariffa1."' and tipo = 'tardescr' and lingua = '$ini_lingua' and numero = '1' ");
 if (numlin_query($descr_esistente)) esegui_query("update $tabledescrizioni set testo = '$n_descrizione' where nome = 'tariffa".$numtariffa1."' and tipo = 'tardescr' and lingua = '$ini_lingua' and numero = '1' ");
@@ -284,13 +294,15 @@ else esegui_query("delete from $tabledescrizioni where nome = 'tariffa".$numtari
 closedir($lang_dir);
 echo "<br>".ucfirst(mex("descrizione della tariffa",$pag))." ".mex("aggiornata",$pag).".<br>";
 unlock_tabelle($tabelle_lock);
+$dest = "#descrcocont";
 } # fine if ($modificadescr and $priv_mod_tariffe != "n")
 
 
 if ($aggurlfoto and $priv_mod_tariffe != "n" and (!defined('C_RESTRIZIONI_DEMO_ADMIN') or C_RESTRIZIONI_DEMO_ADMIN != "SI")) {
-if (get_magic_quotes_gpc()) $n_urlfoto = stripslashes($n_urlfoto);
+$dest = "#aggfoto";
+if (@get_magic_quotes_gpc()) $n_urlfoto = stripslashes($n_urlfoto);
 $lowurl = strtolower($n_urlfoto);
-if (substr($lowurl,-4) != ".jpg" and substr($lowurl,-5) != ".jpeg" and substr($lowurl,-4) != ".gif" and substr($lowurl,-4) != ".png") $errore = "SI";
+if (substr($lowurl,-4) != ".jpg" and substr($lowurl,-5) != ".jpeg" and substr($lowurl,-4) != ".gif" and substr($lowurl,-4) != ".png" and substr($lowurl,-5) != ".webp") $errore = "SI";
 if (str_replace("<","",$n_urlfoto) != $n_urlfoto or str_replace(">","",$n_urlfoto) != $n_urlfoto or str_replace("\"","",$n_urlfoto) != $n_urlfoto) $errore = "SI";
 if ($errore != "SI") {
 $tabelle_lock = array($tabledescrizioni);
@@ -298,9 +310,12 @@ $tabelle_lock = lock_tabelle($tabelle_lock);
 $foto_esistenti = esegui_query("select * from $tabledescrizioni where nome = 'tariffa".$numtariffa1."' and tipo = 'tarfoto' order by numero desc ");
 if (numlin_query($foto_esistenti)) $numfoto = (risul_query($foto_esistenti,0,'numero') + 1);
 else $numfoto = 1;
+upload_hd_img($n_urlfoto);
 esegui_query("insert into $tabledescrizioni (nome,tipo,numero,testo) values ('tariffa".$numtariffa1."','tarfoto','$numfoto','".aggslashdb($n_urlfoto)."') ");
 echo "<br>".ucfirst(mex("la nuova foto è stata aggiunta",$pag)).".<br>";
+if (substr($n_urlfoto,0,17) == "https://localhost" or substr($n_urlfoto,0,16) == "http://localhost" or substr($n_urlfoto,0,17) == "https://127.0.0.1" or substr($n_urlfoto,0,16) == "http://127.0.0.1") echo mex("Attenzione: l'indirizzo usato potrà essere raggiungibile solo da questo computer",$pag).".<br>";
 unlock_tabelle($tabelle_lock);
+$dest = "#ultimafoto";
 } # fine if ($errore != "SI")
 else echo "".ucfirst(mex("l'url della foto è sbagliata",$pag)).".<br>";
 } # fine if ($aggurlfoto and $priv_mod_tariffe != "n" and...
@@ -313,7 +328,7 @@ $tabelle_lock = lock_tabelle($tabelle_lock);
 $foto_esistente = esegui_query("select testo from $tabledescrizioni where nome = 'tariffa".$numtariffa1."' and tipo = 'tarfoto' and numero = '$numfoto' ");
 if (numlin_query($foto_esistente)) {
 if (strcmp($n_commento_ita,"")) {
-if (get_magic_quotes_gpc()) $n_commento_ita = stripslashes($n_commento_ita);
+if (@get_magic_quotes_gpc()) $n_commento_ita = stripslashes($n_commento_ita);
 $n_commento_ita = aggslashdb(htmlspecialchars($n_commento_ita));
 $comm_esistente = esegui_query("select testo from $tabledescrizioni where nome = 'tariffa".$numtariffa1."' and tipo = 'tarcommfoto' and lingua = 'ita' and numero = '$numfoto' ");
 if (numlin_query($comm_esistente)) esegui_query("update $tabledescrizioni set testo = '$n_commento_ita' where nome = 'tariffa".$numtariffa1."' and tipo = 'tarcommfoto' and lingua = 'ita' and numero = '$numfoto' ");
@@ -326,7 +341,7 @@ while ($ini_lingua = readdir($lang_dir)) {
 if ($ini_lingua != "." && $ini_lingua != ".." and strlen($ini_lingua) <= 3 and preg_replace("/[a-z]/","",$ini_lingua) == "") {
 $n_commento = ${"n_commento_".$ini_lingua};
 if (strcmp($n_commento,"")) {
-if (get_magic_quotes_gpc()) $n_commento = stripslashes($n_commento);
+if (@get_magic_quotes_gpc()) $n_commento = stripslashes($n_commento);
 $n_commento = aggslashdb(htmlspecialchars($n_commento));
 $comm_esistente = esegui_query("select testo from $tabledescrizioni where nome = 'tariffa".$numtariffa1."' and tipo = 'tarcommfoto' and lingua = '$ini_lingua' and numero = '$numfoto' ");
 if (numlin_query($comm_esistente)) esegui_query("update $tabledescrizioni set testo = '$n_commento' where nome = 'tariffa".$numtariffa1."' and tipo = 'tarcommfoto' and lingua = '$ini_lingua' and numero = '$numfoto' ");
@@ -340,6 +355,7 @@ echo "<br>".ucfirst(mex("commento della foto",$pag))." $numfoto ".mex("aggiornat
 } # fine if (numlin_query($foto_esistente))
 unlock_tabelle($tabelle_lock);
 } # fine if ($numfoto and controlla_num_pos($numfoto) == "SI") 
+$dest = "#fotocont";
 } # fine if ($commentofoto and $priv_mod_tariffe != "n")
 
 
@@ -348,11 +364,12 @@ if ($numfoto and controlla_num_pos($numfoto) == "SI") {
 esegui_query("delete from $tabledescrizioni where nome = 'tariffa".$numtariffa1."' and (tipo = 'tarfoto' or tipo = 'tarcommfoto') and numero = '$numfoto' ");
 echo "".ucfirst(mex("foto eliminata",$pag)).".<br>";
 } # fine if ($numfoto and controlla_num_pos($numfoto) == "SI") 
+$dest = "#fotocont";
 } # fine if ($cancurlfoto and $priv_mod_tariffe != "n")
 
 
 echo "<br><div style=\"text-align: center;\">
-<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
+<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag$dest\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"num_tariffe_mostra\" value=\"1\">
@@ -478,6 +495,12 @@ $nome_mese["10"] = "10";
 $nome_mese["11"] = "11";
 $nome_mese["12"] = "12";
 $colonna_destra_tab_disp = "";
+unset($condizioni_regole1_consentite);
+if ($attiva_regole1_consentite == "s") {
+for ($num1 = 0 ; $num1 < count($regole1_consentite) ; $num1++) if ($regole1_consentite[$num1]) $condizioni_regole1_consentite .= "motivazione = '".aggslashdb($regole1_consentite[$num1])."' or ";
+if (!$condizioni_regole1_consentite) $condizioni_regole1_consentite = "app_agenzia = ''";
+else $condizioni_regole1_consentite = "(".str_replace("motivazione = ' '","motivazione = '' or motivazione is null",substr($condizioni_regole1_consentite,0,-4)).")";
+} # fine if ($attiva_regole1_consentite == "s")
 trova_app_consentiti_per_tab_disp($app_consentito,$app_consentito_sett,$quadro_non_preciso,$dati_app,$dati_tariffe,$id_data_inizio_tab_disp,$num_colonne_tab_disp,$dati_r2,$attiva_regole1_consentite,0,"",$condizioni_regole1_consentite,"","","","","","","",$tableregole);
 $tab_liberi = crea_quadro_disp($id_data_inizio_tab_disp,$num_colonne_tab_disp,"reg2","SI",$app_consentito,$app_consentito_sett,$app_regola2_orig,$tipo_periodi,$dati_tariffe['num'],$nome_tariffa,$dati_app,$prenota_in_app_sett,$app_orig_prenota_id,$tableperiodi,"SI",$dati_tariffe,1);
 } # fine if ($mostra_disp == "s")
@@ -553,7 +576,8 @@ $idper_corr = risul_query($periodi,($sett_in_per - 1),'idperiodi');
 for ($num1 = 1 ; $num1 <= $num_tariffe_mostra ; $num1++) {
 if ($priv_vedi_tab_periodi == "s" or $attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[${"numtariffa".$num1}] == "SI") {
 $tar_corr = (string) risul_query($periodi,($sett_in_per - 1),$tariffa[$num1]);
-$tarp_corr = (string) risul_query($periodi,($sett_in_per - 1),$tariffa[$num1]."p");
+if ($dati_tariffe[$tariffa[$num1]]['moltiplica'] != "p") $tarp_corr = "";
+else $tarp_corr = (string) risul_query($periodi,($sett_in_per - 1),$tariffa[$num1]."p");
 if ($dati_r2['napp'][$tariffa[$num1]] > 1) {
 $p_app[${"numtariffa".$num1}] = "*".$dati_r2['napp'][$tariffa[$num1]];
 if (!$form_tabella) $tar_corr = (string) ((double) $tar_corr * (double) $dati_r2['napp'][$tariffa[$num1]]);
@@ -603,7 +627,8 @@ $idper_corr = risul_query($periodi,$num1,'idperiodi');
 for ($num2 = 1 ; $num2 <= $num_tariffe_mostra ; $num2++) {
 if ($priv_vedi_tab_periodi == "s" or $attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[${"numtariffa".$num2}] == "SI") {
 $tar_corr = (string) risul_query($periodi,$num1,$tariffa[$num2]);
-$tarp_corr = (string) risul_query($periodi,$num1,$tariffa[$num2]."p");
+if ($dati_tariffe[$tariffa[$num2]]['moltiplica'] != "p") $tarp_corr = "";
+else $tarp_corr = (string) risul_query($periodi,$num1,$tariffa[$num2]."p");
 if ($dati_r2['napp'][$tariffa[$num2]] > 1) {
 if (!$form_tabella) $tar_corr = (string) ((double) $tar_corr * (double) $dati_r2['napp'][$tariffa[$num2]]);
 #$tarp_corr = (string) ((double) $tarp_corr * (double) $dati_r2['napp'][$tariffa[$num2]]);
@@ -967,14 +992,14 @@ else echo "$num_app ".strtolower(mex("Appartamento disponibile",'unit.php'));
 echo " ".mex("in modo predefinito per la tariffa",$pag)." \"".$nometariffa_vedi[1]."\": ";
 if (!$dati_r2[$tariffa[1]]) echo "<span class=\"colwarn\"><em>".mex("tutti gli appartamenti",'unit.php')."</em></span>.";
 else echo "<em>".str_replace(",","</em>, <em>",$dati_r2[$tariffa[1]])."</em>.";
-if ($id_utente == 1) echo " <a style=\"display: inline-block; margin-bottom: 2px;\" href=\"./crearegole.php?id_sessione=$id_sessione&amp;anno=$anno&amp;tipotariffa_regola2=".$tariffa[1]."&amp;origine=tab_tariffa\">".mex("Modifica la regola di assegnazione",'interconnessioni.php')." 2</a>";
+if ($priv_mod_reg2 == "s") echo " <a style=\"display: inline-block; margin-bottom: 2px;\" href=\"./crearegole.php?id_sessione=$id_sessione&amp;anno=$anno&amp;tipotariffa_regola2=".$tariffa[1]."&amp;origine=tab_tariffa\">".mex("Modifica la regola di assegnazione",'interconnessioni.php')." 2</a>";
 echo "<br><br>";
 
 $regola4 = esegui_query("select * from $tableregole where tariffa_per_persone = '".$tariffa[1]."' ");
 if (numlin_query($regola4)) $num_pers_reg4 = risul_query($regola4,0,'iddatainizio');
 else $num_pers_reg4 = mex("non definito",$pag);
 echo mex("Numero di persone predefinito per la tariffa",$pag)." \"".$nometariffa_vedi[1]."\": <em>$num_pers_reg4</em>.";
-if ($id_utente == 1) echo " <a style=\"display: inline-block; margin-bottom: 2px;\" href=\"./crearegole.php?id_sessione=$id_sessione&amp;anno=$anno&amp;tipotariffa_regola4=".$tariffa[1]."&amp;origine=tab_tariffa\">".mex("Modifica la regola di assegnazione",'interconnessioni.php')." 4</a>";
+if ($priv_mod_reg2 == "s") echo " <a style=\"display: inline-block; margin-bottom: 2px;\" href=\"./crearegole.php?id_sessione=$id_sessione&amp;anno=$anno&amp;tipotariffa_regola3=".$tariffa[1]."&amp;origine=tab_tariffa\">".mex("Modifica la regola di assegnazione",'interconnessioni.php')." 3</a>";
 echo "<br><br><br>";
 
 if ($attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[$numtariffa1] == "SI") {
@@ -982,7 +1007,7 @@ $d_descrizione = esegui_query("select testo from $tabledescrizioni where nome =
 if (numlin_query($d_descrizione)) $d_descrizione = risul_query($d_descrizione,0,'testo');
 else $d_descrizione = "";
 if ($priv_mod_tariffe != "n") {
-echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
+echo "<div id=\"descrcocont\" class=\"rbox\"><form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div style=\"padding: 2px 0 5px; 0;\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"num_tariffe_mostra\" value=\"1\">
@@ -1022,15 +1047,17 @@ else echo "<div style=\"width: 580px;\">\"<em>".nl2br($d_descrizione)."</em>\"</
 } # fine while ($file = readdir($lang_dig))
 closedir($lang_dir);
 echo "</tr></table>";
-if ($priv_mod_tariffe != "n") echo "<button class=\"edit\" type=\"submit\"><div>".ucfirst(mex("modifica",$pag))."</div></button></div></form><br>";
+if ($priv_mod_tariffe != "n") echo "<button class=\"edit\" type=\"submit\"><div>".ucfirst(mex("modifica",$pag))."</div></button></div></form></div><br>";
 
 $foto = esegui_query("select * from $tabledescrizioni where nome = 'tariffa".$numtariffa1."' and tipo = 'tarfoto' order by numero ");
 $num_foto = numlin_query($foto);
-echo "<br>".ucfirst(mex("foto della tariffa",$pag))." \"<em>".$nometariffa[1]."</em>\":<br>";
+echo "<br><div id=\"fotocont\" class=\"rbox\"><div style=\"padding-top: 2px;\">".ucfirst(mex("foto della tariffa",$pag))." \"<em>".$nometariffa[1]."</em>\":<br>";
 for ($num1 = 1 ; $num1 <= $num_foto ; $num1++) {
 $url_foto = risul_query($foto,($num1 - 1),'testo');
 $numfoto = risul_query($foto,($num1 - 1),'numero');
-echo "<table><tr><td valign=\"top\">$num1.</td><td>
+if ($num1 == $num_foto) $id_foto = " id=\"ultimafoto\"";
+else $id_foto = "";
+echo "<table$id_foto><tr><td valign=\"top\">$num1.</td><td>
 <a href=\"$url_foto\"><img class=\"dphoto\" style=\"border: 0px none ; text-decoration: none;\" src=\"$url_foto\" alt=\"".htmlspecialchars($url_foto)."\"></a>
 </td><td style=\"width: 20px;\"></td><td>
 <form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div class=\"linhbox\">
@@ -1073,7 +1100,7 @@ echo "<br>";
 if ($priv_mod_tariffe != "n") {
 if (defined('C_RESTRIZIONI_DEMO_ADMIN') and C_RESTRIZIONI_DEMO_ADMIN == "SI") $readonly = " readonly=\"readonly\"";
 else $readonly = "";
-echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
+echo "<form id=\"aggfoto\" accept-charset=\"utf-8\" method=\"post\" action=\"$pag\" enctype=\"multipart/form-data\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"num_tariffe_mostra\" value=\"1\">
@@ -1081,10 +1108,11 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
 <input type=\"hidden\" name=\"azione\" value=\"SI\">
 <input type=\"hidden\" name=\"aggurlfoto\" value=\"SI\">
 ".ucfirst(mex("url di una nuova foto",$pag)).":
-<input type=\"text\" name=\"n_urlfoto\" size=\"30\" value=\"http://\"$readonly>
-<button class=\"apho\" type=\"submit\"><div>".ucfirst(mex("aggiungi",$pag))."</div></button>
-</div></form><br>";
+<input id=\"n_urlf\" type=\"text\" name=\"n_urlfoto\" size=\"30\" value=\"http://\"$readonly>
+<button class=\"apho\" type=\"submit\"><div>".ucfirst(mex("aggiungi",$pag))."</div></button><br>
+".upload_hd_img_form('n_urlf',$tablepersonalizza)."</div></form><br>";
 } # fine if ($priv_mod_tariffe != "n")
+echo "</div></div>";
 } # fine if ($attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[$numtariffa1] == "SI")
 
 } # fine if ($num_tariffe_mostra == 1)
