@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2018 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2019 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -95,9 +95,11 @@ $tariffe_consentite = explode(",",substr($tariffe_consentite,2));
 unset($tariffe_consentite_vett);
 for ($num1 = 0 ; $num1 < count($tariffe_consentite) ; $num1++) if ($tariffe_consentite[$num1]) $tariffe_consentite_vett[$tariffe_consentite[$num1]] = "SI";
 } # fine if ($attiva_tariffe_consentite == "s")
-$priv_ins_nuove_prenota_v = substr($priv_ins_prenota,0,1);
-$priv_ins_assegnazione_app_v = substr($priv_ins_prenota,1,1);
-$priv_mod_assegnazione_app_v = substr($priv_mod_prenota,2,1);
+$priv_ins_nuove_prenota = substr($priv_ins_prenota,0,1);
+$priv_ins_assegnazione_app = substr($priv_ins_prenota,1,1);
+$priv_ins_nuove_prenota_v = $priv_ins_nuove_prenota;
+$priv_ins_assegnazione_app_v = $priv_ins_assegnazione_app;
+$priv_mod_assegnazione_app_v = $priv_mod_assegnazione_app;
 $priv_mod_prenotazioni_v = $priv_mod_prenotazioni;
 } # fine if ($priv_vedi_tab_mesi == "p")
 $priv_oscura_tab_mesi = substr($priv_vedi_tab,8,1);
@@ -193,6 +195,8 @@ $priv_vedi_commento = "s";
 $priv_vedi_commenti_pers = "s";
 $priv_vedi_tab_mesi = "s";
 $attiva_contratti_consentiti = "n";
+$attiva_tariffe_consentite = "n";
+$attiva_regole1_consentite = "n";
 $cassa_pagamenti = "";
 } # fine else if ($id_utente != 1)
 if ($anno_utente_attivato == "SI" and $priv_vedi_tab_mesi != "n") {
@@ -543,7 +547,7 @@ $pag = "modifica_prenota.php";
 if (($vedi_clienti == "PROPRI" and $utente_inserimento != $id_utente) or ($vedi_clienti == "GRUPPI" and !$utenti_gruppi[$utente_inserimento])) $dati_xml .= mex("Cliente",$pag)." $id_cli ";
 else {
 include_once("./includes/funzioni_clienti.php");
-$txt_cli = mostra_dati_cliente($dati_cliente,$dcognome,$dnome,$dsoprannome,$dtitolo_cli,$dsesso,$ddatanascita,$ddatanascita_f,$dnazionenascita,$dcittanascita,$dregionenascita,$ddocumento,$dscadenzadoc,$dscadenzadoc_f,$dtipodoc,$dnazionedoc,$dregionedoc,$dcittadoc,$dnazionalita,$dlingua_cli,$dnazione,$dregione,$dcitta,$dvia,$dnumcivico,$dtelefono,$dtelefono2,$dtelefono3,$dfax,$dcap,$demail,$dcod_fiscale,$dpartita_iva,"",$priv_ins_clienti,"1");
+$txt_cli = mostra_dati_cliente($dati_cliente,$dcognome,$dnome,$dsoprannome,$dtitolo_cli,$dsesso,$ddatanascita,$ddatanascita_f,$dnazionenascita,$dcittanascita,$dregionenascita,$ddocumento,$dscadenzadoc,$dscadenzadoc_f,$dtipodoc,$dnazionedoc,$dregionedoc,$dcittadoc,$dnazionalita,$dlingua_cli,$dnazione,$dregione,$dcitta,$dvia,$dnumcivico,$dtelefono,$dtelefono2,$dtelefono3,$dfax,$dcap,$demail,$demail2,$demail_cert,$dcod_fiscale,$dpartita_iva,"",$priv_ins_clienti,"1");
 $txt_cli = str_replace("<br>"," \n",$txt_cli);
 $txt_cli = preg_replace("/<[^<]*>/","",$txt_cli);
 $dati_xml .= "$id_prn - ".$txt_cli." ";
@@ -573,6 +577,7 @@ $dati_xml .= ") ";
 $tariffa = risul_query($dati_prn,0,'tariffa');
 if ($tariffa and $priv_mod_tariffa != "n") {
 $tariffa = explode("#@&",$tariffa);
+$costo_tariffa = $tariffa[1];
 $tariffa = $tariffa[0];
 $dati_xml .= "\n-".mex("Tipo di tariffa",$pag).": ".str_replace("\"","&quot;",str_replace(">","&gt;",str_replace("<","&lt;",str_replace("&","&amp;",$tariffa))))." ";
 } # fine if ($tariffa and $priv_mod_tariffa != "n")
@@ -593,10 +598,47 @@ $Euro = nome_valuta();
 $stile_soldi = stile_soldi();
 $tariffa_tot = risul_query($dati_prn,0,'tariffa_tot');
 $dati_xml .= "\n-".mex("Totale da pagare",$pag).": ".punti_in_num($tariffa_tot,$stile_soldi)." $Euro ";
+$valuta_tariffa = explode(">",risul_query($dati_prn,0,'valuta'));
+if ($valuta_tariffa[0]) {
+$valuta_tariffa = explode("<",$valuta_tariffa[0]);
+$cambio_tariffa = $valuta_tariffa[1];
+$arrotond_tariffa = $valuta_tariffa[2];
+$valuta_tariffa = $valuta_tariffa[0];
+$sconto = risul_query($dati_prn,0,'sconto');
+$tariffa_sconto_valuta = converti_valuta(($costo_tariffa - $sconto),$cambio_tariffa,$arrotond_tariffa);
+$costo_agg_tot = round(((double) $tariffa_tot - (double) $costo_tariffa + (double) $sconto),2);
+if ($costo_agg_tot) {
+$altre_valute = altre_valute();
+if (!strcmp($altre_valute['id'][$valuta_tariffa],"")) $costi_agg_valuta = converti_valuta($costo_agg_tot,$cambio_tariffa,$arrotond_tariffa);
+else  $costi_agg_valuta = converti_valuta($costo_agg_tot,$altre_valute[$altre_valute['id'][$valuta_tariffa]]['cambio'],$altre_valute[$altre_valute['id'][$valuta_tariffa]]['arrotond']);
+} # fine if ($costo_agg_tot)
+$tariffa_valuta_tot = round(($tariffa_sconto_valuta + $costi_agg_valuta),2);
+$dati_xml .= " = ".punti_in_num($tariffa_valuta_tot,$stile_soldi)." $valuta_tariffa ";
+} # fine if ($valuta_tariffa[0])
+else $valuta_tariffa = "";
 $pagato = risul_query($dati_prn,0,'pagato');
 $dati_xml .= "\n-".mex("Pagato",$pag).": ".punti_in_num($pagato,$stile_soldi)." $Euro ";
 $da_pagare = $tariffa_tot - $pagato;
-if ($da_pagare and $da_pagare != $tariffa_tot) $dati_xml .= "\n-".mex("Ancora da pagare",$pag).": ".punti_in_num($da_pagare,$stile_soldi)." $Euro ";
+if ($da_pagare and $da_pagare != $tariffa_tot) {
+$dati_xml .= "\n-".mex("Ancora da pagare",$pag).": ".punti_in_num($da_pagare,$stile_soldi)." $Euro ";
+if (strcmp($valuta_tariffa,"")) {
+$resto_tarsco_valuta = round(((double) $costo_tariffa - (double) $sconto - (double) $pagato),2);
+if ($resto_tarsco_valuta >= 0) {
+$dapagare_tarsco_valuta = converti_valuta($resto_tarsco_valuta,$cambio_tariffa,$arrotond_tariffa);
+$dapagare_cosagg_valuta = $costo_agg_tot;
+} # fine if ($resto_tarsco_valuta >= 0)
+else {
+$dapagare_tarsco_valuta = 0;
+$dapagare_cosagg_valuta = round(((double) $costo_agg_tot + (double) $resto_tarsco_valuta),2);
+} # fine else if ($resto_tarsco_valuta >= 0)
+if ($dapagare_cosagg_valuta) {
+if (!strcmp($altre_valute['id'][$valuta_tariffa],"")) $dapagare_cosagg_valuta = converti_valuta($dapagare_cosagg_valuta,$cambio_tariffa,$arrotond_tariffa);
+else $dapagare_cosagg_valuta = converti_valuta($dapagare_cosagg_valuta,$altre_valute[$altre_valute['id'][$valuta_tariffa]]['cambio'],$altre_valute[$altre_valute['id'][$valuta_tariffa]]['arrotond']);
+} # fine if ($dapagare_cosagg_valuta)
+$da_pagare_valuta = round(($dapagare_tarsco_valuta + $dapagare_cosagg_valuta),2);
+$dati_xml .= "= ".virgola_in_num($da_pagare_valuta,$stile_soldi)." $valuta_tariffa ";
+} # fine if (strcmp($valuta_tariffa,""))
+} # fine if ($da_pagare and $da_pagare != $tariffa_tot)
 } # fine if ($priv_mod_pagato != "n" and $priv_mod_pagato != "i")
 $dati_xml .= "</txt>";
 $pag = $pag_orig;
@@ -620,6 +662,7 @@ else {
 
 
 
+$titolo = "HotelDruid: ".mex("Tabella Mese",$pag);
 if ($tema[$id_utente] and $tema[$id_utente] != "base" and @is_dir("./themes/".$tema[$id_utente]."/php")) include("./themes/".$tema[$id_utente]."/php/head.php");
 else include("./includes/head.php");
 
@@ -631,8 +674,8 @@ controlla_id_prenota($id_prenota,$id_prenota_idpr,$num_id_prenota,$id_prenota_in
 if ($priv_mod_prenotazioni != "n") {
 $inserire = "SI";
 $cancellata = "NO";
-prepara_modifiche_prenotazione($id_prenota_idpr,$num_id_prenota,$prenota_in_anno_succ,$dati_da_anno_prec,$tra_anni,$anno,$PHPR_TAB_PRE);
-esegui_modifiche_prenotazione($inserire,$cancellata,$id_prenota_int,$id_prenota_idpr,$num_id_prenota,$id_transazione,$id_sessione,$anno,$id_nuovo_utente_inserimento,$n_stima_checkin,$n_met_paga_caparra,$n_origine_prenota,$n_pagato,$n_confermato,$tipo_commento,$n_commento,$n_cancella_commento,$tableprenota_da_aggiornare,$tipo_sposta,$dati_da_anno_prec,$prenota_in_anno_succ,$tra_anni,$PHPR_TAB_PRE);
+prepara_modifiche_prenotazione($id_prenota_idpr,$num_id_prenota,$prenota_in_anno_succ,$dati_da_anno_prec,$tra_anni,$anno,$PHPR_TAB_PRE,"");
+esegui_modifiche_prenotazione($inserire,$cancellata,$id_prenota_int,$id_prenota_idpr,$num_id_prenota,$id_transazione,$id_sessione,$anno,$id_nuovo_utente_inserimento,$n_stima_checkin,$n_valuta_caparra,$n_met_paga_caparra,$n_origine_prenota,$n_pagato,$n_confermato,$tipo_commento,$n_commento,$n_cancella_commento,$tableprenota_da_aggiornare,$tipo_sposta,$dati_da_anno_prec,$prenota_in_anno_succ,$tra_anni,$PHPR_TAB_PRE,"");
 } # fine if ($priv_mod_prenotazioni != "n")
 } # fine if ($modificaprenotazione == "Continua")
 
