@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2017 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2019 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -48,7 +48,7 @@ if (defined('C_NASCONDI_MARCA') and C_NASCONDI_MARCA == "SI") $titolo = "";
 if (defined('C_FILE_TITOLO_PERS') and C_FILE_TITOLO_PERS != "" and @is_file(C_FILE_TITOLO_PERS)) $titolo = trim(substr(implode("",file(C_FILE_TITOLO_PERS)),0,40))." - $titolo";
 echo "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN\"
         \"http://www.w3.org/TR/html4/strict.dtd\">
-<html>
+<html lang=\"$lingua_mex\">
 <head>
 <meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" >
 <meta name=\"viewport\" content=\"initial-scale=$iscale\">
@@ -123,6 +123,7 @@ if (!$priv_mod_pers) $priv_mod_pers = risul_query($privilegi_globali_utente,0,'p
 if (substr($priv_mod_pers,0,1) != "s" and !$modifica_pers) $modifica_pers = "NO";
 if (!$priv_crea_backup) $priv_crea_backup = substr($priv_mod_pers,1,1);
 if (!$priv_crea_interconnessioni) $priv_crea_interconnessioni = substr($priv_mod_pers,3,1);
+if (!$priv_crea_pagineweb) $priv_crea_pagineweb = substr($priv_mod_pers,8,1);
 if (!$priv_gest_pass_cc) $priv_gest_pass_cc = substr($priv_mod_pers,5,1);
 if (!$priv_ins_clienti) $priv_ins_clienti = risul_query($privilegi_globali_utente,0,'priv_ins_clienti');
 if (substr($priv_ins_clienti,0,1) != "s" and !$inserimento_nuovi_clienti) $inserimento_nuovi_clienti = "NO";
@@ -155,6 +156,8 @@ if (!$priv_vedi_tab_stat) $priv_vedi_tab_stat = substr($priv_vedi_tab,6,1);
 if (!$priv_vedi_tab_doc) $priv_vedi_tab_doc = substr($priv_vedi_tab,7,1);
 if (!$priv_ins_tariffe) $priv_ins_tariffe = risul_query($privilegi_annuali_utente,0,'priv_ins_tariffe');
 if (!$priv_mod_tariffe) $priv_mod_tariffe = substr($priv_ins_tariffe,0,1);
+if (!$priv_mod_reg1) $priv_mod_reg1 = substr($priv_ins_tariffe,4,1);
+if (!$priv_mod_reg2) $priv_mod_reg2 = substr($priv_ins_tariffe,5,1);
 if (!$priv_ins_costi_agg) $priv_ins_costi_agg = substr($priv_ins_tariffe,1,1);
 } # fine if ($anno_utente_attivato == "SI")
 } # fine if ($id_utente != 1)
@@ -163,6 +166,7 @@ if (!$anno_utente_attivato) $anno_utente_attivato = "SI";
 if (!$modifica_pers) $modifica_pers = "SI";
 if (!$priv_crea_backup) $priv_crea_backup = "s";
 if (!$priv_crea_interconnessioni) $priv_crea_interconnessioni = "s";
+if (!$priv_crea_pagineweb) $priv_crea_pagineweb = "s";
 if (!$priv_gest_pass_cc) $priv_gest_pass_cc = "s";
 if (!$inserimento_nuovi_clienti) $inserimento_nuovi_clienti = "SI";
 if (!$modifica_clienti) $modifica_clienti = "SI";
@@ -185,6 +189,8 @@ if (!$priv_vedi_tab_appartamenti) $priv_vedi_tab_appartamenti = "s";
 if (!$priv_vedi_tab_stat) $priv_vedi_tab_stat = "s";
 if (!$priv_vedi_tab_doc) $priv_vedi_tab_doc = "s";
 if (!$priv_mod_tariffe) $priv_mod_tariffe = "s";
+if (!$priv_mod_reg1) $priv_mod_reg1 = "s";
+if (!$priv_mod_reg2) $priv_mod_reg2 = "s";
 if (!$priv_ins_costi_agg) $priv_ins_costi_agg = "s";
 } # fine else if ($id_utente != 1)
 
@@ -243,7 +249,7 @@ if ($mobile_device and $priv_ins_nuove_prenota == "s") echo "<li><a id=\"nb_ires
 if ($inserimento_nuovi_clienti != "NO" or ($modifica_clienti != "NO" and $vedi_clienti != "NO")) echo "<li><a id=\"nb_icli\" href=\"./clienti.php?$sessione_anno_var\">&nbsp;<b>".mex("CLIENTE","head.php")."</b>&nbsp;</a></li>";
 if ($priv_ins_spese == "s" or $priv_ins_entrate == "s") echo "<li><a id=\"nb_iexp\" href=\"./costi.php?$sessione_anno_var\">&nbsp;<b>".mex("SPESE","head.php")."</b>&nbsp;</a></li>";
 if ($priv_mod_tariffe != "n" or $priv_ins_costi_agg != "n") echo "<li><a id=\"nb_ipri\" href=\"./creaprezzi.php?$sessione_anno_var\">&nbsp;<b>".mex("PREZZI","head.php")."</b>&nbsp;</a></li>";
-if ($id_utente == 1 and $installazione_subordinata != "SI") echo "<li><a id=\"nb_irul\" href=\"./crearegole.php?$sessione_anno_var\">&nbsp;<b>".mex("REGOLE","head.php")."</b>&nbsp;</a></li>";
+if ($priv_mod_reg1 != "n" or $priv_mod_reg2 != "n") echo "<li><a id=\"nb_irul\" href=\"./crearegole.php?$sessione_anno_var\">&nbsp;<b>".mex("REGOLE","head.php")."</b>&nbsp;</a></li>";
 if ($priv_mod_prenotazioni != "n" and $priv_mod_costi_agg == "s") echo "<li><a id=\"nb_pos\" href=\"./punto_vendita.php?$sessione_anno_var\">&nbsp;<b>".mex("P.TO&nbsp;VENDITA","head.php")."</b>&nbsp;</a></li>";
 if ($mobile_device and $modifica_pers != "NO") echo "<li><a id=\"nb_con\" href=\"./personalizza.php?$sessione_anno_var\">&nbsp;<b>".mex("CONFIGURA","head.php")."</b>&nbsp;</a></li>";
 echo "</ul>";
@@ -339,15 +345,13 @@ echo "<div class=\"drop nb_rat\"><div class=\"nb_rat\"><ul>
 </ul></li></ul></div></div></td><td>";
 } # fine if ($priv_vedi_tab_periodi != "n" and !$mobile_device)
 } # fine if ($priv_vedi_tab_mesi != "n" or $priv_vedi_tab_prenotazioni != "n" or...
-if (($modifica_pers != "NO" or ($priv_crea_backup == "s" and $installazione_subordinata != "SI") or ($priv_crea_interconnessioni == "s" and (!defined('C_CREA_SUBORDINAZIONI') or C_CREA_SUBORDINAZIONI != "NO")) or $priv_gest_pass_cc == "s") and !$mobile_device) {
+if (($modifica_pers != "NO" or ($priv_crea_backup == "s" and $installazione_subordinata != "SI") or $priv_crea_pagineweb == "s" or ($priv_crea_interconnessioni == "s" and (!defined('C_CREA_SUBORDINAZIONI') or C_CREA_SUBORDINAZIONI != "NO")) or $priv_gest_pass_cc == "s") and !$mobile_device) {
 echo "|</td><td><div class=\"drop nb_con\"><ul>
 <li><a class=\"nav\" id=\"nb_con\" href=\"./personalizza.php?$sessione_anno_var\">&nbsp;<b>".mex("CONFIGURA","head.php")."</b>&nbsp;</a>";
-if ($modifica_pers != "NO" or ($priv_crea_backup == "s" and $installazione_subordinata != "SI") or ($priv_crea_interconnessioni == "s" and (!defined('C_CREA_SUBORDINAZIONI') or C_CREA_SUBORDINAZIONI != "NO"))) {
+if ($modifica_pers != "NO" or ($priv_crea_backup == "s" and $installazione_subordinata != "SI") or $priv_crea_pagineweb == "s" or ($priv_crea_interconnessioni == "s" and (!defined('C_CREA_SUBORDINAZIONI') or C_CREA_SUBORDINAZIONI != "NO"))) {
 echo "<ul>";
-if ($id_utente == 1 and $installazione_subordinata != "SI") {
-echo "<li><a id=\"nb_use\" href=\"./gestione_utenti.php?$sessione_anno_var\">&nbsp;<b>".mex("UTENTI","head.php")."</b>&nbsp;</a></li>
-<li><a id=\"nb_web\" href=\"./crea_modelli.php?$sessione_anno_var\">&nbsp;<b>".mex("SITO WEB","head.php")."</b>&nbsp;</a></li>";
-} # fine if ($id_utente == 1 and $installazione_subordinata != "SI")
+if ($id_utente == 1 and $installazione_subordinata != "SI") echo "<li><a id=\"nb_use\" href=\"./gestione_utenti.php?$sessione_anno_var\">&nbsp;<b>".mex("UTENTI","head.php")."</b>&nbsp;</a></li>";
+if ($priv_crea_pagineweb == "s") echo "<li><a id=\"nb_web\" href=\"./crea_modelli.php?$sessione_anno_var\">&nbsp;<b>".mex("SITO WEB","head.php")."</b>&nbsp;</a></li>";
 if ($priv_crea_interconnessioni == "s" and (!defined('C_CREA_SUBORDINAZIONI') or C_CREA_SUBORDINAZIONI != "NO")) echo "<li><a id=\"nb_int\" href=\"./interconnessioni.php?$sessione_anno_var\">&nbsp;<b>".mex("INTERCONN.","head.php")."</b>&nbsp;</a></li>";
 if ($priv_crea_backup == "s" and $installazione_subordinata != "SI") echo "<li><a id=\"nb_bac\" href=\"./crea_backup.php?$sessione_anno_var\">&nbsp;<b>".mex("BACKUP","head.php")."</b>&nbsp;</a></li>";
 if ($modifica_pers != "NO") echo "<li><a id=\"nb_cdoc\" href=\"./personalizza.php?$sessione_anno_var#contratti\">&nbsp;<b>".mex("DOCUMENTI","head.php")."</b>&nbsp;</a></li>";
