@@ -33,6 +33,7 @@ include("./includes/funzioni_contratti.php");
 include("./includes/funzioni_testo.php");
 $tablecontratti = $PHPR_TAB_PRE."contratti";
 $tableprenota = $PHPR_TAB_PRE."prenota".$anno;
+$tableprenotacanc = $PHPR_TAB_PRE."prenotacanc".$anno;
 $tablecostiprenota = $PHPR_TAB_PRE."costiprenota".$anno;
 $tableclienti = $PHPR_TAB_PRE."clienti";
 $tableperiodi = $PHPR_TAB_PRE."periodi".$anno;
@@ -51,6 +52,8 @@ $tableanni = $PHPR_TAB_PRE."anni";
 $tableutenti = $PHPR_TAB_PRE."utenti";
 $tableappartamenti = $PHPR_TAB_PRE."appartamenti";
 $tablerelclienti = $PHPR_TAB_PRE."relclienti";
+$tablecasse = $PHPR_TAB_PRE."casse";
+$tablecosti = $PHPR_TAB_PRE."costi".$anno;
 
 
 $id_utente = controlla_login($numconnessione,$PHPR_TAB_PRE,$id_sessione,$nome_utente_phpr,$password_phpr,$anno);
@@ -99,14 +102,21 @@ if (substr($priv_ins_clienti,2,1) == "p") $vedi_clienti = "PROPRI";
 if (substr($priv_ins_clienti,2,1) == "g") { $vedi_clienti = "GRUPPI"; $prendi_gruppi = "SI"; }
 $priv_vedi_telefoni = substr($priv_ins_clienti,3,1);
 $priv_vedi_indirizzo = substr($priv_ins_clienti,4,1);
+$casse_consentite = risul_query($privilegi_globali_utente,0,'casse_consentite');
+$attiva_casse_consentite = substr($casse_consentite,0,1);
+if ($attiva_casse_consentite == "s") {
+$casse_consentite = explode(",",substr($casse_consentite,2));
+unset($casse_consentite_vett);
+for ($num1 = 0 ; $num1 < count($casse_consentite) ; $num1++) if ($casse_consentite[$num1]) $casse_consentite_vett[$casse_consentite[$num1]] = "SI";
+} # fine if ($attiva_casse_consentite == "s")
 $contratti_consentiti = risul_query($privilegi_annuali_utente,0,'contratti_consentiti');
 $attiva_contratti_consentiti = substr($contratti_consentiti,0,1);
 $priv_cancella_contratti = substr($contratti_consentiti,1,1);
 if ($attiva_contratti_consentiti == "s") {
 $contratti_consentiti = explode(",",$contratti_consentiti);
-unset($contratto_trovato);
-for ($num1 = 1 ; $num1 < count($contratti_consentiti) ; $num1++) if ($contratti_consentiti[$num1] and $contratti_consentiti[$num1] == $numero_contratto) $contratto_trovato = "SI";
-if ($contratto_trovato != "SI") $anno_utente_attivato = "NO";
+$contratti_consentiti_vett = array();
+for ($num1 = 1 ; $num1 < count($contratti_consentiti) ; $num1++) if ($contratti_consentiti[$num1]) $contratti_consentiti_vett[$contratti_consentiti[$num1]] = "SI";
+if ($contratti_consentiti_vett[$numero_contratto] != "SI") $anno_utente_attivato = "NO";
 } # fine if ($attiva_contratti_consentiti == "s")
 } # fine else if (numlin_query($privilegi_annuali_utente) == 0)
 unset($utenti_gruppi);
@@ -140,6 +150,7 @@ $priv_mod_codice = "s";
 $vedi_clienti = "SI";
 $priv_vedi_telefoni = "s";
 $priv_vedi_indirizzo = "s";
+$attiva_casse_consentite = "n";
 $attiva_contratti_consentiti = "n";
 $priv_cancella_contratti = "s";
 } # fine else if ($id_utente != 1)
@@ -252,14 +263,14 @@ $bcc_mittente = $opz_eml[1];
 $bcc_indirizzo = $opz_eml[2];
 
 for ($num1 = 1 ; $num1 <= $numero_email ; $num1++) {
-if (${"destinatario_email".$num1}) {
+if (${"destinatario_email".$num1} and strstr(${"destinatario_email".$num1},"@")) {
 $inviato = "";
 if ($modifica_pers != "NO") $mittente_email = ${"mittente_email".$num1};
 $destinatario_email = ${"destinatario_email".$num1};
-if (get_magic_quotes_gpc()) {
+if (@get_magic_quotes_gpc()) {
 ${"oggetto_email".$num1} = stripslashes(${"oggetto_email".$num1});
 ${"testo_email".$num1} = stripslashes(${"testo_email".$num1});
-} # fine if (get_magic_quotes_gpc())
+} # fine if (@get_magic_quotes_gpc())
 switch (strtoupper(substr(PHP_OS,0,3))) {
 case "WIN": $mailh_nl = "\r\n"; break;
 case "MAC": $mailh_nl = "\r"; break;
@@ -311,7 +322,7 @@ if ($maschera_envelope == "SI") $inviato = mail($destinatario_email,${"oggetto_e
 else $inviato = mail($destinatario_email,${"oggetto_email".$num1},$testo_email,$headers);
 } # fine if (!defined('C_RESTRIZIONI_DEMO_ADMIN') or C_RESTRIZIONI_DEMO_ADMIN != "SI")
 if ($inviato) {
-echo "<br>&nbsp;".mex("L'email a",$pag)." <b>$destinatario_email</b> ".mex("è stata inviata",$pag);
+echo "<br>&nbsp;".mex("L'email a",$pag)." <b>".htmlspecialchars($destinatario_email)."</b> ".mex("è stata inviata",$pag);
 if ($bcc_mittente == "SI" or $bcc_indirizzo) echo " (".mex("bcc a",$pag)." ";
 if ($bcc_mittente == "SI") echo $mittente_email;
 if ($bcc_mittente == "SI" and $bcc_indirizzo) echo ", ";
@@ -343,7 +354,7 @@ esegui_query("update $tableclienti set doc_inviati = '".aggslashdb($doc_inviati)
 unlock_tabelle($tabelle_lock);
 } # fine if ($inviato)
 else echo "<br>&nbsp;".mex("Non si è potuto inviare l'email a",$pag)." <b style=\"font-weight: normal; color: red;\">$destinatario_email</b>.<br>";
-} # fine if (${"destinatario_email".$num1})
+} # fine if (${"destinatario_email".$num1} and strstr(${"destinatario_email".$num1},"@"))
 } # fine for $num1
 
 } # fine if ($tipo_contratto == "contreml")
@@ -357,7 +368,7 @@ if ($mostra_contratto == "SI") {
 
 
 
-define('C_ID_UTENTE',$id_utente);
+define('C_ID_UTENTE_CONTR',$id_utente);
 $campi_pers_comm = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'campi_pers_comm' and idutente = '$id_utente'");
 if (numlin_query($campi_pers_comm) == 1) {
 $campi_pers_comm = explode(">",risul_query($campi_pers_comm,0,'valpersonalizza'));
@@ -379,15 +390,16 @@ include("./includes/variabili_contratto.php");
 
 if (!$num_ripeti or controlla_num_pos($num_ripeti) == "NO") $num_ripeti = 1;
 
-if (get_magic_quotes_gpc()) {
+if (@get_magic_quotes_gpc()) {
 for ($n_r = 1 ; $n_r <= $num_ripeti ; $n_r++) {
 for ($num1 = 0 ; $num1 < $num_var_predef_ripeti ; $num1++) ${$var_predef[$num1]."_".$n_r} = stripslashes(${$var_predef[$num1]."_".$n_r});
 } # fine for $n_r
-} # fine if (get_magic_quotes_gpc())
+} # fine if (@get_magic_quotes_gpc())
 
 
 if ($lista_prenota) {
 $lista_clienti = "";
+$lista_cassa = "";
 if ($priv_vedi_tab_prenotazioni != "n" or ($priv_vedi_tab_mesi != "n" and $priv_mod_prenotazioni != "n")) {
 $lista_prenota = explode(",",$lista_prenota);
 $num_ripeti = count($lista_prenota) - 2;
@@ -396,6 +408,7 @@ include("./includes/dati_lista_prenota.php");
 } # fine if ($lista_prenota)
 
 if ($lista_clienti) {
+$lista_cassa = "";
 if ($vedi_clienti != "NO") {
 $lista_clienti = explode(",",$lista_clienti);
 $num_ripeti = count($lista_clienti) - 2;
@@ -403,6 +416,13 @@ include("./includes/dati_lista_clienti.php");
 } # fine if ($vedi_clienti != "NO")
 } # fine if ($lista_clienti)
 
+if ($lista_cassa and controlla_num_pos($lista_cassa) == "SI") {
+if ($priv_vedi_tab_costi != "n" and ($attiva_casse_consentite == "n" or $casse_consentite_vett[$lista_cassa] == "SI")) {
+$num_ripeti = 1;
+include("./includes/dati_lista_cassa.php");
+} # fine if ($priv_vedi_tab_costi != "n" and ($attiva_casse_consentite == "n" or $casse_consentite_vett[$lista_cassa] == "SI"))
+} # fine if ($lista_cassa and controlla_num_pos($lista_cassa) == "SI")
+
 
 
 $mostra_headers = "SI";
@@ -410,8 +430,13 @@ $messaggio_di_errore = "";
 $num_contr_esist = 0;
 if (!$id_transazione) $contratto = crea_contratto($numero_contratto,$tipo_contratto,$id_utente,$id_sessione,$origine,$origine_vecchia);
 else {
-if (substr($nome_file_contr[$n_file],-3) == ".gz") $contratto = implode("",@gzfile($dir_salvato."/".$nome_file_contr[$n_file]));
-else $contratto = implode("",@file($dir_salvato."/".$nome_file_contr[$n_file]));
+if (@is_file($dir_salvato."/".$nome_file_contr[$n_file])) {
+if (substr($nome_file_contr[$n_file],-3) == ".gz") $contratto = @gzfile($dir_salvato."/".$nome_file_contr[$n_file]);
+else $contratto = @file($dir_salvato."/".$nome_file_contr[$n_file]);
+if (@is_array($contratto)) $contratto = implode("",$contratto);
+else $contratto = "";
+} # fine if (@is_file($dir_salvato."/".$nome_file_contr[$n_file]))
+else $contratto = "";
 } # fine else if (!$id_transazione)
 
 if ($messaggio_di_errore) {
